package com.jjt.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.BizInspectionDetail;
import com.jjt.biz.service.IBizInspectionDetailService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 业务模型健康度评分明细Controller
 *
 * @author jjt
 * @date 2024-08-26
 */
@Api(tags="业务模型健康度评分明细")
@RestController
@RequestMapping("/hl/id")
public class BizInspectionDetailController extends BaseController
{
    @Resource
    private IBizInspectionDetailService bizInspectionDetailService;

    /**
     * 查询业务模型健康度评分明细列表
     */
    @ApiOperation("查询业务模型健康度评分明细列表")
    //@PreAuthorize("@ss.hasPermi('hl:id:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizInspectionDetail bizInspectionDetail)
    {
        startPage();
        List<BizInspectionDetail> list = bizInspectionDetailService.selectBizInspectionDetailList(bizInspectionDetail);
        return getDataTable(list);
    }

    /**
     * 导出业务模型健康度评分明细列表
     */
    @ApiOperation("导出业务模型健康度评分明细列表")
    //@PreAuthorize("@ss.hasPermi('hl:id:export')")
    @Log(title = "业务模型健康度评分明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizInspectionDetail bizInspectionDetail)
    {
        List<BizInspectionDetail> list = bizInspectionDetailService.selectBizInspectionDetailList(bizInspectionDetail);
        ExcelUtil<BizInspectionDetail> util = new ExcelUtil<BizInspectionDetail>(BizInspectionDetail.class);
        util.exportExcel(response, list, "业务模型健康度评分明细数据");
    }

    /**
     * 获取业务模型健康度评分明细详细信息
     */
    @ApiOperation("获取业务模型健康度评分明细详细信息")
    //@PreAuthorize("@ss.hasPermi('hl:id:query')")
    @GetMapping(value = "/{inspectionDetailId}")
    public AjaxResult getInfo(@PathVariable("inspectionDetailId") Long inspectionDetailId)
    {
        return success(bizInspectionDetailService.selectBizInspectionDetailByInspectionDetailId(inspectionDetailId));
    }

    /**
     * 新增业务模型健康度评分明细
     */
    @ApiOperation("新增业务模型健康度评分明细")
    //@PreAuthorize("@ss.hasPermi('hl:id:add')")
    @Log(title = "业务模型健康度评分明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizInspectionDetail bizInspectionDetail)
    {
        return toAjax(bizInspectionDetailService.insertBizInspectionDetail(bizInspectionDetail));
    }

    /**
     * 修改业务模型健康度评分明细
     */
    @ApiOperation("修改业务模型健康度评分明细")
    //@PreAuthorize("@ss.hasPermi('hl:id:edit')")
    @Log(title = "业务模型健康度评分明细", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody BizInspectionDetail bizInspectionDetail)
    {
        return toAjax(bizInspectionDetailService.updateBizInspectionDetail(bizInspectionDetail));
    }

    /**
     * 删除业务模型健康度评分明细
     */
    @ApiOperation("删除业务模型健康度评分明细")
    //@PreAuthorize("@ss.hasPermi('hl:id:remove')")
    @Log(title = "业务模型健康度评分明细", businessType = BusinessType.DELETE)
	@GetMapping("/del/{inspectionDetailIds}")
    public AjaxResult remove(@PathVariable Long[] inspectionDetailIds)
    {
        return toAjax(bizInspectionDetailService.deleteBizInspectionDetailByInspectionDetailIds(inspectionDetailIds));
    }
}
