package com.jjt.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.BizInspectionMetrics;
import com.jjt.biz.service.IBizInspectionMetricsService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 业务模型健康度指标明细Controller
 *
 * @author jjt
 * @date 2024-08-26
 */
@Api(tags="业务模型健康度指标明细")
@RestController
@RequestMapping("/hl/im")
public class BizInspectionMetricsController extends BaseController
{
    @Resource
    private IBizInspectionMetricsService bizInspectionMetricsService;

    /**
     * 查询业务模型健康度指标明细列表
     */
    @ApiOperation("查询业务模型健康度指标明细列表")
    //@PreAuthorize("@ss.hasPermi('hl:im:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizInspectionMetrics bizInspectionMetrics)
    {
        startPage();
        List<BizInspectionMetrics> list = bizInspectionMetricsService.selectBizInspectionMetricsList(bizInspectionMetrics);
        return getDataTable(list);
    }

    /**
     * 导出业务模型健康度指标明细列表
     */
    @ApiOperation("导出业务模型健康度指标明细列表")
    //@PreAuthorize("@ss.hasPermi('hl:im:export')")
    @Log(title = "业务模型健康度指标明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizInspectionMetrics bizInspectionMetrics)
    {
        List<BizInspectionMetrics> list = bizInspectionMetricsService.selectBizInspectionMetricsList(bizInspectionMetrics);
        ExcelUtil<BizInspectionMetrics> util = new ExcelUtil<BizInspectionMetrics>(BizInspectionMetrics.class);
        util.exportExcel(response, list, "业务模型健康度指标明细数据");
    }

    /**
     * 获取业务模型健康度指标明细详细信息
     */
    @ApiOperation("获取业务模型健康度指标明细详细信息")
    //@PreAuthorize("@ss.hasPermi('hl:im:query')")
    @GetMapping(value = "/{autoId}")
    public AjaxResult getInfo(@PathVariable("autoId") Long autoId)
    {
        return success(bizInspectionMetricsService.selectBizInspectionMetricsByAutoId(autoId));
    }

    /**
     * 新增业务模型健康度指标明细
     */
    @ApiOperation("新增业务模型健康度指标明细")
    //@PreAuthorize("@ss.hasPermi('hl:im:add')")
    @Log(title = "业务模型健康度指标明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizInspectionMetrics bizInspectionMetrics)
    {
        return toAjax(bizInspectionMetricsService.insertBizInspectionMetrics(bizInspectionMetrics));
    }

    /**
     * 修改业务模型健康度指标明细
     */
    @ApiOperation("修改业务模型健康度指标明细")
    //@PreAuthorize("@ss.hasPermi('hl:im:edit')")
    @Log(title = "业务模型健康度指标明细", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody BizInspectionMetrics bizInspectionMetrics)
    {
        return toAjax(bizInspectionMetricsService.updateBizInspectionMetrics(bizInspectionMetrics));
    }

    /**
     * 删除业务模型健康度指标明细
     */
    @ApiOperation("删除业务模型健康度指标明细")
    //@PreAuthorize("@ss.hasPermi('hl:im:remove')")
    @Log(title = "业务模型健康度指标明细", businessType = BusinessType.DELETE)
	@GetMapping("/del/{autoIds}")
    public AjaxResult remove(@PathVariable Long[] autoIds)
    {
        return toAjax(bizInspectionMetricsService.deleteBizInspectionMetricsByAutoIds(autoIds));
    }
}
