package com.jjt.biz.controller;

import com.jjt.biz.domain.BizModelDetail;
import com.jjt.biz.service.IBizModelDetailService;
import com.jjt.biz.service.IBizModelService;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 业务模型明细Controller
 *
 * @author jjt
 * @date 2024-08-26
 */
@Api(tags = "业务模型明细")
@RestController
@RequestMapping("/hl/bd")
public class BizModelDetailController extends BaseController {
    @Resource
    private IBizModelDetailService bizModelDetailService;
    @Resource
    private IBizModelService modelService;

    /**
     * 查询业务模型明细列表
     */
    @ApiOperation("查询业务模型明细列表")
    //@PreAuthorize("@ss.hasPermi('hl:bd:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizModelDetail bizModelDetail) {
        startPage();
        List<BizModelDetail> list = bizModelDetailService.selectBizModelDetailList(bizModelDetail);
        return getDataTable(list);
    }

    /**
     * 导出业务模型明细列表
     */
    @ApiOperation("导出业务模型明细列表")
    //@PreAuthorize("@ss.hasPermi('hl:bd:export')")
    @Log(title = "业务模型明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizModelDetail bizModelDetail) {
        List<BizModelDetail> list = bizModelDetailService.selectBizModelDetailList(bizModelDetail);
        ExcelUtil<BizModelDetail> util = new ExcelUtil<BizModelDetail>(BizModelDetail.class);
        util.exportExcel(response, list, "业务模型明细数据");
    }

    /**
     * 获取业务模型明细详细信息
     */
    @ApiOperation("获取业务模型明细详细信息")
    //@PreAuthorize("@ss.hasPermi('hl:bd:query')")
    @GetMapping(value = "/{bizDetailId}")
    public AjaxResult getInfo(@PathVariable("bizDetailId") Long bizDetailId) {
        return success(bizModelDetailService.selectBizModelDetailByBizDetailId(bizDetailId));
    }

    /**
     * 新增业务模型明细
     */
    @ApiOperation("新增业务模型明细")
    //@PreAuthorize("@ss.hasPermi('hl:bd:add')")
    @Log(title = "业务模型明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizModelDetail bizModelDetail) {
        return toAjax(bizModelDetailService.insertBizModelDetail(bizModelDetail));
    }

    /**
     * 修改业务模型明细
     */
    @ApiOperation("修改业务模型明细")
    //@PreAuthorize("@ss.hasPermi('hl:bd:edit')")
    @Log(title = "业务模型明细", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody BizModelDetail bizModelDetail) {
        return toAjax(bizModelDetailService.updateBizModelDetail(bizModelDetail));
    }

    /**
     * 删除业务模型明细
     */
    @ApiOperation("删除业务模型明细")
    //@PreAuthorize("@ss.hasPermi('hl:bd:remove')")
    @Log(title = "业务模型明细", businessType = BusinessType.DELETE)
    @GetMapping("/del")
    public AjaxResult remove(Long[] bizDetailIds) {
        for (Long id : bizDetailIds) {
            BizModelDetail detail = bizModelDetailService.selectBizModelDetailByBizDetailId(id);
            modelService.cleanClass(detail.getModelId());
        }
        return toAjax(bizModelDetailService.deleteBizModelDetailByBizDetailIds(bizDetailIds));
    }
}
