package com.jjt.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.BizModelMetrics;
import com.jjt.biz.service.IBizModelMetricsService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 业务模型健康度指标Controller
 *
 * @author jjt
 * @date 2024-08-26
 */
@Api(tags="业务模型健康度指标")
@RestController
@RequestMapping("/hl/bdm")
public class BizModelMetricsController extends BaseController
{
    @Resource
    private IBizModelMetricsService bizModelMetricsService;

    /**
     * 查询业务模型健康度指标列表
     */
    @ApiOperation("查询业务模型健康度指标列表")
    //@PreAuthorize("@ss.hasPermi('hl:bdm:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizModelMetrics bizModelMetrics)
    {
        startPage();
        List<BizModelMetrics> list = bizModelMetricsService.selectBizModelMetricsList(bizModelMetrics);
        return getDataTable(list);
    }

    /**
     * 导出业务模型健康度指标列表
     */
    @ApiOperation("导出业务模型健康度指标列表")
    //@PreAuthorize("@ss.hasPermi('hl:bdm:export')")
    @Log(title = "业务模型健康度指标", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizModelMetrics bizModelMetrics)
    {
        List<BizModelMetrics> list = bizModelMetricsService.selectBizModelMetricsList(bizModelMetrics);
        ExcelUtil<BizModelMetrics> util = new ExcelUtil<BizModelMetrics>(BizModelMetrics.class);
        util.exportExcel(response, list, "业务模型健康度指标数据");
    }

    /**
     * 获取业务模型健康度指标详细信息
     */
    @ApiOperation("获取业务模型健康度指标详细信息")
    //@PreAuthorize("@ss.hasPermi('hl:bdm:query')")
    @GetMapping(value = "/{bizMetricsId}")
    public AjaxResult getInfo(@PathVariable("bizMetricsId") Long bizMetricsId)
    {
        return success(bizModelMetricsService.selectBizModelMetricsByBizMetricsId(bizMetricsId));
    }

    /**
     * 新增业务模型健康度指标
     */
    @ApiOperation("新增业务模型健康度指标")
    //@PreAuthorize("@ss.hasPermi('hl:bdm:add')")
    @Log(title = "业务模型健康度指标", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizModelMetrics bizModelMetrics)
    {
        return toAjax(bizModelMetricsService.insertBizModelMetrics(bizModelMetrics));
    }

    /**
     * 修改业务模型健康度指标
     */
    @ApiOperation("修改业务模型健康度指标")
    //@PreAuthorize("@ss.hasPermi('hl:bdm:edit')")
    @Log(title = "业务模型健康度指标", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody BizModelMetrics bizModelMetrics)
    {
        return toAjax(bizModelMetricsService.updateBizModelMetrics(bizModelMetrics));
    }

    /**
     * 删除业务模型健康度指标
     */
    @ApiOperation("删除业务模型健康度指标")
    //@PreAuthorize("@ss.hasPermi('hl:bdm:remove')")
    @Log(title = "业务模型健康度指标", businessType = BusinessType.DELETE)
	@GetMapping("/del/{bizMetricsIds}")
    public AjaxResult remove(@PathVariable Long[] bizMetricsIds)
    {
        return toAjax(bizModelMetricsService.deleteBizModelMetricsByBizMetricsIds(bizMetricsIds));
    }
}
