package com.jjt.biz.controller;

import com.jjt.biz.domain.BizObjApp;
import com.jjt.biz.service.IBizObjAppService;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.SecurityUtils;
import com.jjt.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 应用程序管理Controller
 *
 * @author jjt
 * @date 2024-08-09
 */
@Api(tags = "应用程序管理")
@RestController
@RequestMapping("/obj/app")
public class BizObjAppController extends BaseController {
    @Resource
    private IBizObjAppService bizObjAppService;

    /**
     * 查询应用程序管理列表
     */
    @ApiOperation("查询应用程序管理列表")
    //@PreAuthorize("@ss.hasPermi('obj:app:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizObjApp bizObjApp) {
        startPage();
        List<BizObjApp> list = bizObjAppService.selectBizObjAppList(bizObjApp);
        return getDataTable(list);
    }

    /**
     * 导出应用程序管理列表
     */
    @ApiOperation("导出应用程序管理列表")
    //@PreAuthorize("@ss.hasPermi('obj:app:export')")
    @Log(title = "应用程序管理" , businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizObjApp bizObjApp) {
        List<BizObjApp> list = bizObjAppService.selectBizObjAppList(bizObjApp);
        ExcelUtil<BizObjApp> util = new ExcelUtil<BizObjApp>(BizObjApp.class);
        util.exportExcel(response, list, "应用程序管理数据");
    }

    /**
     * 获取应用程序管理详细信息
     */
    @ApiOperation("获取应用程序管理详细信息")
    //@PreAuthorize("@ss.hasPermi('obj:app:query')")
    @GetMapping(value = "/{appId}")
    public AjaxResult getInfo(@PathVariable("appId") Long appId) {
        return success(bizObjAppService.selectBizObjAppByAppId(appId));
    }

    /**
     * 新增应用程序管理
     */
    @ApiOperation("新增应用程序管理")
    //@PreAuthorize("@ss.hasPermi('obj:app:add')")
    @Log(title = "应用程序管理" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizObjApp bizObjApp) {
        bizObjApp.setCreateBy("admin");
        return toAjax(bizObjAppService.insertBizObjApp(bizObjApp));
    }

    /**
     * 修改应用程序管理
     */
    @ApiOperation("修改应用程序管理")
    //@PreAuthorize("@ss.hasPermi('obj:app:edit')")
    @Log(title = "应用程序管理" , businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody BizObjApp bizObjApp) {
        bizObjApp.setUpdateBy("admin");
        return toAjax(bizObjAppService.updateBizObjApp(bizObjApp));
    }

    /**
     * 删除应用程序管理
     */
    @ApiOperation("删除应用程序管理")
    //@PreAuthorize("@ss.hasPermi('obj:app:remove')")
    @Log(title = "应用程序管理" , businessType = BusinessType.DELETE)
    @GetMapping("/del/{appIds}")
    public AjaxResult remove(@PathVariable Long[] appIds) {
        return toAjax(bizObjAppService.deleteBizObjAppByAppIds(appIds));
    }
}
