package com.jjt.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.BizObjMc;
import com.jjt.biz.service.IBizObjMcService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 业务对象自定义指标Controller
 *
 * @author jjt
 * @date 2024-10-09
 */
@Api(tags="业务对象自定义指标")
@RestController
@RequestMapping("/biz/mc")
public class BizObjMcController extends BaseController
{
    @Resource
    private IBizObjMcService bizObjMcService;

    /**
     * 查询业务对象自定义指标列表
     */
    @ApiOperation("查询业务对象自定义指标列表")
    //@PreAuthorize("@ss.hasPermi('biz:mc:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizObjMc bizObjMc)
    {
        startPage();
        List<BizObjMc> list = bizObjMcService.selectBizObjMcList(bizObjMc);
        return getDataTable(list);
    }

    /**
     * 导出业务对象自定义指标列表
     */
    @ApiOperation("导出业务对象自定义指标列表")
    //@PreAuthorize("@ss.hasPermi('biz:mc:export')")
    @Log(title = "业务对象自定义指标", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizObjMc bizObjMc)
    {
        List<BizObjMc> list = bizObjMcService.selectBizObjMcList(bizObjMc);
        ExcelUtil<BizObjMc> util = new ExcelUtil<BizObjMc>(BizObjMc.class);
        util.exportExcel(response, list, "业务对象自定义指标数据");
    }

    /**
     * 获取业务对象自定义指标详细信息
     */
    @ApiOperation("获取业务对象自定义指标详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:mc:query')")
    @GetMapping(value = "/{mcId}")
    public AjaxResult getInfo(@PathVariable("mcId") Long mcId)
    {
        return success(bizObjMcService.selectBizObjMcByMcId(mcId));
    }

    /**
     * 新增业务对象自定义指标
     */
    @ApiOperation("新增业务对象自定义指标")
    //@PreAuthorize("@ss.hasPermi('biz:mc:add')")
    @Log(title = "业务对象自定义指标", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizObjMc bizObjMc)
    {
        return toAjax(bizObjMcService.insertBizObjMc(bizObjMc));
    }

    /**
     * 修改业务对象自定义指标
     */
    @ApiOperation("修改业务对象自定义指标")
    //@PreAuthorize("@ss.hasPermi('biz:mc:edit')")
    @Log(title = "业务对象自定义指标", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody BizObjMc bizObjMc)
    {
        return toAjax(bizObjMcService.updateBizObjMc(bizObjMc));
    }

    /**
     * 删除业务对象自定义指标
     */
    @ApiOperation("删除业务对象自定义指标")
    //@PreAuthorize("@ss.hasPermi('biz:mc:remove')")
    @Log(title = "业务对象自定义指标", businessType = BusinessType.DELETE)
	@GetMapping("/del")
    public AjaxResult remove(Long[] mcIds)
    {
        return toAjax(bizObjMcService.deleteBizObjMcByMcIds(mcIds));
    }
}
