package com.jjt.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.BizObjMetricsData;
import com.jjt.biz.service.IBizObjMetricsDataService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 业务对象指标数据Controller
 *
 * @author jjt
 * @date 2024-09-01
 */
@Api(tags="业务对象指标数据")
@RestController
@RequestMapping("/obj/omd")
public class BizObjMetricsDataController extends BaseController
{
    @Resource
    private IBizObjMetricsDataService bizObjMetricsDataService;

    /**
     * 查询业务对象指标数据列表
     */
    @ApiOperation("查询业务对象指标数据列表")
    //@PreAuthorize("@ss.hasPermi('obj:omd:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizObjMetricsData bizObjMetricsData)
    {
        startPage();
        List<BizObjMetricsData> list = bizObjMetricsDataService.selectBizObjMetricsDataList(bizObjMetricsData);
        return getDataTable(list);
    }

    /**
     * 导出业务对象指标数据列表
     */
    @ApiOperation("导出业务对象指标数据列表")
    //@PreAuthorize("@ss.hasPermi('obj:omd:export')")
    @Log(title = "业务对象指标数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizObjMetricsData bizObjMetricsData)
    {
        List<BizObjMetricsData> list = bizObjMetricsDataService.selectBizObjMetricsDataList(bizObjMetricsData);
        ExcelUtil<BizObjMetricsData> util = new ExcelUtil<BizObjMetricsData>(BizObjMetricsData.class);
        util.exportExcel(response, list, "业务对象指标数据数据");
    }

    /**
     * 获取业务对象指标数据详细信息
     */
    @ApiOperation("获取业务对象指标数据详细信息")
    //@PreAuthorize("@ss.hasPermi('obj:omd:query')")
    @GetMapping(value = "/{dataId}")
    public AjaxResult getInfo(@PathVariable("dataId") Long dataId)
    {
        return success(bizObjMetricsDataService.selectBizObjMetricsDataByDataId(dataId));
    }

    /**
     * 新增业务对象指标数据
     */
    @ApiOperation("新增业务对象指标数据")
    //@PreAuthorize("@ss.hasPermi('obj:omd:add')")
    @Log(title = "业务对象指标数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizObjMetricsData bizObjMetricsData)
    {
        return toAjax(bizObjMetricsDataService.insertBizObjMetricsData(bizObjMetricsData));
    }

    /**
     * 修改业务对象指标数据
     */
    @ApiOperation("修改业务对象指标数据")
    //@PreAuthorize("@ss.hasPermi('obj:omd:edit')")
    @Log(title = "业务对象指标数据", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody BizObjMetricsData bizObjMetricsData)
    {
        return toAjax(bizObjMetricsDataService.updateBizObjMetricsData(bizObjMetricsData));
    }

    /**
     * 删除业务对象指标数据
     */
    @ApiOperation("删除业务对象指标数据")
    //@PreAuthorize("@ss.hasPermi('obj:omd:remove')")
    @Log(title = "业务对象指标数据", businessType = BusinessType.DELETE)
	@GetMapping("/del/{dataIds}")
    public AjaxResult remove(@PathVariable Long[] dataIds)
    {
        return toAjax(bizObjMetricsDataService.deleteBizObjMetricsDataByDataIds(dataIds));
    }
}
