package com.jjt.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.BizObjPp;
import com.jjt.biz.service.IBizObjPpService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 业务对象pinpoint组成Controller
 *
 * @author jjt
 * @date 2024-08-09
 */
@Api(tags="业务对象pinpoint组成")
@RestController
@RequestMapping("/obj/pp")
public class BizObjPpController extends BaseController
{
    @Resource
    private IBizObjPpService bizObjPpService;

    /**
     * 查询业务对象pinpoint组成列表
     */
    @ApiOperation("查询业务对象pinpoint组成列表")
    //@PreAuthorize("@ss.hasPermi('obj:pp:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizObjPp bizObjPp)
    {
        startPage();
        List<BizObjPp> list = bizObjPpService.selectBizObjPpList(bizObjPp);
        return getDataTable(list);
    }

    /**
     * 导出业务对象pinpoint组成列表
     */
    @ApiOperation("导出业务对象pinpoint组成列表")
    //@PreAuthorize("@ss.hasPermi('obj:pp:export')")
    @Log(title = "业务对象pinpoint组成", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizObjPp bizObjPp)
    {
        List<BizObjPp> list = bizObjPpService.selectBizObjPpList(bizObjPp);
        ExcelUtil<BizObjPp> util = new ExcelUtil<BizObjPp>(BizObjPp.class);
        util.exportExcel(response, list, "业务对象pinpoint组成数据");
    }

    /**
     * 获取业务对象pinpoint组成详细信息
     */
    @ApiOperation("获取业务对象pinpoint组成详细信息")
    //@PreAuthorize("@ss.hasPermi('obj:pp:query')")
    @GetMapping(value = "/{objPpId}")
    public AjaxResult getInfo(@PathVariable("objPpId") Long objPpId)
    {
        return success(bizObjPpService.selectBizObjPpByObjPpId(objPpId));
    }

    /**
     * 新增业务对象pinpoint组成
     */
    @ApiOperation("新增业务对象pinpoint组成")
    //@PreAuthorize("@ss.hasPermi('obj:pp:add')")
    @Log(title = "业务对象pinpoint组成", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizObjPp bizObjPp)
    {
        return toAjax(bizObjPpService.insertBizObjPp(bizObjPp));
    }

    /**
     * 修改业务对象pinpoint组成
     */
    @ApiOperation("修改业务对象pinpoint组成")
    //@PreAuthorize("@ss.hasPermi('obj:pp:edit')")
    @Log(title = "业务对象pinpoint组成", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody BizObjPp bizObjPp)
    {
        return toAjax(bizObjPpService.updateBizObjPp(bizObjPp));
    }

    /**
     * 删除业务对象pinpoint组成
     */
    @ApiOperation("删除业务对象pinpoint组成")
    //@PreAuthorize("@ss.hasPermi('obj:pp:remove')")
    @Log(title = "业务对象pinpoint组成", businessType = BusinessType.DELETE)
	@GetMapping("/del/{objPpIds}")
    public AjaxResult remove(@PathVariable Long[] objPpIds)
    {
        return toAjax(bizObjPpService.deleteBizObjPpByObjPpIds(objPpIds));
    }
}
