package com.jjt.biz.controller;

import com.jjt.biz.domain.BizObjTpl;
import com.jjt.biz.domain.MetricsDef;
import com.jjt.biz.domain.MetricsTpl;
import com.jjt.biz.service.IBizObjTplService;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 业务对象模板应用Controller
 *
 * @author jjt
 * @date 2024-08-09
 */
@Api(tags = "业务对象模板应用")
@RestController
@RequestMapping("/obj/tpl")
public class BizObjTplController extends BaseController {
    @Resource
    private IBizObjTplService bizObjTplService;

    /**
     * 查询业务对象模板应用列表
     */
    @ApiOperation("查询业务对象模板应用列表")
    //@PreAuthorize("@ss.hasPermi('obj:tpl:list')")
    @GetMapping("/list")
    public TableDataInfo list(BizObjTpl bizObjTpl) {
        startPage();
        List<BizObjTpl> list = bizObjTplService.selectBizObjTplList(bizObjTpl);
        return getDataTable(list);
    }

    /**
     * 导出业务对象模板应用列表
     */
    @ApiOperation("导出业务对象模板应用列表")
    //@PreAuthorize("@ss.hasPermi('obj:tpl:export')")
    @Log(title = "业务对象模板应用" , businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BizObjTpl bizObjTpl) {
        List<BizObjTpl> list = bizObjTplService.selectBizObjTplList(bizObjTpl);
        ExcelUtil<BizObjTpl> util = new ExcelUtil<BizObjTpl>(BizObjTpl.class);
        util.exportExcel(response, list, "业务对象模板应用数据");
    }

    /**
     * 获取业务对象模板应用详细信息
     */
    @ApiOperation("获取业务对象模板应用详细信息")
    //@PreAuthorize("@ss.hasPermi('obj:tpl:query')")
    @GetMapping(value = "/{objTplId}")
    public AjaxResult getInfo(@PathVariable("objTplId") Long objTplId) {
        return success(bizObjTplService.selectBizObjTplByObjTplId(objTplId));
    }

    /**
     * 新增业务对象模板应用
     */
    @ApiOperation("新增业务对象模板应用")
    //@PreAuthorize("@ss.hasPermi('obj:tpl:add')")
    @Log(title = "业务对象模板应用" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BizObjTpl bizObjTpl) {
        return toAjax(bizObjTplService.insertBizObjTpl(bizObjTpl));
    }

    /**
     * 修改业务对象模板应用
     */
    @ApiOperation("修改业务对象模板应用")
    //@PreAuthorize("@ss.hasPermi('obj:tpl:edit')")
    @Log(title = "业务对象模板应用" , businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody BizObjTpl bizObjTpl) {
        return toAjax(bizObjTplService.updateBizObjTpl(bizObjTpl));
    }

    /**
     * 删除业务对象模板应用
     */
    @ApiOperation("删除业务对象模板应用")
    //@PreAuthorize("@ss.hasPermi('obj:tpl:remove')")
    @Log(title = "业务对象模板应用" , businessType = BusinessType.DELETE)
    @GetMapping("/del/{objTplIds}")
    public AjaxResult remove(@PathVariable Long[] objTplIds) {
        return toAjax(bizObjTplService.deleteBizObjTplByObjTplIds(objTplIds));
    }
}
