package com.jjt.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.biz.domain.IndexMetrics;
import com.jjt.biz.service.IIndexMetricsService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 首页指标配置Controller
 *
 * @author jjt
 * @date 2024-09-12
 */
@Api(tags="首页指标配置")
@RestController
@RequestMapping("/biz/msConfig")
public class IndexMetricsController extends BaseController
{
    @Resource
    private IIndexMetricsService indexMetricsService;

    /**
     * 查询首页指标配置列表
     */
    @ApiOperation("查询首页指标配置列表")
    //@PreAuthorize("@ss.hasPermi('biz:msConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(IndexMetrics indexMetrics)
    {
        startPage();
        List<IndexMetrics> list = indexMetricsService.selectIndexMetricsList(indexMetrics);
        return getDataTable(list);
    }

    /**
     * 导出首页指标配置列表
     */
    @ApiOperation("导出首页指标配置列表")
    //@PreAuthorize("@ss.hasPermi('biz:msConfig:export')")
    @Log(title = "首页指标配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, IndexMetrics indexMetrics)
    {
        List<IndexMetrics> list = indexMetricsService.selectIndexMetricsList(indexMetrics);
        ExcelUtil<IndexMetrics> util = new ExcelUtil<IndexMetrics>(IndexMetrics.class);
        util.exportExcel(response, list, "首页指标配置数据");
    }

    /**
     * 获取首页指标配置详细信息
     */
    @ApiOperation("获取首页指标配置详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:msConfig:query')")
    @GetMapping(value = "/{imId}")
    public AjaxResult getInfo(@PathVariable("imId") Long imId)
    {
        return success(indexMetricsService.selectIndexMetricsByImId(imId));
    }

    /**
     * 新增首页指标配置
     */
    @ApiOperation("新增首页指标配置")
    //@PreAuthorize("@ss.hasPermi('biz:msConfig:add')")
    @Log(title = "首页指标配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody IndexMetrics indexMetrics)
    {
        return toAjax(indexMetricsService.insertIndexMetrics(indexMetrics));
    }

    /**
     * 修改首页指标配置
     */
    @ApiOperation("修改首页指标配置")
    //@PreAuthorize("@ss.hasPermi('biz:msConfig:edit')")
    @Log(title = "首页指标配置", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody IndexMetrics indexMetrics)
    {
        return toAjax(indexMetricsService.updateIndexMetrics(indexMetrics));
    }

    /**
     * 删除首页指标配置
     */
    @ApiOperation("删除首页指标配置")
    //@PreAuthorize("@ss.hasPermi('biz:msConfig:remove')")
    @Log(title = "首页指标配置", businessType = BusinessType.DELETE)
	@GetMapping("/del/{imIds}")
    public AjaxResult remove(@PathVariable Long[] imIds)
    {
        return toAjax(indexMetricsService.deleteIndexMetricsByImIds(imIds));
    }
}
