package com.jjt.biz.controller;

import com.jjt.biz.domain.MetricsTpl;
import com.jjt.biz.service.IMetricsTplService;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.SecurityUtils;
import com.jjt.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 指标模板Controller
 *
 * @author jjt
 * @date 2024-08-08
 */
@Api(tags = "指标模板")
@RestController
@RequestMapping("/metrics/tpl")
public class MetricsTplController extends BaseController {
    @Resource
    private IMetricsTplService metricsTplService;

    /**
     * 查询指标模板列表
     */
    @ApiOperation("查询指标模板列表")
    //@PreAuthorize("@ss.hasPermi('metrics:tpl:list')")
    @GetMapping("/list")
    public TableDataInfo list(MetricsTpl metricsTpl) {
        startPage();
        List<MetricsTpl> list = metricsTplService.selectMetricsTplList(metricsTpl);
        return getDataTable(list);
    }

    /**
     * 导出指标模板列表
     */
    @ApiOperation("导出指标模板列表")
    //@PreAuthorize("@ss.hasPermi('metrics:tpl:export')")
    @Log(title = "指标模板", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MetricsTpl metricsTpl) {
        List<MetricsTpl> list = metricsTplService.selectMetricsTplList(metricsTpl);
        ExcelUtil<MetricsTpl> util = new ExcelUtil<MetricsTpl>(MetricsTpl.class);
        util.exportExcel(response, list, "指标模板数据");
    }

    /**
     * 获取指标模板详细信息
     */
    @ApiOperation("获取指标模板详细信息")
    //@PreAuthorize("@ss.hasPermi('metrics:tpl:query')")
    @GetMapping(value = "/detail")
    public AjaxResult getInfo(Long tplId) {
        return success(metricsTplService.selectMetricsTplByTplId(tplId));
    }

    /**
     * 新增指标模板
     */
    @ApiOperation("新增指标模板")
    //@PreAuthorize("@ss.hasPermi('metrics:tpl:add')")
    @Log(title = "指标模板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MetricsTpl metricsTpl) {
        metricsTpl.setConfStatus("N");
        metricsTpl.setCreateBy("admin");
        return toAjax(metricsTplService.insertMetricsTpl(metricsTpl));
    }

    /**
     * 修改指标模板
     */
    @ApiOperation("修改指标模板")
    //@PreAuthorize("@ss.hasPermi('metrics:tpl:edit')")
    @Log(title = "指标模板", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody MetricsTpl metricsTpl) {
        metricsTpl.setUpdateBy("admin");
        return toAjax(metricsTplService.updateMetricsTpl(metricsTpl));
    }

    /**
     * 删除指标模板
     */
    @ApiOperation("删除指标模板")
    //@PreAuthorize("@ss.hasPermi('metrics:tpl:remove')")
    @Log(title = "指标模板", businessType = BusinessType.DELETE)
    @GetMapping("/del")
    public AjaxResult remove(Long[] tplIds) {
        return toAjax(metricsTplService.deleteMetricsTplByTplIds(tplIds));
    }
}
