package com.jjt.biz.controller;

import com.jjt.biz.domain.MetricsTypeDef;
import com.jjt.biz.service.IMetricsTypeDefService;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.poi.ExcelUtil;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 分类和定义关系Controller
 *
 * @author jjt
 * @date 2024-08-08
 */
//@Api(tags="分类和定义关系")
@RestController
@RequestMapping("/metrics/rela")
public class MetricsTypeDefController extends BaseController {
    @Resource
    private IMetricsTypeDefService metricsTypeDefService;

    /**
     * 查询分类和定义关系列表
     */
    @ApiOperation("查询分类和定义关系列表")
    //@PreAuthorize("@ss.hasPermi('metrics:rela:list')")
    @GetMapping("/list")
    public TableDataInfo list(MetricsTypeDef metricsTypeDef) {
        startPage();
        List<MetricsTypeDef> list = metricsTypeDefService.selectMetricsTypeDefList(metricsTypeDef);
        return getDataTable(list);
    }

    /**
     * 导出分类和定义关系列表
     */
    @ApiOperation("导出分类和定义关系列表")
    //@PreAuthorize("@ss.hasPermi('metrics:rela:export')")
    @Log(title = "分类和定义关系" , businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MetricsTypeDef metricsTypeDef) {
        List<MetricsTypeDef> list = metricsTypeDefService.selectMetricsTypeDefList(metricsTypeDef);
        ExcelUtil<MetricsTypeDef> util = new ExcelUtil<MetricsTypeDef>(MetricsTypeDef.class);
        util.exportExcel(response, list, "分类和定义关系数据");
    }

    /**
     * 获取分类和定义关系详细信息
     */
    @ApiOperation("获取分类和定义关系详细信息")
    //@PreAuthorize("@ss.hasPermi('metrics:rela:query')")
    @GetMapping(value = "/{relaId}")
    public AjaxResult getInfo(@PathVariable("relaId") Long relaId) {
        return success(metricsTypeDefService.selectMetricsTypeDefByRelaId(relaId));
    }

    /**
     * 新增分类和定义关系
     */
    @ApiOperation("新增分类和定义关系")
    //@PreAuthorize("@ss.hasPermi('metrics:rela:add')")
    @Log(title = "分类和定义关系" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MetricsTypeDef metricsTypeDef) {
        return toAjax(metricsTypeDefService.insertMetricsTypeDef(metricsTypeDef));
    }

    /**
     * 修改分类和定义关系
     */
    @ApiOperation("修改分类和定义关系")
    //@PreAuthorize("@ss.hasPermi('metrics:rela:edit')")
    @Log(title = "分类和定义关系" , businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody MetricsTypeDef metricsTypeDef) {
        return toAjax(metricsTypeDefService.updateMetricsTypeDef(metricsTypeDef));
    }

    /**
     * 删除分类和定义关系
     */
    @ApiOperation("删除分类和定义关系")
    //@PreAuthorize("@ss.hasPermi('metrics:rela:remove')")
    @Log(title = "分类和定义关系" , businessType = BusinessType.DELETE)
    @GetMapping("/del/{relaIds}")
    public AjaxResult remove(@PathVariable Long[] relaIds) {
        return toAjax(metricsTypeDefService.deleteMetricsTypeDefByRelaIds(relaIds));
    }
}
