package com.jjt.biz.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.biz.domain.AlarmRecord;

import java.util.List;
import java.util.Map;

/**
 * 告警记录Mapper接口
 *
 * @author jjt
 * @date 2024-08-08
 */
public interface AlarmRecordMapper extends BaseMapper<AlarmRecord> {
    /**
     * 查询告警记录
     *
     * @param alarmId 告警记录主键
     * @return 告警记录
     */
    public AlarmRecord selectAlarmRecordByAlarmId(Long alarmId);

    /**
     * 查询告警记录列表
     *
     * @param alarmRecord 告警记录
     * @return 告警记录集合
     */
    public List<AlarmRecord> selectAlarmRecordList(AlarmRecord alarmRecord);

    /**
     * 新增告警记录
     *
     * @param alarmRecord 告警记录
     * @return 结果
     */
    public int insertAlarmRecord(AlarmRecord alarmRecord);

    /**
     * 修改告警记录
     *
     * @param alarmRecord 告警记录
     * @return 结果
     */
    public int updateAlarmRecord(AlarmRecord alarmRecord);

    /**
     * 删除告警记录
     *
     * @param alarmId 告警记录主键
     * @return 结果
     */
    public int deleteAlarmRecordByAlarmId(Long alarmId);

    /**
     * 批量删除告警记录
     *
     * @param alarmIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAlarmRecordByAlarmIds(Long[] alarmIds);

    /**
     * 告警等级排行
     *
     * @param alarmRecord 对象
     * @return 结果
     */
    List<Map<String, Object>> levelSort(AlarmRecord alarmRecord);
    /**
     * 按小时告警趋势
     *
     * @param alarmRecord 对象
     * @return 结果
     */
    List<Map<String, Object>> listHours(AlarmRecord alarmRecord);
}
