package com.jjt.biz.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.biz.domain.BizModel;
import com.jjt.biz.domain.BizObj;
import com.jjt.biz.domain.BizObjMetrics;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 业务模型Mapper接口
 *
 * @author jjt
 * @date 2024-08-26
 */
public interface BizModelMapper extends BaseMapper<BizModel> {
    /**
     * 查询业务模型
     *
     * @param modelId 业务模型主键
     * @return 业务模型
     */
    public BizModel selectBizModelByModelId(Long modelId);

    /**
     * 查询业务模型列表
     *
     * @param bizModel 业务模型
     * @return 业务模型集合
     */
    public List<BizModel> selectBizModelList(BizModel bizModel);

    /**
     * 新增业务模型
     *
     * @param bizModel 业务模型
     * @return 结果
     */
    public int insertBizModel(BizModel bizModel);

    /**
     * 修改业务模型
     *
     * @param bizModel 业务模型
     * @return 结果
     */
    public int updateBizModel(BizModel bizModel);

    /**
     * 删除业务模型
     *
     * @param modelId 业务模型主键
     * @return 结果
     */
    public int deleteBizModelByModelId(Long modelId);

    /**
     * 批量删除业务模型
     *
     * @param modelIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBizModelByModelIds(Long[] modelIds);
    /**
     * 选择业务对象
     *
     * @param modelId 模型ID
     * @return 结果
     */
    List<BizObj> selectObjList(Long modelId);
    /**
     * 根据模型ID查询指标
     *
     * @param modelId 模型ID
     * @return 结果
     */
    List<BizObjMetrics> selectBizModelMetricsList(Long modelId);
}
