package com.jjt.biz.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.biz.domain.BizObjMetrics;
import com.jjt.biz.domain.MetricsDef;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 业务对象指标Mapper接口
 *
 * @author jjt
 * @date 2024-08-09
 */
public interface BizObjMetricsMapper extends BaseMapper<BizObjMetrics> {
    /**
     * 查询业务对象指标
     *
     * @param objMetricsId 业务对象指标主键
     * @return 业务对象指标
     */
    public BizObjMetrics selectBizObjMetricsByObjMetricsId(Long objMetricsId);

    /**
     * 查询业务对象指标列表
     *
     * @param bizObjMetrics 业务对象指标
     * @return 业务对象指标集合
     */
    public List<BizObjMetrics> selectBizObjMetricsList(BizObjMetrics bizObjMetrics);

    /**
     * 新增业务对象指标
     *
     * @param bizObjMetrics 业务对象指标
     * @return 结果
     */
    public int insertBizObjMetrics(BizObjMetrics bizObjMetrics);

    /**
     * 修改业务对象指标
     *
     * @param bizObjMetrics 业务对象指标
     * @return 结果
     */
    public int updateBizObjMetrics(BizObjMetrics bizObjMetrics);

    /**
     * 删除业务对象指标
     *
     * @param objMetricsId 业务对象指标主键
     * @return 结果
     */
    public int deleteBizObjMetricsByObjMetricsId(Long objMetricsId);

    /**
     * 批量删除业务对象指标
     *
     * @param objMetricsIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBizObjMetricsByObjMetricsIds(Long[] objMetricsIds);

    /**
     * 选择指标，除去当前对象已选择的
     *
     * @param objId 对象ID
     * @return 结果
     */
    List<MetricsDef> selectMetricsDefList(Long objId);

    /**
     * 添加指标
     *
     * @param objId      对象ID
     * @param metricsIds 指标IDS
     * @param suffix     名称添加后缀
     * @return 结果
     */
    int insertMetricsDetails(@Param("objId") Long objId, @Param("suffix") String suffix, @Param("metricsIds") Long[] metricsIds);

    /**
     * 批量插入
     *
     * @param objMetrics 指标列表
     */
    void batchInsert(@Param("objMetrics") List<BizObjMetrics> objMetrics);
}
