package com.jjt.biz.service;

import com.jjt.biz.domain.AlarmRecord;
import com.jjt.biz.domain.BizObjMetrics;
import com.jjt.biz.vo.BizAccessVO;
import com.jjt.biz.vo.BizTypeVO;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 告警记录Service接口
 *
 * @author jjt
 * @date 2024-08-08
 */
public interface IAlarmRecordService {
    /**
     * 查询告警记录
     *
     * @param alarmId 告警记录主键
     * @return 告警记录
     */
    public AlarmRecord selectAlarmRecordByAlarmId(Long alarmId);

    /**
     * 查询告警记录列表
     *
     * @param alarmRecord 告警记录
     * @return 告警记录集合
     */
    public List<AlarmRecord> selectAlarmRecordList(AlarmRecord alarmRecord);

    /**
     * 新增告警记录
     *
     * @param alarmRecord 告警记录
     * @return 结果
     */
    public int insertAlarmRecord(AlarmRecord alarmRecord);

    /**
     * 修改告警记录
     *
     * @param alarmRecord 告警记录
     * @return 结果
     */
    public int updateAlarmRecord(AlarmRecord alarmRecord);

    /**
     * 批量删除告警记录
     *
     * @param alarmIds 需要删除的告警记录主键集合
     * @return 结果
     */
    public int deleteAlarmRecordByAlarmIds(Long[] alarmIds);

    /**
     * 删除告警记录信息
     *
     * @param alarmId 告警记录主键
     * @return 结果
     */
    public int deleteAlarmRecordByAlarmId(Long alarmId);

    /**
     * 告警等级排行
     *
     * @param alarmRecord 对象
     * @return 结果
     */
    List<Map<String, Object>> levelSort(AlarmRecord alarmRecord);

    /**
     * 按小时告警趋势
     *
     * @param alarmRecord 对象
     * @return 结果
     */
    List<Map<String, Object>> listHours(AlarmRecord alarmRecord);

    /**
     * 处理告警和事件
     *
     * @param om        指标对象
     * @param recordMap 正在告警的列表
     * @param date      时间
     * @return 结果
     */
    Map<String, AlarmRecord> process(BizObjMetrics om, Map<Long, AlarmRecord> recordMap, Date date);

    /**
     * 通过对象ID查询当前正在告警的列表,并转换成map
     *
     * @param objId 对象ID
     * @return 结果
     */
    Map<Long, AlarmRecord> selectAlarmRecordListCurr(Long objId);

    /**
     * 业务类型统计
     * @param start 开始时间
     * @param end 结束时间
     * @return 结果
     */
    List<BizTypeVO> listBizType(String start, String end);

    /**
     * 业务组件统计
     * @param type 业务类型
     * @param start 开始时间
     * @param end 结束时间
     * @return 结果
     */
    List<BizTypeVO> listBizObj(String type, String start, String end);

    /**
     * 组件压力排名
     * @param modelId 模型ID
     * @param start 开始时间
     * @param end 结束时间
     * @return 结果
     */
    List<BizAccessVO> objAccess(Long modelId, String start, String end);
}
