package com.jjt.biz.service;

import com.jjt.biz.domain.BizModel;
import com.jjt.biz.domain.BizObj;
import com.jjt.biz.domain.BizObjMetrics;
import com.jjt.hl.domain.HlClass;

import java.util.List;

/**
 * 业务模型Service接口
 *
 * @author jjt
 * @date 2024-08-26
 */
public interface IBizModelService {
    /**
     * 查询业务模型
     *
     * @param modelId 业务模型主键
     * @return 业务模型
     */
    public BizModel selectBizModelByModelId(Long modelId);

    /**
     * 查询业务模型列表
     *
     * @param bizModel 业务模型
     * @return 业务模型集合
     */
    public List<BizModel> selectBizModelList(BizModel bizModel);

    /**
     * 新增业务模型
     *
     * @param bizModel 业务模型
     * @return 结果
     */
    public int insertBizModel(BizModel bizModel);

    /**
     * 修改业务模型
     *
     * @param bizModel 业务模型
     * @return 结果
     */
    public int updateBizModel(BizModel bizModel);

    /**
     * 批量删除业务模型
     *
     * @param modelIds 需要删除的业务模型主键集合
     * @return 结果
     */
    public int deleteBizModelByModelIds(Long[] modelIds);

    /**
     * 删除业务模型信息
     *
     * @param modelId 业务模型主键
     * @return 结果
     */
    public int deleteBizModelByModelId(Long modelId);

    /**
     * 选择业务对象
     *
     * @param modelId 模型ID
     * @return 结果
     */
    List<BizObj> selectObjList(Long modelId);

    /**
     * 添加业务对象
     *
     * @param modelId 模型ID
     * @param objIds  业务对象列表
     * @return 结果
     */
    int insertObj(Long modelId, Long[] objIds);

    /**
     * 根据模型ID查询指标
     *
     * @param modelId 模型ID
     * @return 结果
     */
    List<BizObjMetrics> selectBizModelMetricsList(Long modelId);

    /**
     * 通过模型ID获取 分类列表
     *
     * @param modelId 模型ID
     * @return 结果
     */
    List<HlClass> selectHlClassList4modelId(Long modelId);

    /**
     * 导入分类
     *
     * @param modelId 模型ID
     */
    void impClass(Long modelId);

    /**
     * 清理分类
     *
     * @param modelId 模型ID
     */
    void cleanClass(Long modelId);
}
