package com.jjt.biz.service;

import com.jjt.biz.domain.BizObjMetrics;
import com.jjt.biz.domain.MetricsDef;
import com.jjt.biz.domain.MetricsTplDetail;

import java.util.Date;
import java.util.List;

/**
 * 业务对象指标Service接口
 *
 * @author jjt
 * @date 2024-08-09
 */
public interface IBizObjMetricsService {
    /**
     * 查询业务对象指标
     *
     * @param objMetricsId 业务对象指标主键
     * @return 业务对象指标
     */
    public BizObjMetrics selectBizObjMetricsByObjMetricsId(Long objMetricsId);

    /**
     * 查询业务对象指标列表
     *
     * @param bizObjMetrics 业务对象指标
     * @return 业务对象指标集合
     */
    public List<BizObjMetrics> selectBizObjMetricsList(BizObjMetrics bizObjMetrics);

    /**
     * 新增业务对象指标
     *
     * @param bizObjMetrics 业务对象指标
     * @return 结果
     */
    public int insertBizObjMetrics(BizObjMetrics bizObjMetrics);

    /**
     * 修改业务对象指标
     *
     * @param bizObjMetrics 业务对象指标
     * @return 结果
     */
    public int updateBizObjMetrics(BizObjMetrics bizObjMetrics);

    /**
     * 批量删除业务对象指标
     *
     * @param objMetricsIds 需要删除的业务对象指标主键集合
     * @return 结果
     */
    public int deleteBizObjMetricsByObjMetricsIds(Long[] objMetricsIds);

    /**
     * 删除业务对象指标信息
     *
     * @param objMetricsId 业务对象指标主键
     * @return 结果
     */
    public int deleteBizObjMetricsByObjMetricsId(Long objMetricsId);

    /**
     * 选择指标，除去当前对象已选择的
     *
     * @param objId 对象ID
     * @return
     */
    List<MetricsDef> selectMetricsDefList(Long objId);

    /**
     * 添加指标
     *
     * @param objId      对象ID
     * @param metricsIds 指标IDS
     * @return
     */
    int insertMetricsDetails(Long objId, Long[] metricsIds);

    /**
     * 通过objId查询列表
     *
     * @param objId 对象ID
     * @return 结果
     */
    List<BizObjMetrics> selectBizObjMetricsListByObjId(Long objId);

    /**
     * 通过对象和模板ID删除指标
     *
     * @param objId 对象ID
     * @param tplId 模板ID
     */
    void delete(Long objId, Long tplId);

    /**
     * 通过模板ID批量插入指标
     *
     * @param objId 对象ID
     * @param tplId 模板ID
     */
    void insertBatch(Long objId, Long tplId);

    /**
     * 根据模板指标修改
     *
     * @param metricsTplDetail 模板指标
     */
    void update(MetricsTplDetail metricsTplDetail);

    /**
     * 根据模板指标删除
     *
     * @param detail
     */
    void del(MetricsTplDetail detail);

    /**
     * 根据objId获取pinpoint指标值
     *
     * @param objId 对象ID
     * @param date  数据时间
     */
    void pinpointMetricsValue(Long objId, Date date);

    /**
     * 根据objId获取prometheus指标值
     *
     * @param objId 对象ID
     * @param date  数据时间
     */
    void prometheusMetricsValue(Long objId, Date date);

    /**
     * 使用模拟数据
     *
     * @param objId 对象ID
     * @param date  数据时间
     */
    void imitate(Long objId, Date date);

    /**
     * 更新公式
     *
     * @param metricsList 指标列表
     * @param userName    用户名
     * @return 列表
     */
    String importMetrics(List<BizObjMetrics> metricsList, String userName);

    /**
     * 插入自定义指标
     *
     * @param objId 对象ID
     * @return 结果
     */
    boolean insertMc(Long objId);
}
