package com.jjt.biz.service;

import com.alibaba.fastjson2.JSONObject;
import com.jjt.biz.vo.AgentVO;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * API接口
 *
 * @author jjt
 * @date 2024-08-08
 */
public interface IPinpointService {
    /**
     * 获取所有应用列表
     *
     * @return 结果
     */
    Map<String, String> getApps();

    /**
     * 链路查询
     *
     * @param name appName
     * @param type serviceType
     * @param st   开始时间
     * @param ed   结束时间
     * @return 结果
     */
    JSONObject link(String name, String type, LocalDateTime st, LocalDateTime ed);

    /**
     * tps查询
     *
     * @param agentId appName
     * @param st      开始时间
     * @param ed      结束时间
     * @return 结果
     */
    Float tps(String agentId, LocalDateTime st, LocalDateTime ed);

    /**
     * 打开文件数量查询
     *
     * @param agentId appName
     * @param st      开始时间
     * @param ed      结束时间
     * @return 结果
     */
    int openFile(String agentId, LocalDateTime st, LocalDateTime ed);

    /**
     * jvm内存使用情况
     *
     * @param agentId appName
     * @param st      开始时间
     * @param ed      结束时间
     * @return 结果
     */
    Map<String, Object> jvmMemory(String agentId, LocalDateTime st, LocalDateTime ed);

    /**
     * 清理失效agent
     */
    void cleanAgent();

    /**
     * 删除agent
     *
     * @param applicationName 应用名称
     * @param agentId         应用ID
     */
    void removeAgent(String applicationName, String agentId);

    /**
     * 通过应用名称获取agent列表
     *
     * @param applicationName 应用名称
     * @param st              开始时间
     * @param ed              结束时间
     * @return 结果
     */
    List<AgentVO> agentList(String applicationName, LocalDateTime st, LocalDateTime ed);

    /**
     * 通过应用名称获取agent列表，不带时间
     *
     * @param applicationName 应用名称
     * @return 结果
     */
    List<AgentVO> agentList(String applicationName);
}
