package com.jjt.biz.service.impl;

import java.util.List;
        import com.jjt.common.utils.DateUtils;
import org.springframework.stereotype.Service;
import com.jjt.biz.mapper.BizInspectionMapper;
import com.jjt.biz.domain.BizInspection;
import com.jjt.biz.service.IBizInspectionService;
import javax.annotation.Resource;

/**
 * 业务模型健康度巡检Service业务层处理
 *
 * @author jjt
 * @date 2024-08-26
 */
@Service
public class BizInspectionServiceImpl implements IBizInspectionService {
    @Resource
    private BizInspectionMapper bizInspectionMapper;

    /**
     * 查询业务模型健康度巡检
     *
     * @param inspectionId 业务模型健康度巡检主键
     * @return 业务模型健康度巡检
     */
    @Override
    public BizInspection selectBizInspectionByInspectionId(Long inspectionId) {
        return bizInspectionMapper.selectBizInspectionByInspectionId(inspectionId);
    }

    /**
     * 查询业务模型健康度巡检列表
     *
     * @param bizInspection 业务模型健康度巡检
     * @return 业务模型健康度巡检
     */
    @Override
    public List<BizInspection> selectBizInspectionList(BizInspection bizInspection) {
        return bizInspectionMapper.selectBizInspectionList(bizInspection);
    }

    /**
     * 新增业务模型健康度巡检
     *
     * @param bizInspection 业务模型健康度巡检
     * @return 结果
     */
    @Override
    public int insertBizInspection(BizInspection bizInspection) {
                bizInspection.setCreateTime(DateUtils.getNowDate());
            return bizInspectionMapper.insertBizInspection(bizInspection);
    }

    /**
     * 修改业务模型健康度巡检
     *
     * @param bizInspection 业务模型健康度巡检
     * @return 结果
     */
    @Override
    public int updateBizInspection(BizInspection bizInspection) {
                bizInspection.setUpdateTime(DateUtils.getNowDate());
        return bizInspectionMapper.updateBizInspection(bizInspection);
    }

    /**
     * 批量删除业务模型健康度巡检
     *
     * @param inspectionIds 需要删除的业务模型健康度巡检主键
     * @return 结果
     */
    @Override
    public int deleteBizInspectionByInspectionIds(Long[] inspectionIds) {
        return bizInspectionMapper.deleteBizInspectionByInspectionIds(inspectionIds);
    }

    /**
     * 删除业务模型健康度巡检信息
     *
     * @param inspectionId 业务模型健康度巡检主键
     * @return 结果
     */
    @Override
    public int deleteBizInspectionByInspectionId(Long inspectionId) {
        return bizInspectionMapper.deleteBizInspectionByInspectionId(inspectionId);
    }
}
