package com.jjt.biz.service.impl;

import com.jjt.biz.domain.BizModelDetail;
import com.jjt.biz.mapper.BizModelDetailMapper;
import com.jjt.biz.service.IBizModelDetailService;
import com.jjt.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 业务模型明细Service业务层处理
 *
 * @author jjt
 * @date 2024-08-26
 */
@Service
public class BizModelDetailServiceImpl implements IBizModelDetailService {
    @Resource
    private BizModelDetailMapper bizModelDetailMapper;

    /**
     * 查询业务模型明细
     *
     * @param bizDetailId 业务模型明细主键
     * @return 业务模型明细
     */
    @Override
    public BizModelDetail selectBizModelDetailByBizDetailId(Long bizDetailId) {
        return bizModelDetailMapper.selectBizModelDetailByBizDetailId(bizDetailId);
    }

    /**
     * 查询业务模型明细列表
     *
     * @param bizModelDetail 业务模型明细
     * @return 业务模型明细
     */
    @Override
    public List<BizModelDetail> selectBizModelDetailList(BizModelDetail bizModelDetail) {
        return bizModelDetailMapper.selectBizModelDetailList(bizModelDetail);
    }

    /**
     * 新增业务模型明细
     *
     * @param bizModelDetail 业务模型明细
     * @return 结果
     */
    @Override
    public int insertBizModelDetail(BizModelDetail bizModelDetail) {
        bizModelDetail.setCreateTime(DateUtils.getNowDate());
        return bizModelDetailMapper.insertBizModelDetail(bizModelDetail);
    }

    /**
     * 修改业务模型明细
     *
     * @param bizModelDetail 业务模型明细
     * @return 结果
     */
    @Override
    public int updateBizModelDetail(BizModelDetail bizModelDetail) {
        bizModelDetail.setUpdateTime(DateUtils.getNowDate());
        return bizModelDetailMapper.updateBizModelDetail(bizModelDetail);
    }

    /**
     * 批量删除业务模型明细
     *
     * @param bizDetailIds 需要删除的业务模型明细主键
     * @return 结果
     */
    @Override
    public int deleteBizModelDetailByBizDetailIds(Long[] bizDetailIds) {
        return bizModelDetailMapper.deleteBizModelDetailByBizDetailIds(bizDetailIds);
    }

    /**
     * 删除业务模型明细信息
     *
     * @param bizDetailId 业务模型明细主键
     * @return 结果
     */
    @Override
    public int deleteBizModelDetailByBizDetailId(Long bizDetailId) {
        return bizModelDetailMapper.deleteBizModelDetailByBizDetailId(bizDetailId);
    }

    /**
     * 通过模型ID获取明细
     *
     * @param modelId 模型ID
     * @return 结果
     */
    @Override
    public List<BizModelDetail> selectBizModelDetailList4ModelId(Long modelId) {
        BizModelDetail query = new BizModelDetail();
        query.setModelId(modelId);
        return selectBizModelDetailList(query);
    }
}
