package com.jjt.biz.service.impl;

import java.util.List;
        import com.jjt.common.utils.DateUtils;
import org.springframework.stereotype.Service;
import com.jjt.biz.mapper.BizModelMetricsMapper;
import com.jjt.biz.domain.BizModelMetrics;
import com.jjt.biz.service.IBizModelMetricsService;
import javax.annotation.Resource;

/**
 * 业务模型健康度指标Service业务层处理
 *
 * @author jjt
 * @date 2024-08-26
 */
@Service
public class BizModelMetricsServiceImpl implements IBizModelMetricsService {
    @Resource
    private BizModelMetricsMapper bizModelMetricsMapper;

    /**
     * 查询业务模型健康度指标
     *
     * @param bizMetricsId 业务模型健康度指标主键
     * @return 业务模型健康度指标
     */
    @Override
    public BizModelMetrics selectBizModelMetricsByBizMetricsId(Long bizMetricsId) {
        return bizModelMetricsMapper.selectBizModelMetricsByBizMetricsId(bizMetricsId);
    }

    /**
     * 查询业务模型健康度指标列表
     *
     * @param bizModelMetrics 业务模型健康度指标
     * @return 业务模型健康度指标
     */
    @Override
    public List<BizModelMetrics> selectBizModelMetricsList(BizModelMetrics bizModelMetrics) {
        return bizModelMetricsMapper.selectBizModelMetricsList(bizModelMetrics);
    }

    /**
     * 新增业务模型健康度指标
     *
     * @param bizModelMetrics 业务模型健康度指标
     * @return 结果
     */
    @Override
    public int insertBizModelMetrics(BizModelMetrics bizModelMetrics) {
                bizModelMetrics.setCreateTime(DateUtils.getNowDate());
            return bizModelMetricsMapper.insertBizModelMetrics(bizModelMetrics);
    }

    /**
     * 修改业务模型健康度指标
     *
     * @param bizModelMetrics 业务模型健康度指标
     * @return 结果
     */
    @Override
    public int updateBizModelMetrics(BizModelMetrics bizModelMetrics) {
                bizModelMetrics.setUpdateTime(DateUtils.getNowDate());
        return bizModelMetricsMapper.updateBizModelMetrics(bizModelMetrics);
    }

    /**
     * 批量删除业务模型健康度指标
     *
     * @param bizMetricsIds 需要删除的业务模型健康度指标主键
     * @return 结果
     */
    @Override
    public int deleteBizModelMetricsByBizMetricsIds(Long[] bizMetricsIds) {
        return bizModelMetricsMapper.deleteBizModelMetricsByBizMetricsIds(bizMetricsIds);
    }

    /**
     * 删除业务模型健康度指标信息
     *
     * @param bizMetricsId 业务模型健康度指标主键
     * @return 结果
     */
    @Override
    public int deleteBizModelMetricsByBizMetricsId(Long bizMetricsId) {
        return bizModelMetricsMapper.deleteBizModelMetricsByBizMetricsId(bizMetricsId);
    }
}
