package com.jjt.biz.service.impl;

import com.jjt.biz.domain.BizModel;
import com.jjt.biz.domain.BizModelDetail;
import com.jjt.biz.domain.BizObj;
import com.jjt.biz.domain.BizObjMetrics;
import com.jjt.biz.mapper.BizModelMapper;
import com.jjt.biz.service.IBizModelDetailService;
import com.jjt.biz.service.IBizModelService;
import com.jjt.common.utils.DateUtils;
import com.jjt.hl.domain.HlClass;
import com.jjt.hl.domain.HlObj;
import com.jjt.hl.mapper.HlObjMapper;
import com.jjt.hl.service.IHlClassService;
import com.jjt.hl.service.IHlMetricsService;
import com.jjt.hl.service.IHlObjService;
import org.apache.ibatis.session.ExecutorType;
import org.apache.ibatis.session.SqlSession;
import org.apache.ibatis.session.SqlSessionFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 业务模型Service业务层处理
 *
 * @author jjt
 * @date 2024-08-26
 */
@Service
public class BizModelServiceImpl implements IBizModelService {
    @Resource
    private BizModelMapper bizModelMapper;
    @Resource
    private IBizModelDetailService modelDetailService;
    @Resource
    private IHlClassService hlClassService;
    @Resource
    private IHlObjService hlObjService;
    @Resource
    private IHlMetricsService hlMetricsService;
    @Resource
    private SqlSessionFactory factory;

    /**
     * 查询业务模型
     *
     * @param modelId 业务模型主键
     * @return 业务模型
     */
    @Override
    public BizModel selectBizModelByModelId(Long modelId) {
        return bizModelMapper.selectBizModelByModelId(modelId);
    }

    /**
     * 查询业务模型列表
     *
     * @param bizModel 业务模型
     * @return 业务模型
     */
    @Override
    public List<BizModel> selectBizModelList(BizModel bizModel) {
        return bizModelMapper.selectBizModelList(bizModel);
    }

    /**
     * 新增业务模型
     *
     * @param bizModel 业务模型
     * @return 结果
     */
    @Override
    public int insertBizModel(BizModel bizModel) {
        bizModel.setCreateTime(DateUtils.getNowDate());
        return bizModelMapper.insertBizModel(bizModel);
    }

    /**
     * 修改业务模型
     *
     * @param bizModel 业务模型
     * @return 结果
     */
    @Override
    public int updateBizModel(BizModel bizModel) {
        bizModel.setUpdateTime(DateUtils.getNowDate());
        return bizModelMapper.updateBizModel(bizModel);
    }

    /**
     * 批量删除业务模型
     *
     * @param modelIds 需要删除的业务模型主键
     * @return 结果
     */
    @Override
    public int deleteBizModelByModelIds(Long[] modelIds) {
        return bizModelMapper.deleteBizModelByModelIds(modelIds);
    }

    /**
     * 删除业务模型信息
     *
     * @param modelId 业务模型主键
     * @return 结果
     */
    @Override
    public int deleteBizModelByModelId(Long modelId) {
        return bizModelMapper.deleteBizModelByModelId(modelId);
    }

    /**
     * 选择业务对象
     *
     * @param modelId 模型ID
     * @return 结果
     */
    @Override
    public List<BizObj> selectObjList(Long modelId) {
        return bizModelMapper.selectObjList(modelId);
    }

    /**
     * 添加业务对象
     *
     * @param modelId 模型ID
     * @param objIds  业务对象列表
     * @return 结果
     */
    @Override
    public int insertObj(Long modelId, Long[] objIds) {
        for (Long objId : objIds) {
            BizModelDetail detail = new BizModelDetail();
            detail.setModelId(modelId);
            detail.setObjId(objId);
            modelDetailService.insertBizModelDetail(detail);
        }
        impClass(modelId);
        return 0;
    }

    /**
     * 根据模型ID查询指标
     *
     * @param modelId 模型ID
     * @return 结果
     */
    @Override
    public List<BizObjMetrics> selectBizModelMetricsList(Long modelId) {
        return bizModelMapper.selectBizModelMetricsList(modelId);
    }

    /**
     * 通过模型ID获取 分类列表
     *
     * @param modelId 模型ID
     * @return 结果
     */
    @Override
    public List<HlClass> selectHlClassList4modelId(Long modelId) {
        List<HlClass> list = hlClassService.selectHlClassList4modelId(modelId);
        //如果还未配置，则初始化
        if (list.size() == 0) {
            List<BizModelDetail> details = modelDetailService.selectBizModelDetailList4ModelId(modelId);
            Map<String, List<BizModelDetail>> map = details.stream().collect(Collectors.groupingBy(d -> d.getBizObj().getObjType()));
            List<HlObj> hlObjList = new ArrayList<>();
            int size = map.size();
            BigDecimal total = BigDecimal.valueOf(100);
            int avg = total.divide(BigDecimal.valueOf(size), 0, RoundingMode.HALF_DOWN).intValue();
            int one = avg * size == total.intValue() ? avg : total.intValue() - avg * (size - 1);
            boolean flag = true;
            for (String s : map.keySet()) {
                HlClass hlClass = new HlClass();
                hlClass.setObjType(s);
                hlClass.setModelId(modelId);
                hlClass.setScoreType("1");
                if (flag) {
                    hlClass.setHlScore(BigDecimal.valueOf(one));
                    flag = false;
                } else {
                    hlClass.setHlScore(BigDecimal.valueOf(avg));
                }
                hlClassService.insertHlClass(hlClass);

                List<BizModelDetail> detailList = map.get(s);
                detailList.forEach(d -> {
                    HlObj hlObj = new HlObj();
                    hlObj.setHlClassId(hlClass.getHlClassId());
                    hlObj.setObjId(d.getObjId());
                    hlObjList.add(hlObj);
                });
            }

            try (SqlSession sqlSession = factory.openSession(ExecutorType.BATCH, false)) {
                HlObjMapper mapper = sqlSession.getMapper(HlObjMapper.class);
                hlObjList.forEach(mapper::insertHlObj);
                sqlSession.commit();
            }
            list = hlClassService.selectHlClassList4modelId(modelId);
        }

        return list;
    }

    /**
     * 导入分类
     *
     * @param modelId 模型ID
     */
    @Override
    public void impClass(Long modelId) {
        List<BizModelDetail> details = modelDetailService.selectBizModelDetailList4ModelId(modelId);
        Map<String, List<BizModelDetail>> map = details.stream().collect(Collectors.groupingBy(d -> d.getBizObj().getObjType()));
        List<HlClass> list = hlClassService.selectHlClassList4modelId(modelId);
        List<String> typeList = list.stream().map(HlClass::getObjType).collect(Collectors.toList());
        List<HlObj> hlObjList = new ArrayList<>();
        for (String t : map.keySet()) {
            if (!typeList.contains(t)) {
                //添加
                HlClass hlClass = new HlClass();
                hlClass.setObjType(t);
                hlClass.setModelId(modelId);
                hlClass.setScoreType("1");
                hlClass.setHlScore(BigDecimal.ZERO);
                hlClassService.insertHlClass(hlClass);
                List<BizModelDetail> detailList = map.get(t);
                detailList.forEach(d -> {
                    HlObj hlObj = new HlObj();
                    hlObj.setHlClassId(hlClass.getHlClassId());
                    hlObj.setObjId(d.getObjId());
                    hlObjList.add(hlObj);
                });
            }
        }
        try (SqlSession sqlSession = factory.openSession(ExecutorType.BATCH, false)) {
            HlObjMapper mapper = sqlSession.getMapper(HlObjMapper.class);
            hlObjList.forEach(mapper::insertHlObj);
            sqlSession.commit();
        }
    }

    /**
     * 清理分类
     *
     * @param modelId 模型ID
     */
    @Override
    public void cleanClass(Long modelId) {
        List<BizModelDetail> details = modelDetailService.selectBizModelDetailList4ModelId(modelId);
        List<Long> objList = details.stream().map(BizModelDetail::getObjId).collect(Collectors.toList());
        List<HlClass> list = hlClassService.selectHlClassList4modelId(modelId);
        list.forEach(hc -> {
            List<HlObj> objs = hlObjService.selectHlObjListByClassId(hc.getHlClassId());
            int delTimes = 0;
            for (HlObj obj : objs) {
                if (!objList.contains(obj.getHlObjId())) {
                    hlObjService.deleteHlObjByHlObjId(obj.getHlObjId());
                    delTimes++;
                }
            }
            if (delTimes == objs.size()) {
                //如果该类型对象已经被全部删除。
                //那么需要删除当前类型，和该类型下的指标
                hlMetricsService.deleteHlMetricsByClassId(hc.getHlClassId());
                hlClassService.deleteHlClassByHlClassId(hc.getHlClassId());
            }
        });
//        List<String> typeList = list.stream().map(HlClass::getObjType).collect(Collectors.toList());
//        List<HlObj> hlObjList = new ArrayList<>();
//        for (String t : map.keySet()) {
//            if (!typeList.contains(t)) {
//                //添加
//                HlClass hlClass = new HlClass();
//                hlClass.setObjType(t);
//                hlClass.setModelId(modelId);
//                hlClass.setScoreType("1");
//                hlClass.setHlScore(BigDecimal.ZERO);
//                hlClassService.insertHlClass(hlClass);
//                List<BizModelDetail> detailList = map.get(t);
//                detailList.forEach(d -> {
//                    HlObj hlObj = new HlObj();
//                    hlObj.setHlClassId(hlClass.getHlClassId());
//                    hlObj.setObjId(d.getObjId());
//                    hlObjList.add(hlObj);
//                });
//            }
//        }
//        try (SqlSession sqlSession = factory.openSession(ExecutorType.BATCH, false)) {
//            HlObjMapper mapper = sqlSession.getMapper(HlObjMapper.class);
//            hlObjList.forEach(mapper::insertHlObj);
//            sqlSession.commit();
//        }
    }
}
