package com.jjt.biz.service.impl;

import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.jjt.biz.domain.*;
import com.jjt.biz.mapper.AlarmRecordMapper;
import com.jjt.biz.mapper.BizObjMetricsDataMapper;
import com.jjt.biz.mapper.BizObjMetricsMapper;
import com.jjt.biz.service.*;
import com.jjt.biz.vo.AgentVO;
import com.jjt.common.constant.CacheConstants;
import com.jjt.common.core.redis.RedisCache;
import com.jjt.common.exception.ServiceException;
import com.jjt.common.utils.DateUtils;
import com.jjt.common.utils.StringUtils;
import com.jjt.common.utils.bean.BeanUtils;
import com.jjt.hl.domain.HlEvent;
import com.jjt.hl.mapper.HlEventMapper;
import com.jjt.hl.service.IHlEventService;
import com.jjt.system.service.ISysConfigService;
import lombok.extern.slf4j.Slf4j;
import org.apache.ibatis.session.ExecutorType;
import org.apache.ibatis.session.SqlSession;
import org.apache.ibatis.session.SqlSessionFactory;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.time.LocalDateTime;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 业务对象指标Service业务层处理
 *
 * @author jjt
 * @date 2024-08-09
 */
@Service
@Slf4j
public class BizObjMetricsServiceImpl implements IBizObjMetricsService {
    @Resource
    private BizObjMetricsMapper bizObjMetricsMapper;
    @Resource
    private IMetricsTplDetailService detailService;
    @Resource
    private IBizObjPpService ppService;
    @Resource
    private IBizObjService objService;
    @Resource
    private IBizObjPpAgentService agentService;
    @Resource
    private IPinpointService pinpointService;
    @Resource
    private IPrometheusService prometheusService;
    @Resource
    private IBizObjTplService objTplService;
    @Resource
    private SqlSessionFactory factory;
    @Resource
    private IAlarmRecordService alarmRecordService;
    @Resource
    private IBizObjMetricsDataService metricsDataService;
    @Resource
    private IHlEventService eventService;
    @Resource
    private ISysConfigService configService;
    @Resource
    private IBizObjMcService mcService;
    @Resource
    private JdbcTemplate jdbcTemplate;
    @Resource
    private RedisCache redisCache;

    /**
     * 查询业务对象指标
     *
     * @param objMetricsId 业务对象指标主键
     * @return 业务对象指标
     */
    @Override
    public BizObjMetrics selectBizObjMetricsByObjMetricsId(Long objMetricsId) {
        return bizObjMetricsMapper.selectBizObjMetricsByObjMetricsId(objMetricsId);
    }

    /**
     * 查询业务对象指标列表
     *
     * @param bizObjMetrics 业务对象指标
     * @return 业务对象指标
     */
    @Override
    public List<BizObjMetrics> selectBizObjMetricsList(BizObjMetrics bizObjMetrics) {
        List<BizObjMetrics> list = bizObjMetricsMapper.selectBizObjMetricsList(bizObjMetrics);
        list.forEach(om -> {
            String redisKey = CacheConstants.METRICS_D_VALUE + om.getObjMetricsId();
            String dValue = redisCache.getCacheObject(redisKey);
            if (StringUtils.isNotEmpty(dValue)) {
                om.setDValue(new BigDecimal(dValue));
            } else {
                om.setDValue(null);
            }
        });
        return list;
    }

    /**
     * 新增业务对象指标
     *
     * @param bizObjMetrics 业务对象指标
     * @return 结果
     */
    @Override
    public int insertBizObjMetrics(BizObjMetrics bizObjMetrics) {
        bizObjMetrics.setCreateTime(DateUtils.getNowDate());
        return bizObjMetricsMapper.insertBizObjMetrics(bizObjMetrics);
    }

    /**
     * 修改业务对象指标
     *
     * @param bizObjMetrics 业务对象指标
     * @return 结果
     */
    @Override
    public int updateBizObjMetrics(BizObjMetrics bizObjMetrics) {
        //插入数据记录表
        bizObjMetrics.setUpdateTime(DateUtils.getNowDate());
        return bizObjMetricsMapper.updateBizObjMetrics(bizObjMetrics);
    }

    /**
     * 批量删除业务对象指标
     *
     * @param objMetricsIds 需要删除的业务对象指标主键
     * @return 结果
     */
    @Override
    public int deleteBizObjMetricsByObjMetricsIds(Long[] objMetricsIds) {
        return bizObjMetricsMapper.deleteBizObjMetricsByObjMetricsIds(objMetricsIds);
    }

    /**
     * 删除业务对象指标信息
     *
     * @param objMetricsId 业务对象指标主键
     * @return 结果
     */
    @Override
    public int deleteBizObjMetricsByObjMetricsId(Long objMetricsId) {
        return bizObjMetricsMapper.deleteBizObjMetricsByObjMetricsId(objMetricsId);
    }

    /**
     * 选择指标，除去当前对象已选择的
     *
     * @param objId 对象ID
     * @return 结果
     */
    @Override
    public List<MetricsDef> selectMetricsDefList(Long objId) {
        return bizObjMetricsMapper.selectMetricsDefList(objId);
    }

    /**
     * 添加指标
     *
     * @param objId      对象ID
     * @param metricsIds 指标IDS
     * @return 结果
     */
    @Override
    public int insertMetricsDetails(Long objId, Long[] metricsIds) {
        BizObj obj = objService.selectBizObjByObjId(objId);
        String suffix = "/" + obj.getObjAddr() + ":" + obj.getObjPort();
        return bizObjMetricsMapper.insertMetricsDetails(objId, suffix, metricsIds);
    }

    /**
     * 通过objId查询列表
     *
     * @param objId 对象ID
     * @return 结果
     */
    @Override
    public List<BizObjMetrics> selectBizObjMetricsListByObjId(Long objId) {
        BizObjMetrics obj = new BizObjMetrics();
        obj.setObjId(objId);
        return selectBizObjMetricsList(obj);
    }

    /**
     * 通过对象和模板ID删除指标
     *
     * @param objId 对象ID
     * @param tplId 模板ID
     */
    @Override
    public void delete(Long objId, Long tplId) {
        QueryWrapper<BizObjMetrics> wrapper = new QueryWrapper<>();
        wrapper.eq("obj_id", objId);
        wrapper.eq("tpl_id", tplId);
        bizObjMetricsMapper.delete(wrapper);
    }

    /**
     * 通过模板ID批量插入指标
     * * @param objId 对象ID
     *
     * @param tplId 模板ID
     */
    @Override
    public void insertBatch(Long objId, Long tplId) {
        BizObj obj = objService.selectBizObjByObjId(objId);
        MetricsTplDetail query = new MetricsTplDetail();
        query.setTplId(tplId);
        List<MetricsTplDetail> list = detailService.selectMetricsTplDetailList(query);
        List<BizObjMetrics> objMetrics = new ArrayList<>();
        list.forEach(d -> {
            if ("1".equals(d.getMetricsDef().getMetricsType()) && !d.getMetricsDef().getMetricsCode().startsWith("pp.jvm.")) {
                //如果是pinpoint,并且不是jvm参数
                // 1.获取对象pinpoint组成
                List<BizObjPp> pps = ppService.selectBizObjPpListByObjId(objId);

                for (BizObjPp pp : pps) {
                    BizObjMetrics ms = new BizObjMetrics();
                    ms.setObjId(objId);
                    ms.setTplId(tplId);
                    ms.setMetricsId(d.getMetricsId());
                    ms.setMetricsName(pp.getPpType() + "/" + d.getMetricsDef().getMetricsName());
                    ms.setMetricsCode(d.getMetricsDef().getMetricsCode());
                    ms.setDataExp(d.getMetricsDef().getMetricsCode());
                    ms.setAlarmLow(d.getAlarmLow());
                    ms.setAlarmMid(d.getAlarmMid());
                    ms.setAlarmHigh(d.getAlarmHigh());
                    ms.setEvent(d.getEvent());

                    if ("REDIS".equals(pp.getPpType())) {
                        //redis需要将1s换成100ms 3s换成300ms 5s换成500ms
                        if (d.getMetricsCode().endsWith("1s")) {
                            ms.setMetricsName(ms.getMetricsName().replace("1s", "100ms"));
                            ms.setMetricsCode(ms.getMetricsCode().replace("1s", "100ms"));
                        }
                        if (d.getMetricsCode().endsWith("3s")) {
                            ms.setMetricsName(ms.getMetricsName().replace("3s", "300ms"));
                            ms.setMetricsCode(ms.getMetricsCode().replace("3s", "300ms"));
                        }
                        if (d.getMetricsCode().endsWith("5s")) {
                            ms.setMetricsName(ms.getMetricsName().replace("5s", "500ms"));
                            ms.setMetricsCode(ms.getMetricsCode().replace("5s", "500ms"));
                        }
                    }
                    objMetrics.add(ms);
                }
            } else {
                BizObjMetrics ms = new BizObjMetrics();
                ms.setObjId(objId);
                ms.setTplId(tplId);
                ms.setMetricsId(d.getMetricsId());
                ms.setMetricsName(d.getMetricsDef().getMetricsName());
                ms.setMetricsCode(d.getMetricsCode());
                ms.setAlarmLow(d.getAlarmLow());
                ms.setAlarmMid(d.getAlarmMid());
                ms.setAlarmHigh(d.getAlarmHigh());
                ms.setEvent(d.getEvent());
                if ("1".equals(d.getMetricsDef().getMetricsType())) {
                    ms.setDataExp(d.getMetricsCode());
                } else {
                    //如果是普罗米修斯，则需要处理公式
                    ms.setDataExp(d.getDataExp().replace("${instance}", obj.getObjAddr()));
                    if ("3".equals(d.getMetricsDef().getMetricsType())) {
                        //如果是容器指标，则需要替换为=~ "xxxx.*" 模式
                        ms.setDataExp(d.getDataExp().replace("${instance}", obj.getObjAddr() + ".*"));
                    }
                    if ("Y".equals(d.getFindFlag())) {
                        //如果是自动发现
                        cn.hutool.json.JSONObject jsonObject = prometheusService.find(d.getFindRule());
                        cn.hutool.json.JSONArray metric = jsonObject.getByPath("data.result", cn.hutool.json.JSONArray.class);
                        for (int i = 0; i < metric.size(); i++) {
                            String v = metric.getJSONObject(i).getByPath("metric." + d.getFindKey(), String.class);
                            String name = d.getMetricsDef().getMetricsName() + "{" + d.getFindKey() + "=" + v + "}";
                            String dataExp = ms.getDataExp().replace("${key}", v);
                            BizObjMetrics newMs = new BizObjMetrics();
                            BeanUtils.copyProperties(ms, newMs);
                            newMs.setObjMetricsId(null);
                            newMs.setDataExp(dataExp);
                            newMs.setMetricsName(name);
                            objMetrics.add(newMs);
                        }
                    } else {
                        objMetrics.add(ms);
                    }
                }


            }

        });
        try (SqlSession sqlSession = factory.openSession(ExecutorType.BATCH, false)) {
            BizObjMetricsMapper mapper = sqlSession.getMapper(BizObjMetricsMapper.class);
            objMetrics.forEach(mapper::insertBizObjMetrics);
            sqlSession.commit();
        }
    }

    /**
     * 根据模板指标修改
     *
     * @param detail 模板指标
     */
    @Override
    public void update(MetricsTplDetail detail) {
        BizObjMetrics om = new BizObjMetrics();
        om.setMetricsId(detail.getMetricsId());
        om.setTplId(detail.getTplId());

        List<BizObjMetrics> list = selectBizObjMetricsList(om);
//        if (list.size() > 0) {
        list.forEach(obj -> {
            //如果有则更新，没有则插入
            obj.setAlarmMid(detail.getAlarmMid());
            obj.setAlarmLow(detail.getAlarmLow());
            obj.setAlarmHigh(detail.getAlarmHigh());
            obj.setEvent(detail.getEvent());
            bizObjMetricsMapper.updateBizObjMetrics(obj);
        });
//        } else {
//            om.setAlarmLow(detail.getAlarmLow());
//            om.setAlarmMid(detail.getAlarmMid());
//            om.setAlarmHigh(detail.getAlarmHigh());
//            om.setEvent(detail.getEvent());
//            insertBizObjMetrics(om);
//        }

    }

    /**
     * 根据模板指标删除
     *
     * @param detail 模板指标
     */
    @Override
    public void del(MetricsTplDetail detail) {
        QueryWrapper<BizObjMetrics> wrapper = new QueryWrapper<>();
        wrapper.eq("metrics_id", detail.getMetricsId());
        wrapper.eq("tpl_id", detail.getTplId());
        bizObjMetricsMapper.delete(wrapper);
    }

    /**
     * 根据objId获取指标值
     *
     * @param objId 对象ID
     * @param date  数据时间
     */
    @Override
    @Async("threadPoolTaskExecutor")
    public void pinpointMetricsValue(Long objId, Date date) {
        BizObj bizObj = objService.selectBizObjByObjId(objId);

        if ("1".equals(bizObj.getObjType())) {
            // 获取应用程序的code
            String appName = bizObj.getObjAddr();

            long time = Long.parseLong(configService.selectConfigByKey("pp.api.time"));
            LocalDateTime endTime = LocalDateTime.now();

            LocalDateTime startTime = endTime.minusMinutes(time);
            Map<String, String> appMap = pinpointService.getApps();
            String appType = appMap.get(appName);

            List<AgentVO> agentList = pinpointService.agentList(appName, startTime, endTime);
            // 获取监控数据
            agentList.forEach(vo -> {
                if (vo.getCode() == 100) {
                    Float tps = pinpointService.tps(vo.getAgentId(), startTime, endTime);
                    int openFiles = pinpointService.openFile(vo.getAgentId(), startTime, endTime);
                    Map<String, Object> jvmInfo = pinpointService.jvmMemory(vo.getAgentId(), startTime, endTime);
                    float heapUsage = (float) jvmInfo.get("usage");
                    int gcCount = (int) jvmInfo.get("gc");

                    vo.setTps(tps);
                    vo.setOpenFiles(openFiles);
                    vo.setHeapUsage(heapUsage);
                    vo.setGcCount(gcCount);
                }
            });

            JSONObject linkData = pinpointService.link(appName, appType, startTime, endTime);
            JSONArray nodeDataArray = linkData.getJSONObject("applicationMapData").getJSONArray("nodeDataArray");

            List<PinpointVO> pinpointVOList = new ArrayList<>();
            for (int i = 0; i < nodeDataArray.size(); i++) {
                JSONObject obj = nodeDataArray.getJSONObject(i);
                PinpointVO vo = new PinpointVO(obj);

                if ("USER".equals(vo.getCategory())) {
                    bizObj.setAccessTimes(vo.getTot());
                    objService.updateBizObj(bizObj);
                } else {
                    pinpointVOList.add(vo);
                }
            }

            // 1.更新 BIZ_OBJ_PP 表
            updateBizObjPpTable(objId, pinpointVOList, agentList);

            // 2.更新业务对象指标表
            updateBizObjMetrics(objId, agentList, pinpointVOList, date);
//            updateBizObjMetrics(objId, tps, openFiles, heapUsage, gcCount, pinpointVOList, date);
        }
    }


    /**
     * 根据objId获取prometheus指标值
     *
     * @param objId 对象ID
     * @param date  时间
     */
    @Override
    @Async("threadPoolTaskExecutor")
    public void prometheusMetricsValue(Long objId, Date date) {
        List<BizObjMetrics> mList = getAllMetricsForObjIdList(objId);
        List<BizObjMetrics> metricsToUpdate = new ArrayList<>();
        List<BizObjMetricsData> dataList = new ArrayList<>();
        List<AlarmRecord> addRList = new ArrayList<>();
        List<AlarmRecord> updateRList = new ArrayList<>();
        List<HlEvent> addEList = new ArrayList<>();
        List<HlEvent> updateEList = new ArrayList<>();
        //查询当前对象所有正在告警列表
        Map<Long, AlarmRecord> recordMap = alarmRecordService.selectAlarmRecordListCurr(objId);
        //查询当前对象未结束事件列表
        Map<Long, HlEvent> eventMap = eventService.selectHlEventListCurr(objId);
        mList.stream().filter(om -> !"1".equals(om.getMetricsDef().getMetricsType())).forEach(om -> {
            if (StringUtils.isNotEmpty(om.getDataExp())) {
                //非pinpoint
                Float value = prometheusService.query(om.getDataExp());
                if (value != null) {
                    om.setDValue(BigDecimal.valueOf(value));
                    BizObjMetricsData data = new BizObjMetricsData();
                    data.setObjMetricsId(om.getObjMetricsId());
                    data.setdValue(om.getDValue());
                    data.setCreateTime(date);
                    dataList.add(data);
                    metricsToUpdate.add(om);
                    //处理告警
                    Map<String, AlarmRecord> aMap = alarmRecordService.process(om, recordMap, date);
                    if (aMap.get("add") != null) {
                        addRList.add(aMap.get("add"));
                    }
                    if (aMap.get("update") != null) {
                        updateRList.add(aMap.get("update"));
                    }

                    //处理事件
                    Map<String, HlEvent> eMap = eventService.process(om, eventMap, date);
                    if (eMap.get("add") != null) {
                        addEList.add(eMap.get("add"));
                    }
                    if (eMap.get("update") != null) {
                        updateEList.add(eMap.get("update"));
                    }
                }
            }
        });
        batchUpdate(null, dataList, addRList, updateRList, addEList, updateEList);
//        Map<Long, BigDecimal> updateMap = new HashMap<>();
        metricsToUpdate.forEach(mo -> {
            String redisKey = CacheConstants.METRICS_D_VALUE + mo.getObjMetricsId();
            redisCache.setCacheObject(redisKey, mo.getDValue().toString());
//            updateMap.put(up.getObjMetricsId(), up.getDValue());
        });
//        if (updateMap.size() > 0) {
//            // 使用Redis存储最新指标数据，避免数据库死锁问题
//            // 批量更新Redis中的指标值
//            updateMap.forEach((metricsId, value) -> {
////                Map<String, String> metricData = new HashMap<>();
////                metricData.put("dValue", value.toString());
////                metricData.put("updateTime", DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS, updateTime));
//                // 存储到Redis，设置过期时间（例如：1小时）
//                // 注意：这里需要注入RedisTemplate或相关Redis操作类
////                redisTemplate.opsForHash().putAll(redisKey, metricData);
//                // redisTemplate.expire(redisKey, 3600, TimeUnit.SECONDS);
//            });

        // 同时更新数据库（可选，根据业务需求决定是否保留）
//            jdbcTemplate.batchUpdate("update biz_obj_metrics set d_value = ?, UPDATE_TIME = ? where obj_metrics_id = ?",
//                    updateMap.entrySet().stream()
//                            .map(entry -> new Object[]{entry.getValue(), updateTime, entry.getKey()})
//                            .collect(Collectors.toList()));
//    }

    }

    /**
     * 使用模拟数据
     *
     * @param objId 对象ID
     * @param date  数据时间
     */
    @Override
//    @Async("threadPoolTaskExecutor")
    public void imitate(Long objId, Date date) {
        List<BizObjMetrics> mList = getAllMetricsForObjIdList(objId);
        List<BizObjMetrics> metricsToUpdate = new ArrayList<>();
        List<BizObjMetricsData> dataList = new ArrayList<>();
        List<AlarmRecord> addRList = new ArrayList<>();
        List<AlarmRecord> updateRList = new ArrayList<>();
        List<HlEvent> addEList = new ArrayList<>();
        List<HlEvent> updateEList = new ArrayList<>();
        //查询当前对象所有正在告警列表
        Map<Long, AlarmRecord> recordMap = alarmRecordService.selectAlarmRecordListCurr(objId);
        //查询当前对象未结束事件列表
        Map<Long, HlEvent> eventMap = eventService.selectHlEventListCurr(objId);

        Random random = new Random();
        mList.stream().forEach(om -> {
            double oldV = 100d;
            if (om.getDValue() != null) {
                oldV = om.getDValue().floatValue();
            }
            double modifier = oldV * 0.1;
            double randomValue = random.nextDouble() * 2 - 1; // 生成-1到1之间的随机数

            double value = oldV + modifier * randomValue;
            BigDecimal dv = BigDecimal.valueOf(value).setScale(2, RoundingMode.HALF_UP);
//            int xxx = (int) (om.getObjMetricsId() % 70);
//            float value = (float) random.nextInt(100 - xxx) + xxx;


            if (dv.doubleValue() < 10) {
                dv = dv.add(BigDecimal.valueOf(10));
            }

            if ("1".equals(om.getMetricsDef().getMetricsType())) {
                dv = dv.setScale(0, RoundingMode.HALF_UP);
            }
            if (om.getMetricsCode().endsWith("pp.tot")) {
                if (dv.doubleValue() < 50) {
                    dv = dv.add(BigDecimal.valueOf(50));
                }
            }

            if (om.getMetricsCode().endsWith("pp.error")) {
                if (dv.doubleValue() > 50) {
                    dv = dv.subtract(BigDecimal.valueOf(50));
                }
            }
            om.setDValue(dv);

            BizObjMetricsData data = new BizObjMetricsData();
            data.setObjMetricsId(om.getObjMetricsId());
            data.setdValue(om.getDValue());
            data.setCreateTime(date);
//            metricsDataService.insertBizObjMetricsData(data);
            dataList.add(data);
            metricsToUpdate.add(om);
            //处理告警
            Map<String, AlarmRecord> aMap = alarmRecordService.process(om, recordMap, date);
            if (aMap.get("add") != null) {
                addRList.add(aMap.get("add"));
            }
            if (aMap.get("update") != null) {
                updateRList.add(aMap.get("update"));
            }

            //处理事件
            Map<String, HlEvent> eMap = eventService.process(om, eventMap, date);
            if (eMap.get("add") != null) {
                addEList.add(eMap.get("add"));
            }
            if (eMap.get("update") != null) {
                updateEList.add(eMap.get("update"));
            }
        });
        batchUpdate(null, dataList, addRList, updateRList, addEList, updateEList);
    }

    /**
     * 更新公式
     *
     * @param metricsList 指标列表
     * @param userName    用户名
     * @return 列表
     */
    @Override
    public String importMetrics(List<BizObjMetrics> metricsList, String userName) {
        if (StringUtils.isNull(metricsList) || metricsList.size() == 0) {
            throw new ServiceException("导入指标不能为空！");
        }
        int successNum = 0;
        int failureNum = 0;
        StringBuilder successMsg = new StringBuilder();
        StringBuilder failureMsg = new StringBuilder();
        for (BizObjMetrics om : metricsList) {
            String metricsName = om.getMetricsName();
            try {
                om.setUpdateBy(userName);
                updateBizObjMetrics(om);
                successNum++;
                successMsg.append("<br/>" + successNum + "、 " + om.getMetricsName() + " 更新成功");
            } catch (Exception e) {
                failureNum++;
                String msg = "<br/>" + failureNum + "、 " + om.getMetricsName() + " 导入失败：";
                failureMsg.append(msg + e.getMessage());
                log.error(msg, e);
            }
        }
        if (failureNum > 0) {
            failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据格式不正确，错误如下：");
            throw new ServiceException(failureMsg.toString());
        } else {
            successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
        }
        return successMsg.toString();
    }

    /**
     * 插入自定义指标
     *
     * @param objId 对象ID
     */
    @Override
    public boolean insertMc(Long objId) {
        BizObj obj = objService.selectBizObjByObjId(objId);
        BizObjMc query = new BizObjMc();
        query.setObjId(objId);
        List<BizObjMc> list = mcService.selectBizObjMcList(query);
        List<BizObjMetrics> objMetrics = new ArrayList<>();
        for (BizObjMc d : list) {
            BizObjMetrics ms = new BizObjMetrics();
            ms.setObjId(objId);
            ms.setTplId(-1L);
            ms.setMetricsId(d.getMetricsId());

            List<BizObjMetrics> queryList = bizObjMetricsMapper.selectBizObjMetricsList(ms);
            if (queryList.size() > 0) {
                continue;
            }
            ms.setMetricsName(d.getMetricsName());
            ms.setMetricsCode(d.getMetricsCode());
            ms.setAlarmLow(d.getAlarmLow());
            ms.setAlarmMid(d.getAlarmMid());
            ms.setAlarmHigh(d.getAlarmHigh());
            ms.setEvent(d.getEvent());
            if (StringUtils.isEmpty(d.getDataExp())) {
                return false;
            }
            //如果是普罗米修斯，则需要处理公式
            ms.setDataExp(d.getDataExp().replace("${instance}", obj.getObjAddr()));
            if ("Y".equals(d.getFindFlag())) {
                //如果是自动发现
                cn.hutool.json.JSONObject jsonObject = prometheusService.find(d.getFindRule());
                cn.hutool.json.JSONArray metric = jsonObject.getByPath("data.result", cn.hutool.json.JSONArray.class);
                for (int i = 0; i < metric.size(); i++) {
                    String v = metric.getJSONObject(i).getByPath("metric." + d.getFindKey(), String.class);
                    String name = d.getMetricsName() + "{" + d.getFindKey() + "=" + v + "}";
                    String dataExp = ms.getDataExp().replace("${key}", v);
                    BizObjMetrics newMs = new BizObjMetrics();
                    BeanUtils.copyProperties(ms, newMs);
                    newMs.setObjMetricsId(null);
                    newMs.setDataExp(dataExp);
                    newMs.setMetricsName(name);
                    objMetrics.add(newMs);
                }
            } else {
                objMetrics.add(ms);
            }
        }
        try (SqlSession sqlSession = factory.openSession(ExecutorType.BATCH, false)) {
            BizObjMetricsMapper mapper = sqlSession.getMapper(BizObjMetricsMapper.class);
            objMetrics.forEach(mapper::insertBizObjMetrics);
            sqlSession.commit();
        }
        return true;
    }

    /**
     * 更新BIZ_OBJ_PP
     * 更新agent
     *
     * @param objId          对象ID
     * @param pinpointVOList PP组成
     * @param agentList      agentId列表
     */
    private void updateBizObjPpTable(Long objId, List<PinpointVO> pinpointVOList, List<AgentVO> agentList) {
        List<BizObjPpAgent> existingAgentList = agentService.selectBizObjPpAgentListByObjId(objId);
        Set<String> ags = agentList.stream()
                .map(AgentVO::getAgentId)
                .collect(Collectors.toSet());
        //删除表中存在，agentList中不存在的记录
        existingAgentList.forEach(ag -> {
            if (!ags.contains(ag.getAgentId())) {
                agentService.delete(ag);
            }
        });


        Set<String> existingAgents = existingAgentList.stream()
                .map(BizObjPpAgent::getAgentId)
                .collect(Collectors.toSet());

        List<BizObjPp> existingPpList = ppService.selectBizObjPpListByObjId(objId);
        Set<String> existingNames = existingPpList.stream()
                .map(BizObjPp::getPpName)
                .collect(Collectors.toSet());

        List<BizObjPpAgent> agents = new ArrayList<>();
        List<BizObjPp> pps = new ArrayList<>();
        agentList.forEach(vo -> {
            //如果没有，则添加
            if (!existingAgents.contains(vo.getAgentId()) && vo.getCode() == 100) {
                BizObjPpAgent agent = new BizObjPpAgent();
                agent.setAgentId(vo.getAgentId());
                agent.setObjId(objId);
                agentService.insertBizObjPpAgent(agent);
                agents.add(agent);
            }
        });


        pinpointVOList.stream()
                .filter(vo -> !existingNames.contains(vo.getApplicationName()))
                .forEach(vo -> {
                    BizObjPp pp = new BizObjPp();
                    pp.setObjId(objId);
                    pp.setPpKey(vo.getKey());
                    pp.setPpName(vo.getApplicationName());
                    pp.setPpType(vo.getCategory());
                    ppService.insertBizObjPp(pp);
                    pps.add(pp);
                });
        updateBizObjMetricsFromTemplate(objId, agents, pps);
    }


    /**
     * 根据模板更新业务对象指标表
     *
     * @param objId  对象ID
     * @param agents agent对象
     * @param pps    pp对象
     */
    private void updateBizObjMetricsFromTemplate(Long objId, List<BizObjPpAgent> agents, List<BizObjPp> pps) {
        List<BizObjTpl> templateList = objTplService.selectTplList4objId(objId);
        templateList.forEach(template -> insertOrUpdateMetricsFromTemplate(objId, template.getTplId(), agents, pps));
    }

    /**
     * 更新模板中的pinpoint指标到业务对象指标
     *
     * @param objId  对象ID
     * @param tplId  模板ID
     * @param agents agent对象
     * @param pps    pp对象
     */
    private void insertOrUpdateMetricsFromTemplate(Long objId, Long tplId, List<BizObjPpAgent> agents, List<BizObjPp> pps) {
        MetricsTplDetail query = new MetricsTplDetail();
        query.setTplId(tplId);
        List<MetricsTplDetail> list = detailService.selectMetricsTplDetailList(query);
        List<BizObjMetrics> objMetrics = new ArrayList<>();
        list.forEach(d -> {
            if ("1".equals(d.getMetricsDef().getMetricsType())) {
                if (!d.getMetricsDef().getMetricsCode().startsWith("pp.jvm.")) {
                    //如果是pinpoint链路指标,需要
                    // 1.获取对象pinpoint组成
                    pps.forEach(pp -> {
                        BizObjMetrics ms = new BizObjMetrics();
                        ms.setObjId(objId);
                        ms.setTplId(tplId);
                        ms.setMetricsId(d.getMetricsId());
                        ms.setMetricsName(pp.getPpType() + "/" + d.getMetricsDef().getMetricsName());
                        ms.setMetricsCode(d.getMetricsDef().getMetricsCode());
                        if (pp.getPpType().equals("REDIS")) {
                            //redis需要将1s换成100ms 3s换成300ms 5s换成500ms
                            if (d.getMetricsCode().endsWith("1s")) {
                                ms.setMetricsName(ms.getMetricsName().replace("1s", "100ms"));
                                ms.setMetricsCode(ms.getMetricsCode().replace("1s", "100ms"));
                            }
                            if (d.getMetricsCode().endsWith("3s")) {
                                ms.setMetricsName(ms.getMetricsName().replace("3s", "300ms"));
                                ms.setMetricsCode(ms.getMetricsCode().replace("3s", "300ms"));
                            }
                            if (d.getMetricsCode().endsWith("5s")) {
                                ms.setMetricsName(ms.getMetricsName().replace("5s", "500ms"));
                                ms.setMetricsCode(ms.getMetricsCode().replace("5s", "500ms"));
                            }
                        }
                        ms.setDataExp(ms.getMetricsCode());
                        ms.setAlarmLow(d.getAlarmLow());
                        ms.setAlarmMid(d.getAlarmMid());
                        ms.setAlarmHigh(d.getAlarmHigh());
                        objMetrics.add(ms);
                    });
                } else {
                    agents.forEach(agent -> {
                        BizObjMetrics ms = new BizObjMetrics();
                        ms.setObjId(objId);
                        ms.setTplId(tplId);
                        ms.setMetricsId(d.getMetricsId());
                        ms.setMetricsName(agent.getAgentId() + "/" + d.getMetricsDef().getMetricsName());
                        ms.setMetricsCode(d.getMetricsDef().getMetricsCode());
                        ms.setDataExp(ms.getMetricsCode());
                        ms.setAlarmLow(d.getAlarmLow());
                        ms.setAlarmMid(d.getAlarmMid());
                        ms.setAlarmHigh(d.getAlarmHigh());
                        objMetrics.add(ms);
                    });
                }
            }
        });
        if (objMetrics.size() > 0) {
            bizObjMetricsMapper.batchInsert(objMetrics);
        }
    }

    /**
     * 更新指标
     *
     * @param objId          对象ID
     * @param agentVOList    jvm信息
     * @param pinpointVOList 链路列表数据
     * @param date           时间
     */
    private void updateBizObjMetrics(Long objId, List<AgentVO> agentVOList, List<
            PinpointVO> pinpointVOList, Date date) {
        //查询当前对象所有正在告警列表
        Map<Long, AlarmRecord> recordMap = alarmRecordService.selectAlarmRecordListCurr(objId);
        //查询当前对象未结束事件列表
        Map<Long, HlEvent> eventMap = eventService.selectHlEventListCurr(objId);
        Map<Long, BigDecimal> updateMap = new HashMap<>();
        updateJvmMetrics(objId, agentVOList, date, recordMap, eventMap, updateMap);
        updateLinkMetrics(objId, pinpointVOList, date, recordMap, eventMap, updateMap);
        if (updateMap.size() > 0) {
            updateMap.forEach((key, value) -> {
                String redisKey = CacheConstants.METRICS_D_VALUE + key;
                redisCache.setCacheObject(redisKey, value.toString());
            });
//            jdbcTemplate.batchUpdate("update biz_obj_metrics set d_value = ?, UPDATE_TIME = ? where obj_metrics_id = ?",
//                    updateMap.entrySet().stream()
//                            .map(entry -> new Object[]{entry.getValue(), new Date(), entry.getKey()})
//                            .collect(Collectors.toList()));
        }
    }

    /**
     * 更新jvm指标
     *
     * @param objId 对象ID
     *              * @param agentVOList    jvm信息
     * @param date  数据时间
     */
    private void updateJvmMetrics(Long objId, List<AgentVO> agentVOList, Date date, Map<Long, AlarmRecord> recordMap, Map<Long, HlEvent> eventMap, Map<Long, BigDecimal> updateMap) {
        BizObjMetrics jvmMetrics = new BizObjMetrics();
        jvmMetrics.setObjId(objId);
        jvmMetrics.setMetricsCode("pp.jvm.");
        List<BizObjMetrics> omList = selectBizObjMetricsList(jvmMetrics);
        for (AgentVO vo : agentVOList) {
            if (vo.getCode() == 100) {
                updateMetricsValues(omList, "tps", vo.getAgentId(), BigDecimal.valueOf(vo.getTps()), date, recordMap, eventMap, updateMap);
                updateMetricsValues(omList, "heap.usage", vo.getAgentId(), BigDecimal.valueOf(vo.getHeapUsage()), date, recordMap, eventMap, updateMap);
                updateMetricsValues(omList, "open", vo.getAgentId(), BigDecimal.valueOf(vo.getOpenFiles()), date, recordMap, eventMap, updateMap);
                updateMetricsValues(omList, "gc", vo.getAgentId(), BigDecimal.valueOf(vo.getGcCount()), date, recordMap, eventMap, updateMap);
            }
        }

    }

    /**
     * jvm指标更新
     *
     * @param omList       jvm指标列表
     * @param metricSuffix 指标后缀
     * @param value        值
     * @param agentId      agentId
     * @param date         数据时间
     */
    private void updateMetricsValues(List<BizObjMetrics> omList, String metricSuffix, String agentId, BigDecimal value, Date
            date, Map<Long, AlarmRecord> recordMap, Map<Long, HlEvent> eventMap, Map<Long, BigDecimal> updateMap) {
        List<BizObjMetricsData> dataList = new ArrayList<>();
        List<AlarmRecord> addRList = new ArrayList<>();
        List<AlarmRecord> updateRList = new ArrayList<>();
        List<HlEvent> addEList = new ArrayList<>();
        List<HlEvent> updateEList = new ArrayList<>();
        List<BizObjMetrics> updateList = new ArrayList<>();
        omList.stream()
                .filter(om -> om.getMetricsCode().endsWith(metricSuffix) && om.getMetricsName().startsWith(agentId + "/"))
                .forEach(om -> {
                    om.setDValue(value);
                    om.setUpdateTime(DateUtils.getNowDate());
                    updateMap.put(om.getObjMetricsId(), value);
//                    updateList.add(om);
//                    updateBizObjMetrics(om);
                    BizObjMetricsData data = new BizObjMetricsData();
                    data.setObjMetricsId(om.getObjMetricsId());
                    data.setCreateTime(date);
                    data.setdValue(om.getDValue());
                    dataList.add(data);
                    //处理告警
                    Map<String, AlarmRecord> aMap = alarmRecordService.process(om, recordMap, date);
                    if (aMap.get("add") != null) {
                        addRList.add(aMap.get("add"));
                    }
                    if (aMap.get("update") != null) {
                        updateRList.add(aMap.get("update"));
                    }

                    //处理事件
                    Map<String, HlEvent> eMap = eventService.process(om, eventMap, date);
                    if (eMap.get("add") != null) {
                        addEList.add(eMap.get("add"));
                    }
                    if (eMap.get("update") != null) {
                        updateEList.add(eMap.get("update"));
                    }
                });
        batchUpdate(null, dataList, addRList, updateRList, addEList, updateEList);
    }

    private void batchUpdate
            (List<BizObjMetrics> metricsToUpdate, List<BizObjMetricsData> dataList, List<AlarmRecord> addRList, List<AlarmRecord> updateRList, List<HlEvent> addEList, List<HlEvent> updateEList) {
        // 更新所有需要更新的BizObjMetrics对象
        if (metricsToUpdate != null && !metricsToUpdate.isEmpty()) {
            // 按 objMetricsId 排序，保证更新顺序一致，避免死锁
            metricsToUpdate.sort(Comparator.comparing(BizObjMetrics::getObjMetricsId));
            try (SqlSession sqlSession = factory.openSession(ExecutorType.BATCH, false)) {
                BizObjMetricsMapper mapper = sqlSession.getMapper(BizObjMetricsMapper.class);
                metricsToUpdate.forEach(mapper::updateBizObjMetrics);
                sqlSession.commit();
            }
        }

        if (dataList != null && dataList.size() > 0) {
            try (SqlSession sqlSession = factory.openSession(ExecutorType.SIMPLE, false)) {
                BizObjMetricsDataMapper dataMapper = sqlSession.getMapper(BizObjMetricsDataMapper.class);
                dataList.forEach(dataMapper::insertBizObjMetricsData);
                sqlSession.commit();
            }
        }

        if (addRList != null && addRList.size() > 0) {
            try (SqlSession sqlSession = factory.openSession(ExecutorType.SIMPLE, false)) {
                AlarmRecordMapper recordMapper = sqlSession.getMapper(AlarmRecordMapper.class);
                addRList.forEach(recordMapper::insertAlarmRecord);
                sqlSession.commit();
            }
        }

        if (updateRList != null && updateRList.size() > 0) {
            try (SqlSession sqlSession = factory.openSession(ExecutorType.SIMPLE, false)) {
                AlarmRecordMapper recordMapper = sqlSession.getMapper(AlarmRecordMapper.class);
                updateRList.sort(Comparator.comparing(AlarmRecord::getAlarmId));
                updateRList.forEach(recordMapper::updateAlarmRecord);
                sqlSession.commit();
            }
        }

        if (addEList != null && addEList.size() > 0) {
            try (SqlSession sqlSession = factory.openSession(ExecutorType.SIMPLE, false)) {
                HlEventMapper eventMapper = sqlSession.getMapper(HlEventMapper.class);
                addEList.forEach(eventMapper::insertHlEvent);
                sqlSession.commit();
            }
        }

        if (updateEList != null && updateEList.size() > 0) {
            try (SqlSession sqlSession = factory.openSession(ExecutorType.SIMPLE, false)) {
                HlEventMapper eventMapper = sqlSession.getMapper(HlEventMapper.class);
                updateEList.sort(Comparator.comparing(HlEvent::getEventId));
                updateEList.forEach(eventMapper::updateHlEvent);
                sqlSession.commit();
            }
        }
    }

    /**
     * 更新链路指标
     *
     * @param objId          对象ID
     * @param pinpointVOList 链路列表
     * @param date           时间
     */
    private void updateLinkMetrics(Long objId, List<PinpointVO> pinpointVOList, Date
            date, Map<Long, AlarmRecord> recordMap, Map<Long, HlEvent> eventMap, Map<Long, BigDecimal> updateMap) {
        Map<String, List<BizObjMetrics>> metricsMap = getAllMetricsForObjId(objId);
        pinpointVOList.forEach(vo -> updateMetricsValues(metricsMap, vo, date, recordMap, eventMap, updateMap));
    }


    /**
     * 更新指标
     *
     * @param metricsMap 指标map
     * @param vo         pp链路对象
     * @param date       时间
     */
    private void updateMetricsValues(Map<String, List<BizObjMetrics>> metricsMap, PinpointVO vo, Date
            date, Map<Long, AlarmRecord> recordMap, Map<Long, HlEvent> eventMap, Map<Long, BigDecimal> updateMap) {
        List<BizObjMetricsData> dataList = new ArrayList<>();
//        List<BizObjMetrics> updateList = new ArrayList<>();
        List<AlarmRecord> addRList = new ArrayList<>();
        List<AlarmRecord> updateRList = new ArrayList<>();
        List<HlEvent> addEList = new ArrayList<>();
        List<HlEvent> updateEList = new ArrayList<>();
        for (String code : metricsMap.keySet()) {
            List<BizObjMetrics> list = metricsMap.get(code);
            list.forEach(om -> {
                if (om.getMetricsName().startsWith(vo.getCategory() + "/")) {
                    if (vo.getTot() != 0) {
                        updateMetric(om, "pp.1s", vo.getTime1s(), date, dataList, updateMap);
                        updateMetric(om, "pp.3s", vo.getTime3s(), date, dataList, updateMap);
                        updateMetric(om, "pp.5s", vo.getTime5s(), date, dataList, updateMap);
                        updateMetric(om, "pp.100ms", vo.getTime100ms(), date, dataList, updateMap);
                        updateMetric(om, "pp.300ms", vo.getTime300ms(), date, dataList, updateMap);
                        updateMetric(om, "pp.500ms", vo.getTime500ms(), date, dataList, updateMap);
                        updateMetric(om, "pp.tot", vo.getTot(), date, dataList, updateMap);
                        updateMetric(om, "pp.sum", vo.getSum(), date, dataList, updateMap);
                        updateMetric(om, "pp.max", vo.getMax(), date, dataList, updateMap);
                        updateMetric(om, "pp.avg", vo.getAvg(), date, dataList, updateMap);
                        updateMetric(om, "pp.slow", vo.getSlow(), date, dataList, updateMap);
                        updateMetric(om, "pp.error", vo.getError(), date, dataList, updateMap);
                        Integer time1 = vo.getTime1s();
                        if (time1 == null) {
                            time1 = vo.getTime100ms();
                        }
                        BigDecimal rate = BigDecimal.valueOf(time1).divide(BigDecimal.valueOf(vo.getTot()), 4, RoundingMode.HALF_UP).multiply(BigDecimal.valueOf(100));
                        updateMetric(om, "pp.rate", rate, date, dataList, updateMap);
                        if (om.getDValue() != null) {
                            //处理告警
                            Map<String, AlarmRecord> aMap = alarmRecordService.process(om, recordMap, date);
                            if (aMap.get("add") != null) {
                                addRList.add(aMap.get("add"));
                            }
                            if (aMap.get("update") != null) {
                                updateRList.add(aMap.get("update"));
                            }

                            //处理事件
                            Map<String, HlEvent> eMap = eventService.process(om, eventMap, date);
                            if (eMap.get("add") != null) {
                                addEList.add(eMap.get("add"));
                            }
                            if (eMap.get("update") != null) {
                                updateEList.add(eMap.get("update"));
                            }
                        }
                    }
                }
            });
        }
        batchUpdate(null, dataList, addRList, updateRList, addEList, updateEList);
//        metricsMap.values().stream()
//                .filter(om -> om.getMetricsCode().startsWith(vo.getApplicationName() + "/"))
//                .forEach(om -> {
//                    updateMetric(om, "pp.1s", vo.getTime1s(), date);
//                    updateMetric(om, "pp.3s", vo.getTime3s(), date);
//                    updateMetric(om, "pp.5s", vo.getTime5s(), date);
//                    updateMetric(om, "pp.100ms", vo.getTime100ms(), date);
//                    updateMetric(om, "pp.300ms", vo.getTime300ms(), date);
//                    updateMetric(om, "pp.500ms", vo.getTime500ms(), date);
//                    updateMetric(om, "pp.tot", vo.getTot(), date);
//                    updateMetric(om, "pp.sum", vo.getSum(), date);
//                    updateMetric(om, "pp.max", vo.getMax(), date);
//                    updateMetric(om, "pp.avg", vo.getAvg(), date);
//                    updateMetric(om, "pp.slow", vo.getSlow(), date);
//                    updateMetric(om, "pp.error", vo.getError(), date);
//                });
    }

    /**
     * 调用更新方法
     *
     * @param om     对象
     * @param suffix 前缘
     * @param value  值
     * @param date   时间
     */
    private void updateMetric(BizObjMetrics om, String suffix, Number value, Date
            date, List<BizObjMetricsData> dataList, Map<Long, BigDecimal> updateMap) {
        if (om.getMetricsCode().endsWith(suffix) && value != null) {
            om.setDValue(BigDecimal.valueOf(value.doubleValue()));
            om.setUpdateTime(new Date());
            updateMap.put(om.getObjMetricsId(), om.getDValue());
//            updateList.add(om);
//            updateBizObjMetrics(om);

            BizObjMetricsData data = new BizObjMetricsData();
            data.setObjMetricsId(om.getObjMetricsId());
            data.setdValue(om.getDValue());
            data.setCreateTime(date);
            dataList.add(data);
//            metricsDataService.insertBizObjMetricsData(data);
        }
    }

    /**
     * 获取所有指标对象，并以code转换成map
     *
     * @param objId 对象ID
     * @return map
     */
    private Map<String, List<BizObjMetrics>> getAllMetricsForObjId(Long objId) {
        return getAllMetricsForObjIdList(objId).stream().collect(Collectors.groupingBy(BizObjMetrics::getMetricsCode));
    }

    /**
     * 根据对象ID获取所有指标
     *
     * @param objId 对象ID
     * @return
     */
    private List<BizObjMetrics> getAllMetricsForObjIdList(Long objId) {
        BizObjMetrics search = new BizObjMetrics();
        search.setObjId(objId);
        return selectBizObjMetricsList(search);
    }

}
