package com.jjt.biz.service.impl;

import com.jjt.biz.domain.BizObjPpAgent;
import com.jjt.biz.mapper.BizObjPpAgentMapper;
import com.jjt.biz.service.IBizObjPpAgentService;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 业务对象pinpoint组成agentService业务层处理
 *
 * @author jjt
 * @date 2024-10-14
 */
@Service
public class BizObjPpAgentServiceImpl implements IBizObjPpAgentService {
    @Resource
    private BizObjPpAgentMapper bizObjPpAgentMapper;
    @Resource
    private JdbcTemplate jdbcTemplate;

    /**
     * 查询业务对象pinpoint组成agent
     *
     * @param objPpAgentId 业务对象pinpoint组成agent主键
     * @return 业务对象pinpoint组成agent
     */
    @Override
    public BizObjPpAgent selectBizObjPpAgentByObjPpAgentId(Long objPpAgentId) {
        return bizObjPpAgentMapper.selectBizObjPpAgentByObjPpAgentId(objPpAgentId);
    }

    /**
     * 查询业务对象pinpoint组成agent列表
     *
     * @param bizObjPpAgent 业务对象pinpoint组成agent
     * @return 业务对象pinpoint组成agent
     */
    @Override
    public List<BizObjPpAgent> selectBizObjPpAgentList(BizObjPpAgent bizObjPpAgent) {
        return bizObjPpAgentMapper.selectBizObjPpAgentList(bizObjPpAgent);
    }

    /**
     * 新增业务对象pinpoint组成agent
     *
     * @param bizObjPpAgent 业务对象pinpoint组成agent
     * @return 结果
     */
    @Override
    public int insertBizObjPpAgent(BizObjPpAgent bizObjPpAgent) {
        return bizObjPpAgentMapper.insertBizObjPpAgent(bizObjPpAgent);
    }

    /**
     * 修改业务对象pinpoint组成agent
     *
     * @param bizObjPpAgent 业务对象pinpoint组成agent
     * @return 结果
     */
    @Override
    public int updateBizObjPpAgent(BizObjPpAgent bizObjPpAgent) {
        return bizObjPpAgentMapper.updateBizObjPpAgent(bizObjPpAgent);
    }

    /**
     * 批量删除业务对象pinpoint组成agent
     *
     * @param objPpAgentIds 需要删除的业务对象pinpoint组成agent主键
     * @return 结果
     */
    @Override
    public int deleteBizObjPpAgentByObjPpAgentIds(Long[] objPpAgentIds) {
        return bizObjPpAgentMapper.deleteBizObjPpAgentByObjPpAgentIds(objPpAgentIds);
    }

    /**
     * 删除业务对象pinpoint组成agent信息
     *
     * @param objPpAgentId 业务对象pinpoint组成agent主键
     * @return 结果
     */
    @Override
    public int deleteBizObjPpAgentByObjPpAgentId(Long objPpAgentId) {
        return bizObjPpAgentMapper.deleteBizObjPpAgentByObjPpAgentId(objPpAgentId);
    }

    /**
     * 根据对象ID查询
     *
     * @param objId 对象ID
     * @return 列表
     */
    @Override
    public List<BizObjPpAgent> selectBizObjPpAgentListByObjId(Long objId) {
        BizObjPpAgent pp = new BizObjPpAgent();
        pp.setObjId(objId);
        return selectBizObjPpAgentList(pp);
    }

    /**
     * 根据对象删除
     *
     * @param ag 对象
     */
    @Override
    public void delete(BizObjPpAgent ag) {
        try {
            // 开始事务
            jdbcTemplate.execute("BEGIN");
            String name = ag.getAgentId() + "/%";

            // 执行删除语句
            //1.删除指标数据
            jdbcTemplate.update("DELETE FROM biz_obj_metrics_data WHERE obj_metrics_id IN(SELECT obj_metrics_id FROM biz_obj_metrics WHERE obj_id=? AND metrics_name LIKE ?)", ag.getObjId(), name);
//            //2.删除指标
            jdbcTemplate.update("DELETE FROM biz_obj_metrics WHERE obj_id=? AND metrics_name LIKE ? ", ag.getObjId(), name);
//            //3.删除模板
            jdbcTemplate.update("DELETE FROM BIZ_OBJ_PP_AGENT WHERE OBJ_PP_AGENT_ID=?", ag.getObjPpAgentId());

            // 提交事务
            jdbcTemplate.execute("COMMIT");
        } catch (Exception e) {
            // 回滚事务
            jdbcTemplate.execute("ROLLBACK");
        }
    }
}
