package com.jjt.biz.service.impl;

import com.jjt.biz.domain.BizObjPp;
import com.jjt.biz.mapper.BizObjPpMapper;
import com.jjt.biz.service.IBizObjPpService;
import com.jjt.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 业务对象pinpoint组成Service业务层处理
 *
 * @author jjt
 * @date 2024-08-09
 */
@Service
public class BizObjPpServiceImpl implements IBizObjPpService {
    @Resource
    private BizObjPpMapper bizObjPpMapper;

    /**
     * 查询业务对象pinpoint组成
     *
     * @param objPpId 业务对象pinpoint组成主键
     * @return 业务对象pinpoint组成
     */
    @Override
    public BizObjPp selectBizObjPpByObjPpId(Long objPpId) {
        return bizObjPpMapper.selectBizObjPpByObjPpId(objPpId);
    }

    /**
     * 查询业务对象pinpoint组成列表
     *
     * @param bizObjPp 业务对象pinpoint组成
     * @return 业务对象pinpoint组成
     */
    @Override
    public List<BizObjPp> selectBizObjPpList(BizObjPp bizObjPp) {
        return bizObjPpMapper.selectBizObjPpList(bizObjPp);
    }

    /**
     * 新增业务对象pinpoint组成
     *
     * @param bizObjPp 业务对象pinpoint组成
     * @return 结果
     */
    @Override
    public int insertBizObjPp(BizObjPp bizObjPp) {
        bizObjPp.setCreateTime(DateUtils.getNowDate());
        return bizObjPpMapper.insertBizObjPp(bizObjPp);
    }

    /**
     * 保存或更新
     *
     * @param bizObjPp 业务对象pinpoint组成
     * @return 结果
     */
    @Override
    public int saveOrUpdate(BizObjPp bizObjPp) {
        List<BizObjPp> list = selectBizObjPpListByObjId(bizObjPp.getObjId());

        return 0;
    }

    /**
     * 修改业务对象pinpoint组成
     *
     * @param bizObjPp 业务对象pinpoint组成
     * @return 结果
     */
    @Override
    public int updateBizObjPp(BizObjPp bizObjPp) {
        bizObjPp.setUpdateTime(DateUtils.getNowDate());
        return bizObjPpMapper.updateBizObjPp(bizObjPp);
    }

    /**
     * 批量删除业务对象pinpoint组成
     *
     * @param objPpIds 需要删除的业务对象pinpoint组成主键
     * @return 结果
     */
    @Override
    public int deleteBizObjPpByObjPpIds(Long[] objPpIds) {
        return bizObjPpMapper.deleteBizObjPpByObjPpIds(objPpIds);
    }

    /**
     * 删除业务对象pinpoint组成信息
     *
     * @param objPpId 业务对象pinpoint组成主键
     * @return 结果
     */
    @Override
    public int deleteBizObjPpByObjPpId(Long objPpId) {
        return bizObjPpMapper.deleteBizObjPpByObjPpId(objPpId);
    }

    /**
     * 通过objId查询列表
     *
     * @param objId 对象ID
     * @return 结果
     */
    @Override
    public List<BizObjPp> selectBizObjPpListByObjId(Long objId) {
        BizObjPp pp = new BizObjPp();
        pp.setObjId(objId);
        return selectBizObjPpList(pp);
    }
}
