package com.jjt.biz.service.impl;

import com.jjt.biz.domain.BizObj;
import com.jjt.biz.domain.BizObjTpl;
import com.jjt.biz.mapper.BizObjMapper;
import com.jjt.biz.service.IBizObjService;
import com.jjt.biz.service.IBizObjTplService;
import com.jjt.common.utils.DateUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 业务对象Service业务层处理
 *
 * @author jjt
 * @date 2024-08-09
 */
@Service
public class BizObjServiceImpl implements IBizObjService {
    @Resource
    private BizObjMapper bizObjMapper;
    @Resource
    private IBizObjTplService objTplService;
    @Resource
    private JdbcTemplate jdbcTemplate;

    /**
     * 查询业务对象
     *
     * @param objId 业务对象主键
     * @return 业务对象
     */
    @Override
    public BizObj selectBizObjByObjId(Long objId) {
        BizObj bizObj = bizObjMapper.selectBizObjByObjId(objId);
        BizObjTpl tpl = new BizObjTpl();
        tpl.setObjId(objId);
        bizObj.setTplList(objTplService.selectBizObjTplList(tpl));
        return bizObj;
    }

    /**
     * 查询业务对象列表
     *
     * @param bizObj 业务对象
     * @return 业务对象
     */
    @Override
    public List<BizObj> selectBizObjList(BizObj bizObj) {
        List<BizObj> list = bizObjMapper.selectBizObjList(bizObj);
        list.forEach(obj -> {
            BizObjTpl tpl = new BizObjTpl();
            tpl.setObjId(obj.getObjId());
            obj.setTplList(objTplService.selectBizObjTplList(tpl));
        });
        return list;
    }

    /**
     * 新增业务对象
     *
     * @param bizObj 业务对象
     * @return 结果
     */
    @Override
    public int insertBizObj(BizObj bizObj) {
        bizObj.setCreateTime(DateUtils.getNowDate());
        return bizObjMapper.insertBizObj(bizObj);
    }

    /**
     * 修改业务对象
     *
     * @param bizObj 业务对象
     * @return 结果
     */
    @Override
    public int updateBizObj(BizObj bizObj) {
        bizObj.setUpdateTime(DateUtils.getNowDate());
        return bizObjMapper.updateBizObj(bizObj);
    }

    /**
     * 批量删除业务对象
     *
     * @param objIds 需要删除的业务对象主键
     * @return 结果
     */
    @Override
    public int deleteBizObjByObjIds(Long[] objIds) {
        int i = 0;
        for (Long objId : objIds) {
            try {
                // 开始事务
                jdbcTemplate.execute("BEGIN");

                // 执行删除语句
                //1.删除指标数据
                jdbcTemplate.update("DELETE FROM biz_obj_metrics_data WHERE obj_metrics_id IN(SELECT obj_metrics_id FROM biz_obj_metrics WHERE obj_id=?)", objId);
                //2.删除指标
                jdbcTemplate.update("DELETE FROM biz_obj_metrics WHERE obj_id=?", objId);
                //3.删除模板
                jdbcTemplate.update("DELETE FROM biz_obj_tpl WHERE obj_id=?", objId);
                //3.删除对象
                jdbcTemplate.update("DELETE FROM biz_obj WHERE obj_id=?", objId);

                // 提交事务
                jdbcTemplate.execute("COMMIT");
                i = 1;
            } catch (Exception e) {
                e.printStackTrace();
                // 回滚事务
                jdbcTemplate.execute("ROLLBACK");
                i = 0;
            }
        }
        return i;
    }

    /**
     * 删除业务对象信息
     *
     * @param objId 业务对象主键
     * @return 结果
     */
    @Override
    public int deleteBizObjByObjId(Long objId) {
        return bizObjMapper.deleteBizObjByObjId(objId);
    }

    /**
     * 通过指标ID查询对象列表
     *
     * @param metricsId 指标ID
     * @return 结果
     */
    @Override
    public List<BizObj> selectBizObjListByMetricsId(Long metricsId) {
        return bizObjMapper.selectBizObjListByMetricsId(metricsId);
    }
}
