package com.jjt.biz.service.impl;

import com.jjt.biz.domain.BizObjTpl;
import com.jjt.biz.domain.MetricsTpl;
import com.jjt.biz.mapper.BizObjTplMapper;
import com.jjt.biz.service.IBizObjMetricsService;
import com.jjt.biz.service.IBizObjTplService;
import com.jjt.biz.service.IMetricsTplDetailService;
import com.jjt.common.utils.DateUtils;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 业务对象模板应用Service业务层处理
 *
 * @author jjt
 * @date 2024-08-09
 */
@Service
public class BizObjTplServiceImpl implements IBizObjTplService {
    @Resource
    private BizObjTplMapper bizObjTplMapper;
    @Resource
    private IBizObjMetricsService metricsService;
    @Resource
    private IMetricsTplDetailService tplDetailService;
    @Resource
    private JdbcTemplate jdbcTemplate;

    /**
     * 查询业务对象模板应用
     *
     * @param objTplId 业务对象模板应用主键
     * @return 业务对象模板应用
     */
    @Override
    public BizObjTpl selectBizObjTplByObjTplId(Long objTplId) {
        return bizObjTplMapper.selectBizObjTplByObjTplId(objTplId);
    }

    /**
     * 查询业务对象模板应用列表
     *
     * @param bizObjTpl 业务对象模板应用
     * @return 业务对象模板应用
     */
    @Override
    public List<BizObjTpl> selectBizObjTplList(BizObjTpl bizObjTpl) {
        return bizObjTplMapper.selectBizObjTplList(bizObjTpl);
    }

    /**
     * 新增业务对象模板应用
     *
     * @param bizObjTpl 业务对象模板应用
     * @return 结果
     */
    @Override
    public int insertBizObjTpl(BizObjTpl bizObjTpl) {
        bizObjTpl.setCreateTime(DateUtils.getNowDate());
        return bizObjTplMapper.insertBizObjTpl(bizObjTpl);
    }

    /**
     * 修改业务对象模板应用
     *
     * @param bizObjTpl 业务对象模板应用
     * @return 结果
     */
    @Override
    public int updateBizObjTpl(BizObjTpl bizObjTpl) {
        bizObjTpl.setUpdateTime(DateUtils.getNowDate());
        return bizObjTplMapper.updateBizObjTpl(bizObjTpl);
    }

    /**
     * 批量删除业务对象模板应用
     *
     * @param objTplIds 需要删除的业务对象模板应用主键
     * @return 结果
     */
    @Override
    public int deleteBizObjTplByObjTplIds(Long[] objTplIds) {
        return bizObjTplMapper.deleteBizObjTplByObjTplIds(objTplIds);
    }

    /**
     * 删除业务对象模板应用信息
     *
     * @param objTplId 业务对象模板应用主键
     * @return 结果
     */
    @Override
    public int deleteBizObjTplByObjTplId(Long objTplId) {
        return bizObjTplMapper.deleteBizObjTplByObjTplId(objTplId);
    }

    /**
     * 选择模板，除开当前对象已选择的。
     *
     * @param objId 对象ID
     * @return 结果
     */
    @Override
    public List<MetricsTpl> selectTplList(Long objId) {
        return bizObjTplMapper.selectTplList(objId);
    }

    /**
     * 查询当前对象已选择的模板
     *
     * @param objId 对象ID
     * @return 结果
     */
    @Override
    public List<BizObjTpl> selectTplList4objId(Long objId) {
        BizObjTpl objTpl = new BizObjTpl();
        objTpl.setObjId(objId);
        return selectBizObjTplList(objTpl);
    }

    /**
     * 添加模板
     *
     * @param objId  对象id
     * @param tplIds 模板ids
     * @return 结果
     */
    @Override
    public int insertTplDetails(Long objId, Long[] tplIds) {
        for (Long tplId : tplIds) {
            BizObjTpl bizObjTpl = new BizObjTpl();
            bizObjTpl.setTplId(tplId);
            bizObjTpl.setObjId(objId);
            List list = selectBizObjTplList(bizObjTpl);
            if (list.size() == 0) {
                //防止重复添加
                insertBizObjTpl(bizObjTpl);
                metricsService.insertBatch(objId, tplId);
            }
        }
        return 0;
    }

    /**
     * 通过objId查询列表
     *
     * @param objId 对象ID
     * @return 结果
     */
    @Override
    public List<BizObjTpl> selectBizObjTplListByObjId(Long objId) {
        BizObjTpl obj = new BizObjTpl();
        obj.setObjId(objId);
        return selectBizObjTplList(obj);
    }

    /**
     * 删除模板
     *
     * @param objId 对象ID
     * @param tplId 模板ID
     * @return 结果
     */
    @Override
    public int del(Long objId, Long tplId) {
        try {
            // 开始事务
            jdbcTemplate.execute("BEGIN");

            // 执行删除语句
            //1.删除指标数据
            jdbcTemplate.update("DELETE FROM biz_obj_metrics_data WHERE obj_metrics_id IN(SELECT obj_metrics_id FROM biz_obj_metrics WHERE obj_id=? AND tpl_id=?)", objId, tplId);
            //2.删除指标
            jdbcTemplate.update("DELETE FROM biz_obj_metrics WHERE obj_id=? AND tpl_id=?", objId, tplId);
            //3.删除模板
            jdbcTemplate.update("DELETE FROM biz_obj_tpl WHERE obj_id=? AND tpl_id=?", objId, tplId);

            // 提交事务
            jdbcTemplate.execute("COMMIT");
            return 1;
        } catch (Exception e) {
            // 回滚事务
            jdbcTemplate.execute("ROLLBACK");
            return 0;
        }
    }
}
