package com.jjt.biz.service.impl;

import com.jjt.biz.domain.MetricsDef;
import com.jjt.biz.domain.MetricsType;
import com.jjt.biz.mapper.MetricsDefMapper;
import com.jjt.biz.service.IMetricsDefService;
import com.jjt.biz.service.IMetricsTypeDefService;
import com.jjt.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 指标定义Service业务层处理
 *
 * @author jjt
 * @date 2024-08-08
 */
@Service
public class MetricsDefServiceImpl implements IMetricsDefService {
    @Resource
    private MetricsDefMapper metricsDefMapper;
    @Resource
    private IMetricsTypeDefService relaService;

    /**
     * 查询指标定义
     *
     * @param metricsId 指标定义主键
     * @return 指标定义
     */
    @Override
    public MetricsDef selectMetricsDefByMetricsId(Long metricsId) {
        MetricsDef def = metricsDefMapper.selectMetricsDefByMetricsId(metricsId);
        List<MetricsType> list = relaService.selectMetricsTypeList(def.getMetricsId());
        def.setMetricsTypes(list);
        return def;
    }

    /**
     * 查询指标定义列表
     *
     * @param metricsDef 指标定义
     * @return 指标定义
     */
    @Override
    public List<MetricsDef> selectMetricsDefList(MetricsDef metricsDef) {
        List<MetricsDef> metricsDefList = metricsDefMapper.selectMetricsDefList(metricsDef);
        metricsDefList.forEach(def -> {
            List<MetricsType> list = relaService.selectMetricsTypeList(def.getMetricsId());
            def.setMetricsTypes(list);
        });
        return metricsDefList;
    }

    /**
     * 新增指标定义
     *
     * @param metricsDef 指标定义
     * @return 结果
     */
    @Override
    public int insertMetricsDef(MetricsDef metricsDef) {
        metricsDef.setCreateTime(DateUtils.getNowDate());
        int x = metricsDefMapper.insertMetricsDef(metricsDef);
        relaService.insert(metricsDef.getMetricsId(), metricsDef.getMetricsTypes());
        return x;
    }

    /**
     * 修改指标定义
     *
     * @param metricsDef 指标定义
     * @return 结果
     */
    @Override
    public int updateMetricsDef(MetricsDef metricsDef) {
        relaService.insert(metricsDef.getMetricsId(), metricsDef.getMetricsTypes());
        metricsDef.setUpdateTime(DateUtils.getNowDate());
        return metricsDefMapper.updateMetricsDef(metricsDef);
    }

    /**
     * 批量删除指标定义
     *
     * @param metricsIds 需要删除的指标定义主键
     * @return 结果
     */
    @Override
    public int deleteMetricsDefByMetricsIds(Long[] metricsIds) {
        return metricsDefMapper.deleteMetricsDefByMetricsIds(metricsIds);
    }

    /**
     * 删除指标定义信息
     *
     * @param metricsId 指标定义主键
     * @return 结果
     */
    @Override
    public int deleteMetricsDefByMetricsId(Long metricsId) {
        return metricsDefMapper.deleteMetricsDefByMetricsId(metricsId);
    }
}
