package com.jjt.biz.service.impl;

import com.jjt.biz.domain.MetricsDef;
import com.jjt.biz.domain.MetricsTplDetail;
import com.jjt.biz.mapper.MetricsTplDetailMapper;
import com.jjt.biz.service.IMetricsTplDetailService;
import com.jjt.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 模板指标明细Service业务层处理
 *
 * @author jjt
 * @date 2024-08-08
 */
@Service
public class MetricsTplDetailServiceImpl implements IMetricsTplDetailService {
    @Resource
    private MetricsTplDetailMapper metricsTplDetailMapper;

    /**
     * 查询模板指标明细
     *
     * @param tplDetailId 模板指标明细主键
     * @return 模板指标明细
     */
    @Override
    public MetricsTplDetail selectMetricsTplDetailByTplDetailId(Long tplDetailId) {
        return metricsTplDetailMapper.selectMetricsTplDetailByTplDetailId(tplDetailId);
    }

    /**
     * 查询模板指标明细列表
     *
     * @param metricsTplDetail 模板指标明细
     * @return 模板指标明细
     */
    @Override
    public List<MetricsTplDetail> selectMetricsTplDetailList(MetricsTplDetail metricsTplDetail) {
        return metricsTplDetailMapper.selectMetricsTplDetailList(metricsTplDetail);
    }

    /**
     * 新增模板指标明细
     *
     * @param metricsTplDetail 模板指标明细
     * @return 结果
     */
    @Override
    public int insertMetricsTplDetail(MetricsTplDetail metricsTplDetail) {
        metricsTplDetail.setCreateTime(DateUtils.getNowDate());
        return metricsTplDetailMapper.insertMetricsTplDetail(metricsTplDetail);
    }

    /**
     * 修改模板指标明细
     *
     * @param metricsTplDetail 模板指标明细
     * @return 结果
     */
    @Override
    public int updateMetricsTplDetail(MetricsTplDetail metricsTplDetail) {
        metricsTplDetail.setUpdateTime(DateUtils.getNowDate());
        return metricsTplDetailMapper.updateMetricsTplDetail(metricsTplDetail);
    }

    /**
     * 批量删除模板指标明细
     *
     * @param tplDetailIds 需要删除的模板指标明细主键
     * @return 结果
     */
    @Override
    public int deleteMetricsTplDetailByTplDetailIds(Long[] tplDetailIds) {
        return metricsTplDetailMapper.deleteMetricsTplDetailByTplDetailIds(tplDetailIds);
    }

    /**
     * 删除模板指标明细信息
     *
     * @param tplDetailId 模板指标明细主键
     * @return 结果
     */
    @Override
    public int deleteMetricsTplDetailByTplDetailId(Long tplDetailId) {
        return metricsTplDetailMapper.deleteMetricsTplDetailByTplDetailId(tplDetailId);
    }

    /**
     * 选择指标，已选择的需要排除
     *
     * @param tplId 模板ID
     * @return 列表
     */
    @Override
    public List<MetricsDef> selectMetricsDefList(Long tplId, MetricsDef def) {
        return metricsTplDetailMapper.selectMetricsDefList(tplId,def);
    }

    /**
     * 添加指标
     *
     * @param tplId      模板ID
     * @param metricsIds 指标ID数组
     * @return 结果
     */
    @Override
    public int insertMetricsTplDetails(Long tplId, Long[] metricsIds) {
        return metricsTplDetailMapper.insertMetricsTplDetails(tplId, metricsIds);
    }
}
