package com.jjt.biz.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.jjt.biz.domain.MetricsType;
import com.jjt.biz.domain.MetricsTypeDef;
import com.jjt.biz.mapper.MetricsTypeDefMapper;
import com.jjt.biz.service.IMetricsTypeDefService;
import com.jjt.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 分类和定义关系Service业务层处理
 *
 * @author jjt
 * @date 2024-08-08
 */
@Service
public class MetricsTypeDefServiceImpl implements IMetricsTypeDefService {
    @Resource
    private MetricsTypeDefMapper metricsTypeDefMapper;

    /**
     * 查询分类和定义关系
     *
     * @param relaId 分类和定义关系主键
     * @return 分类和定义关系
     */
    @Override
    public MetricsTypeDef selectMetricsTypeDefByRelaId(Long relaId) {
        return metricsTypeDefMapper.selectMetricsTypeDefByRelaId(relaId);
    }

    /**
     * 查询分类和定义关系列表
     *
     * @param metricsTypeDef 分类和定义关系
     * @return 分类和定义关系
     */
    @Override
    public List<MetricsTypeDef> selectMetricsTypeDefList(MetricsTypeDef metricsTypeDef) {
        return metricsTypeDefMapper.selectMetricsTypeDefList(metricsTypeDef);
    }

    /**
     * 新增分类和定义关系
     *
     * @param metricsTypeDef 分类和定义关系
     * @return 结果
     */
    @Override
    public int insertMetricsTypeDef(MetricsTypeDef metricsTypeDef) {
        metricsTypeDef.setCreateTime(DateUtils.getNowDate());
        return metricsTypeDefMapper.insertMetricsTypeDef(metricsTypeDef);
    }

    /**
     * 修改分类和定义关系
     *
     * @param metricsTypeDef 分类和定义关系
     * @return 结果
     */
    @Override
    public int updateMetricsTypeDef(MetricsTypeDef metricsTypeDef) {
        metricsTypeDef.setUpdateTime(DateUtils.getNowDate());
        return metricsTypeDefMapper.updateMetricsTypeDef(metricsTypeDef);
    }

    /**
     * 批量删除分类和定义关系
     *
     * @param relaIds 需要删除的分类和定义关系主键
     * @return 结果
     */
    @Override
    public int deleteMetricsTypeDefByRelaIds(Long[] relaIds) {
        return metricsTypeDefMapper.deleteMetricsTypeDefByRelaIds(relaIds);
    }

    /**
     * 删除分类和定义关系信息
     *
     * @param relaId 分类和定义关系主键
     * @return 结果
     */
    @Override
    public int deleteMetricsTypeDefByRelaId(Long relaId) {
        return metricsTypeDefMapper.deleteMetricsTypeDefByRelaId(relaId);
    }

    /**
     * 根据指标ID，查询分类列表
     *
     * @param metricsId 指标ID
     * @return list
     */
    @Override
    public List<MetricsType> selectMetricsTypeList(Long metricsId) {
        return metricsTypeDefMapper.selectMetricsTypeList(metricsId);
    }

    /**
     * 添加关系
     *
     * @param metricsId 指标ID
     * @param list      分类列表
     */
    @Override
    public void insert(Long metricsId, List<MetricsType> list) {
        //先删除
        QueryWrapper<MetricsTypeDef> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("metrics_id" , metricsId);
        metricsTypeDefMapper.delete(queryWrapper);
        if (list != null && list.size() > 0) {
            //再添加
            list.forEach(type -> {
                MetricsTypeDef typeDef = new MetricsTypeDef();
                typeDef.setMetricsId(metricsId);
                typeDef.setTypeId(type.getTypeId());
                metricsTypeDefMapper.insertMetricsTypeDef(typeDef);
            });
        }


    }
}
