package com.jjt.biz.service.impl;

import com.jjt.biz.domain.MetricsType;
import com.jjt.biz.mapper.MetricsTypeMapper;
import com.jjt.biz.service.IMetricsTypeService;
import com.jjt.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 指标分类Service业务层处理
 *
 * @author jjt
 * @date 2024-08-08
 */
@Service
public class MetricsTypeServiceImpl implements IMetricsTypeService {
    @Resource
    private MetricsTypeMapper metricsTypeMapper;

    /**
     * 查询指标分类
     *
     * @param typeId 指标分类主键
     * @return 指标分类
     */
    @Override
    public MetricsType selectMetricsTypeByTypeId(Long typeId) {
        return metricsTypeMapper.selectMetricsTypeByTypeId(typeId);
    }

    /**
     * 查询指标分类列表
     *
     * @param metricsType 指标分类
     * @return 指标分类
     */
    @Override
    public List<MetricsType> selectMetricsTypeList(MetricsType metricsType) {
        return metricsTypeMapper.selectMetricsTypeList(metricsType);
    }

    /**
     * 新增指标分类
     *
     * @param metricsType 指标分类
     * @return 结果
     */
    @Override
    public int insertMetricsType(MetricsType metricsType) {
        metricsType.setCreateTime(DateUtils.getNowDate());
        return metricsTypeMapper.insertMetricsType(metricsType);
    }

    /**
     * 修改指标分类
     *
     * @param metricsType 指标分类
     * @return 结果
     */
    @Override
    public int updateMetricsType(MetricsType metricsType) {
        metricsType.setUpdateTime(DateUtils.getNowDate());
        return metricsTypeMapper.updateMetricsType(metricsType);
    }

    /**
     * 批量删除指标分类
     *
     * @param typeIds 需要删除的指标分类主键
     * @return 结果
     */
    @Override
    public int deleteMetricsTypeByTypeIds(Long[] typeIds) {
        return metricsTypeMapper.deleteMetricsTypeByTypeIds(typeIds);
    }

    /**
     * 删除指标分类信息
     *
     * @param typeId 指标分类主键
     * @return 结果
     */
    @Override
    public int deleteMetricsTypeByTypeId(Long typeId) {
        return metricsTypeMapper.deleteMetricsTypeByTypeId(typeId);
    }
}
