package com.jjt.check.controller;

import com.deepoove.poi.XWPFTemplate;
import com.jjt.biz.domain.BizObjMetrics;
import com.jjt.biz.service.IBizObjMetricsService;
import com.jjt.check.domain.CheckConfig;
import com.jjt.check.domain.CheckRecord;
import com.jjt.check.domain.CheckRecordDetail;
import com.jjt.check.service.ICheckConfigService;
import com.jjt.check.service.ICheckRecordDetailService;
import com.jjt.check.service.ICheckRecordService;
import com.jjt.check.vo.CheckExportVO;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.DateUtils;
import com.jjt.common.utils.IntervalUtil;
import com.jjt.common.utils.bean.BeanUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.net.URLEncoder;
import java.util.*;

/**
 * 自动巡检指标配置Controller
 *
 * @author jjt
 * @date 2024-12-06
 */
@Api(tags = "自动巡检指标配置")
@RestController
@RequestMapping("/check/chkc")
public class CheckConfigController extends BaseController {
    @Resource
    private ICheckConfigService checkConfigService;
    @Resource
    private ICheckRecordService crService;
    @Resource
    private ICheckRecordDetailService crdService;

    /**
     * 查询自动巡检指标配置列表
     */
    @ApiOperation("查询自动巡检指标配置列表")
    ////@PreAuthorize("@ss.hasPermi('check:chkc:list')")
    @GetMapping("/list")
    public TableDataInfo list(CheckConfig checkConfig) {
        startPage();
        List<CheckConfig> list = checkConfigService.selectCheckConfigList(checkConfig);
        return getDataTable(list);
    }

    /**
     * 获取自动巡检指标配置详细信息
     */
    @ApiOperation("获取自动巡检指标配置详细信息")
    ////@PreAuthorize("@ss.hasPermi('check:chkc:query')")
    @GetMapping(value = "/{ccId}")
    public AjaxResult getInfo(@PathVariable("ccId") Long ccId) {
        return success(checkConfigService.selectCheckConfigByCcId(ccId));
    }

    /**
     * 新增自动巡检指标配置
     */
    @ApiOperation("新增自动巡检指标配置")
    ////@PreAuthorize("@ss.hasPermi('check:chkc:add')")
    @Log(title = "自动巡检指标配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CheckConfig checkConfig) {
        return toAjax(checkConfigService.insertCheckConfig(checkConfig));
    }

    @ApiOperation("导出巡检报告")
    @GetMapping("/export/{crId}")
    public void checkExport(@PathVariable("crId") Long crId, HttpServletResponse response) {
        CheckRecord cr = crService.selectCheckRecordByCrId(crId);
        // 定义模板对应的数据
        HashMap<String, Object> data = new HashMap<>();

        for (CheckRecordDetail crd : cr.getDetailList()) {
            String e = crd.getCheckCode().split("_")[1];
            int pos = Integer.parseInt(e);
            data.put("l" + pos, crd.getResultL());
            data.put("r" + pos, crd.getResultR());
        }

        // 渲染模板
        try (InputStream inputStream = getClass().getClassLoader().getResourceAsStream("tpl/check.docx");
             OutputStream outputStream = new BufferedOutputStream(response.getOutputStream());
             ByteArrayOutputStream out = new ByteArrayOutputStream();) {
            // 写出到文件
            XWPFTemplate template = XWPFTemplate.compile(inputStream).render(data);

            template.writeAndClose(out);
            // 清空response
            response.reset();
            // 设置response的Header
            response.setCharacterEncoding("UTF-8");
            //Content-Disposition的作用：告知浏览器以何种方式显示响应返回的文件，用浏览器打开还是以附件的形式下载到本地保存
            //attachment表示以附件方式下载 inline表示在线打开 "Content-Disposition: inline; filename=文件名.mp3"
            // filename表示文件的默认名称，因为网络传输只支持URL编码的相关支付，因此需要将文件名URL编码后进行传输,前端收到后需要反编码才能获取到真正的名称
            response.addHeader("Content-Disposition", "attachment;filename=" + URLEncoder.encode("新一代电力交易平台巡检报告" + DateUtils.dateTimeNow() + ".docx", "UTF-8"));
            response.setContentType("application/octet-stream");
            outputStream.write(out.toByteArray());
            outputStream.flush();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 修改自动巡检指标配置
     */
    @ApiOperation("修改自动巡检指标配置")
    ////@PreAuthorize("@ss.hasPermi('check:chkc:edit')")
    @Log(title = "自动巡检指标配置", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody CheckConfig checkConfig) {
        return toAjax(checkConfigService.updateCheckConfig(checkConfig));
    }

    @ApiOperation("获取巡检结果")
    ////@PreAuthorize("@ss.hasPermi('check:chkc:query')")
    @GetMapping(value = "/result")
    public AjaxResult result(Long id) {
        return success(crService.selectCheckRecordByCrId(id));
    }

    /**
     * 修改自动巡检记录明细
     */
    @ApiOperation("一键巡检")
    @PostMapping("/check")
    public AjaxResult check() {
        CheckRecord cr=crService.check();
        return success(cr);
    }

    /**
     * 删除自动巡检指标配置
     */
    @ApiOperation("删除自动巡检指标配置")
    ////@PreAuthorize("@ss.hasPermi('check:chkc:remove')")
    @Log(title = "自动巡检指标配置", businessType = BusinessType.DELETE)
    @GetMapping("/del/{ccIds}")
    public AjaxResult remove(@PathVariable Long[] ccIds) {
        return toAjax(checkConfigService.deleteCheckConfigByCcIds(ccIds));
    }
}
