package com.jjt.check.controller;

import com.jjt.check.domain.CheckRecord;
import com.jjt.check.service.ICheckRecordService;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 自动巡检记录Controller
 *
 * @author jjt
 * @date 2024-12-06
 */
@Api(tags = "自动巡检记录")
@RestController
@RequestMapping("/check/chkr")
public class CheckRecordController extends BaseController {
    @Resource
    private ICheckRecordService checkRecordService;

    /**
     * 查询自动巡检记录列表
     */
    @ApiOperation("查询自动巡检记录列表")
    //@PreAuthorize("@ss.hasPermi('check:chkr:list')")
    @GetMapping("/list")
    public TableDataInfo list(CheckRecord checkRecord) {
        startPage();
        List<CheckRecord> list = checkRecordService.selectCheckRecordList(checkRecord);
        return getDataTable(list);
    }

    /**
     * 导出自动巡检记录列表
     */
    @ApiOperation("导出自动巡检记录列表")
    //@PreAuthorize("@ss.hasPermi('check:chkr:export')")
    @Log(title = "自动巡检记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CheckRecord checkRecord) {
        List<CheckRecord> list = checkRecordService.selectCheckRecordList(checkRecord);
        ExcelUtil<CheckRecord> util = new ExcelUtil<CheckRecord>(CheckRecord.class);
        util.exportExcel(response, list, "自动巡检记录数据");
    }

    /**
     * 获取自动巡检记录详细信息
     */
    @ApiOperation("获取自动巡检记录详细信息")
    //@PreAuthorize("@ss.hasPermi('check:chkr:query')")
    @GetMapping(value = "/{crId}")
    public AjaxResult getInfo(@PathVariable("crId") Long crId) {
        return success(checkRecordService.selectCheckRecordByCrId(crId));
    }

    /**
     * 新增自动巡检记录
     */
    @ApiOperation("新增自动巡检记录")
    //@PreAuthorize("@ss.hasPermi('check:chkr:add')")
    @Log(title = "自动巡检记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CheckRecord checkRecord) {
        return toAjax(checkRecordService.insertCheckRecord(checkRecord));
    }

    /**
     * 修改自动巡检记录
     */
    @ApiOperation("修改自动巡检记录")
    //@PreAuthorize("@ss.hasPermi('check:chkr:edit')")
    @Log(title = "自动巡检记录", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody CheckRecord checkRecord) {
        return toAjax(checkRecordService.updateCheckRecord(checkRecord));
    }

    /**
     * 删除自动巡检记录
     */
    @ApiOperation("删除自动巡检记录")
    //@PreAuthorize("@ss.hasPermi('check:chkr:remove')")
    @Log(title = "自动巡检记录", businessType = BusinessType.DELETE)
    @GetMapping("/del/{crIds}")
    public AjaxResult remove(@PathVariable Long[] crIds) {
        return toAjax(checkRecordService.deleteCheckRecordByCrIds(crIds));
    }
}
