package com.jjt.check.controller;

import com.jjt.check.domain.CheckRecordDetail;
import com.jjt.check.service.ICheckRecordDetailService;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 自动巡检记录明细Controller
 *
 * @author jjt
 * @date 2024-12-06
 */
@Api(tags = "自动巡检记录明细")
@RestController
@RequestMapping("/check/chkd")
public class CheckRecordDetailController extends BaseController {
    @Resource
    private ICheckRecordDetailService checkRecordDetailService;

    /**
     * 查询自动巡检记录明细列表
     */
    @ApiOperation("查询自动巡检记录明细列表")
    ////@PreAuthorize("@ss.hasPermi('check:chkd:list')")
    @GetMapping("/list")
    public TableDataInfo list(CheckRecordDetail checkRecordDetail) {
        startPage();
        List<CheckRecordDetail> list = checkRecordDetailService.selectCheckRecordDetailList(checkRecordDetail);
        return getDataTable(list);
    }

    /**
     * 导出自动巡检记录明细列表
     */
    @ApiOperation("导出自动巡检记录明细列表")
    ////@PreAuthorize("@ss.hasPermi('check:chkd:export')")
    @Log(title = "自动巡检记录明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CheckRecordDetail checkRecordDetail) {
        List<CheckRecordDetail> list = checkRecordDetailService.selectCheckRecordDetailList(checkRecordDetail);
        ExcelUtil<CheckRecordDetail> util = new ExcelUtil<CheckRecordDetail>(CheckRecordDetail.class);
        util.exportExcel(response, list, "自动巡检记录明细数据");
    }

    /**
     * 获取自动巡检记录明细详细信息
     */
    @ApiOperation("获取自动巡检记录明细详细信息")
    ////@PreAuthorize("@ss.hasPermi('check:chkd:query')")
    @GetMapping(value = "/{crdId}")
    public AjaxResult getInfo(@PathVariable("crdId") Long crdId) {
        return success(checkRecordDetailService.selectCheckRecordDetailByCrdId(crdId));
    }

    /**
     * 新增自动巡检记录明细
     */
    @ApiOperation("新增自动巡检记录明细")
    ////@PreAuthorize("@ss.hasPermi('check:chkd:add')")
    @Log(title = "自动巡检记录明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CheckRecordDetail checkRecordDetail) {
        return toAjax(checkRecordDetailService.insertCheckRecordDetail(checkRecordDetail));
    }

    /**
     * 修改自动巡检记录明细
     */
    @ApiOperation("修改自动巡检记录明细")
    ////@PreAuthorize("@ss.hasPermi('check:chkd:edit')")
    @Log(title = "自动巡检记录明细", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody CheckRecordDetail checkRecordDetail) {
        return toAjax(checkRecordDetailService.updateCheckRecordDetail(checkRecordDetail));
    }

    /**
     * 删除自动巡检记录明细
     */
    @ApiOperation("删除自动巡检记录明细")
    ////@PreAuthorize("@ss.hasPermi('check:chkd:remove')")
    @Log(title = "自动巡检记录明细", businessType = BusinessType.DELETE)
    @GetMapping("/del/{crdIds}")
    public AjaxResult remove(@PathVariable Long[] crdIds) {
        return toAjax(checkRecordDetailService.deleteCheckRecordDetailByCrdIds(crdIds));
    }
}
