package com.jjt.check.service.impl;

import java.util.List;
        import com.jjt.common.utils.DateUtils;
import org.springframework.stereotype.Service;
import com.jjt.check.mapper.CheckConfigMapper;
import com.jjt.check.domain.CheckConfig;
import com.jjt.check.service.ICheckConfigService;
import javax.annotation.Resource;

/**
 * 自动巡检指标配置Service业务层处理
 *
 * @author jjt
 * @date 2024-12-06
 */
@Service
public class CheckConfigServiceImpl implements ICheckConfigService {
    @Resource
    private CheckConfigMapper checkConfigMapper;

    /**
     * 查询自动巡检指标配置
     *
     * @param ccId 自动巡检指标配置主键
     * @return 自动巡检指标配置
     */
    @Override
    public CheckConfig selectCheckConfigByCcId(Long ccId) {
        return checkConfigMapper.selectCheckConfigByCcId(ccId);
    }

    /**
     * 查询自动巡检指标配置列表
     *
     * @param checkConfig 自动巡检指标配置
     * @return 自动巡检指标配置
     */
    @Override
    public List<CheckConfig> selectCheckConfigList(CheckConfig checkConfig) {
        return checkConfigMapper.selectCheckConfigList(checkConfig);
    }

    /**
     * 新增自动巡检指标配置
     *
     * @param checkConfig 自动巡检指标配置
     * @return 结果
     */
    @Override
    public int insertCheckConfig(CheckConfig checkConfig) {
                checkConfig.setCreateTime(DateUtils.getNowDate());
            return checkConfigMapper.insertCheckConfig(checkConfig);
    }

    /**
     * 修改自动巡检指标配置
     *
     * @param checkConfig 自动巡检指标配置
     * @return 结果
     */
    @Override
    public int updateCheckConfig(CheckConfig checkConfig) {
                checkConfig.setUpdateTime(DateUtils.getNowDate());
        return checkConfigMapper.updateCheckConfig(checkConfig);
    }

    /**
     * 批量删除自动巡检指标配置
     *
     * @param ccIds 需要删除的自动巡检指标配置主键
     * @return 结果
     */
    @Override
    public int deleteCheckConfigByCcIds(Long[] ccIds) {
        return checkConfigMapper.deleteCheckConfigByCcIds(ccIds);
    }

    /**
     * 删除自动巡检指标配置信息
     *
     * @param ccId 自动巡检指标配置主键
     * @return 结果
     */
    @Override
    public int deleteCheckConfigByCcId(Long ccId) {
        return checkConfigMapper.deleteCheckConfigByCcId(ccId);
    }
}
