package com.jjt.hl.controller;

import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.hl.domain.HlClass;
import com.jjt.hl.service.IHlClassService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 模型健康度分类Controller
 *
 * @author jjt
 * @date 2024-09-05
 */
@Api(tags = "模型健康度分类")
@RestController
@RequestMapping("/hl/hc")
public class HlClassController extends BaseController {
    @Resource
    private IHlClassService hlClassService;

    /**
     * 查询模型健康度分类列表
     */
    @ApiOperation("查询模型健康度分类列表")
    //@PreAuthorize("@ss.hasPermi('hl:hc:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlClass hlClass) {
        startPage();
        List<HlClass> list = hlClassService.selectHlClassList(hlClass);
        return getDataTable(list);
    }

    /**
     * 导出模型健康度分类列表
     */
    @ApiOperation("导出模型健康度分类列表")
    //@PreAuthorize("@ss.hasPermi('hl:hc:export')")
    @Log(title = "模型健康度分类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlClass hlClass) {
        List<HlClass> list = hlClassService.selectHlClassList(hlClass);
        ExcelUtil<HlClass> util = new ExcelUtil<HlClass>(HlClass.class);
        util.exportExcel(response, list, "模型健康度分类数据");
    }

    /**
     * 获取模型健康度分类详细信息
     */
    @ApiOperation("获取模型健康度分类详细信息")
    //@PreAuthorize("@ss.hasPermi('hl:hc:query')")
    @GetMapping(value = "/{hlClassId}")
    public AjaxResult getInfo(@PathVariable("hlClassId") Long hlClassId) {
        return success(hlClassService.selectHlClassByHlClassId(hlClassId));
    }

    /**
     * 新增模型健康度分类
     */
    @ApiOperation("新增模型健康度分类")
    //@PreAuthorize("@ss.hasPermi('hl:hc:add')")
    @Log(title = "模型健康度分类", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlClass hlClass) {
        return toAjax(hlClassService.insertHlClass(hlClass));
    }

    /**
     * 修改模型健康度分类
     */
    @ApiOperation("修改模型健康度分类")
    //@PreAuthorize("@ss.hasPermi('hl:hc:edit')")
    @Log(title = "模型健康度分类", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody HlClass hlClass) {
        return toAjax(hlClassService.updateHlClass(hlClass));
    }

    /**
     * 删除模型健康度分类
     */
    @ApiOperation("删除模型健康度分类")
    //@PreAuthorize("@ss.hasPermi('hl:hc:remove')")
    @Log(title = "模型健康度分类", businessType = BusinessType.DELETE)
    @GetMapping("/del")
    public AjaxResult remove(Long[] hlClassIds) {
        return toAjax(hlClassService.deleteHlClassByHlClassIds(hlClassIds));
    }
}
