package com.jjt.hl.controller;

import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.hl.domain.HlClassScore;
import com.jjt.hl.service.IHlClassScoreService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 模型健康度分类得分Controller
 *
 * @author jjt
 * @date 2024-09-05
 */
@Api(tags = "模型健康度分类得分")
@RestController
@RequestMapping("/hl/hcs")
public class HlClassScoreController extends BaseController {
    @Resource
    private IHlClassScoreService hlClassScoreService;

    /**
     * 查询模型健康度分类得分列表
     */
    @ApiOperation("根据分数ID查询详细")
    @GetMapping("/detail")
    public AjaxResult list4score(Long id) {
        HlClassScore hlClassScore = new HlClassScore();
        hlClassScore.setHlScoreId(id);
        List<HlClassScore> list = hlClassScoreService.selectHlClassScoreList(hlClassScore);
        return AjaxResult.success(list);
    }

    @ApiOperation("查询模型健康度分类得分列表")
    //@PreAuthorize("@ss.hasPermi('hl:hcs:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlClassScore hlClassScore) {
        startPage();
        List<HlClassScore> list = hlClassScoreService.selectHlClassScoreList(hlClassScore);
        return getDataTable(list);
    }

    /**
     * 导出模型健康度分类得分列表
     */
    @ApiOperation("导出模型健康度分类得分列表")
    //@PreAuthorize("@ss.hasPermi('hl:hcs:export')")
    @Log(title = "模型健康度分类得分", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlClassScore hlClassScore) {
        List<HlClassScore> list = hlClassScoreService.selectHlClassScoreList(hlClassScore);
        ExcelUtil<HlClassScore> util = new ExcelUtil<HlClassScore>(HlClassScore.class);
        util.exportExcel(response, list, "模型健康度分类得分数据");
    }

    /**
     * 获取模型健康度分类得分详细信息
     */
    @ApiOperation("获取模型健康度分类得分详细信息")
    //@PreAuthorize("@ss.hasPermi('hl:hcs:query')")
    @GetMapping(value = "/{scoreClassId}")
    public AjaxResult getInfo(@PathVariable("scoreClassId") Long scoreClassId) {
        return success(hlClassScoreService.selectHlClassScoreByScoreClassId(scoreClassId));
    }

    /**
     * 新增模型健康度分类得分
     */
    @ApiOperation("新增模型健康度分类得分")
    //@PreAuthorize("@ss.hasPermi('hl:hcs:add')")
    @Log(title = "模型健康度分类得分", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlClassScore hlClassScore) {
        return toAjax(hlClassScoreService.insertHlClassScore(hlClassScore));
    }

    /**
     * 修改模型健康度分类得分
     */
    @ApiOperation("修改模型健康度分类得分")
    //@PreAuthorize("@ss.hasPermi('hl:hcs:edit')")
    @Log(title = "模型健康度分类得分", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody HlClassScore hlClassScore) {
        return toAjax(hlClassScoreService.updateHlClassScore(hlClassScore));
    }

    /**
     * 删除模型健康度分类得分
     */
    @ApiOperation("删除模型健康度分类得分")
    //@PreAuthorize("@ss.hasPermi('hl:hcs:remove')")
    @Log(title = "模型健康度分类得分", businessType = BusinessType.DELETE)
    @GetMapping("/del/{scoreClassIds}")
    public AjaxResult remove(@PathVariable Long[] scoreClassIds) {
        return toAjax(hlClassScoreService.deleteHlClassScoreByScoreClassIds(scoreClassIds));
    }
}
