package com.jjt.hl.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.hl.domain.HlEvent;
import com.jjt.hl.service.IHlEventService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 健康度事件记录Controller
 *
 * @author jjt
 * @date 2024-09-16
 */
@Api(tags="健康度事件记录")
@RestController
@RequestMapping("/hl/event")
public class HlEventController extends BaseController
{
    @Resource
    private IHlEventService hlEventService;

    /**
     * 查询健康度事件记录列表
     */
    @ApiOperation("查询健康度事件记录列表")
    //@PreAuthorize("@ss.hasPermi('hl:event:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlEvent hlEvent)
    {
        startPage();
        List<HlEvent> list = hlEventService.selectHlEventList(hlEvent);
        return getDataTable(list);
    }

    /**
     * 导出健康度事件记录列表
     */
    @ApiOperation("导出健康度事件记录列表")
    //@PreAuthorize("@ss.hasPermi('hl:event:export')")
    @Log(title = "健康度事件记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlEvent hlEvent)
    {
        List<HlEvent> list = hlEventService.selectHlEventList(hlEvent);
        ExcelUtil<HlEvent> util = new ExcelUtil<HlEvent>(HlEvent.class);
        util.exportExcel(response, list, "健康度事件记录数据");
    }

    /**
     * 获取健康度事件记录详细信息
     */
    @ApiOperation("获取健康度事件记录详细信息")
    //@PreAuthorize("@ss.hasPermi('hl:event:query')")
    @GetMapping(value = "/{eventId}")
    public AjaxResult getInfo(@PathVariable("eventId") Long eventId)
    {
        return success(hlEventService.selectHlEventByEventId(eventId));
    }

    /**
     * 新增健康度事件记录
     */
    @ApiOperation("新增健康度事件记录")
    //@PreAuthorize("@ss.hasPermi('hl:event:add')")
    @Log(title = "健康度事件记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlEvent hlEvent)
    {
        return toAjax(hlEventService.insertHlEvent(hlEvent));
    }

    /**
     * 修改健康度事件记录
     */
    @ApiOperation("修改健康度事件记录")
    //@PreAuthorize("@ss.hasPermi('hl:event:edit')")
    @Log(title = "健康度事件记录", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody HlEvent hlEvent)
    {
        return toAjax(hlEventService.updateHlEvent(hlEvent));
    }

    /**
     * 删除健康度事件记录
     */
    @ApiOperation("删除健康度事件记录")
    //@PreAuthorize("@ss.hasPermi('hl:event:remove')")
    @Log(title = "健康度事件记录", businessType = BusinessType.DELETE)
	@GetMapping("/del/{eventIds}")
    public AjaxResult remove(@PathVariable Long[] eventIds)
    {
        return toAjax(hlEventService.deleteHlEventByEventIds(eventIds));
    }
}
