package com.jjt.hl.controller;

import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.hl.domain.HlMetricsScore;
import com.jjt.hl.domain.HlMetricsScoreDetail;
import com.jjt.hl.service.IHlMetricsScoreDetailService;
import com.jjt.hl.service.IHlMetricsScoreService;
import com.jjt.hl.vo.ScoreDetailVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Random;

/**
 * 业务模型健康度指标得分Controller
 *
 * @author jjt
 * @date 2024-09-05
 */
@Api(tags = "业务模型健康度指标得分")
@RestController
@RequestMapping("/hl/hms")
public class HlMetricsScoreController extends BaseController {
    @Resource
    private IHlMetricsScoreService hlMetricsScoreService;
    @Resource
    private IHlMetricsScoreDetailService detailService;

    /**
     * 查询模型健康度分类得分列表
     */
    @ApiOperation("根据分类ID查询详细")
    @GetMapping("/list-id")
    public AjaxResult list4score(Long id) {
        HlMetricsScore hlMetricsScore = new HlMetricsScore();
        hlMetricsScore.setScoreClassId(id);
        List<HlMetricsScore> list = hlMetricsScoreService.selectHlMetricsScoreList(hlMetricsScore);
        return AjaxResult.success(list);
    }

    /**
     * 查询模型健康度分类得分列表
     */
    @ApiOperation("根据指标查询扣分明细")
    @GetMapping("/detail")
    public AjaxResult detail4score(Long scoreMetricsId) {
        List<ScoreDetailVO> list = detailService.detailList(scoreMetricsId);
        return AjaxResult.success(list);
    }

    /**
     * 查询业务模型健康度指标得分列表
     */
    @ApiOperation("查询业务模型健康度指标得分列表")
    //@PreAuthorize("@ss.hasPermi('hl:hms:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlMetricsScore hlMetricsScore) {
        startPage();
        List<HlMetricsScore> list = hlMetricsScoreService.selectHlMetricsScoreList(hlMetricsScore);
        return getDataTable(list);
    }

    /**
     * 导出业务模型健康度指标得分列表
     */
    @ApiOperation("导出业务模型健康度指标得分列表")
    //@PreAuthorize("@ss.hasPermi('hl:hms:export')")
    @Log(title = "业务模型健康度指标得分", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlMetricsScore hlMetricsScore) {
        List<HlMetricsScore> list = hlMetricsScoreService.selectHlMetricsScoreList(hlMetricsScore);
        ExcelUtil<HlMetricsScore> util = new ExcelUtil<HlMetricsScore>(HlMetricsScore.class);
        util.exportExcel(response, list, "业务模型健康度指标得分数据");
    }

    /**
     * 获取业务模型健康度指标得分详细信息
     */
    @ApiOperation("获取业务模型健康度指标得分详细信息")
    //@PreAuthorize("@ss.hasPermi('hl:hms:query')")
    @GetMapping(value = "/{scoreMetricsId}")
    public AjaxResult getInfo(@PathVariable("scoreMetricsId") Long scoreMetricsId) {
        return success(hlMetricsScoreService.selectHlMetricsScoreByScoreMetricsId(scoreMetricsId));
    }

    /**
     * 新增业务模型健康度指标得分
     */
    @ApiOperation("新增业务模型健康度指标得分")
    //@PreAuthorize("@ss.hasPermi('hl:hms:add')")
    @Log(title = "业务模型健康度指标得分", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlMetricsScore hlMetricsScore) {
        return toAjax(hlMetricsScoreService.insertHlMetricsScore(hlMetricsScore));
    }

    /**
     * 修改业务模型健康度指标得分
     */
    @ApiOperation("修改业务模型健康度指标得分")
    //@PreAuthorize("@ss.hasPermi('hl:hms:edit')")
    @Log(title = "业务模型健康度指标得分", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody HlMetricsScore hlMetricsScore) {
        return toAjax(hlMetricsScoreService.updateHlMetricsScore(hlMetricsScore));
    }

    /**
     * 删除业务模型健康度指标得分
     */
    @ApiOperation("删除业务模型健康度指标得分")
    //@PreAuthorize("@ss.hasPermi('hl:hms:remove')")
    @Log(title = "业务模型健康度指标得分", businessType = BusinessType.DELETE)
    @GetMapping("/del/{scoreMetricsIds}")
    public AjaxResult remove(@PathVariable Long[] scoreMetricsIds) {
        return toAjax(hlMetricsScoreService.deleteHlMetricsScoreByScoreMetricsIds(scoreMetricsIds));
    }
}
