package com.jjt.hl.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.hl.domain.HlMetricsScoreDetail;
import com.jjt.hl.service.IHlMetricsScoreDetailService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 业务模型健康度得分指标明细Controller
 *
 * @author jjt
 * @date 2024-09-05
 */
@Api(tags="业务模型健康度得分指标明细")
@RestController
@RequestMapping("/hl/hmsd")
public class HlMetricsScoreDetailController extends BaseController
{
    @Resource
    private IHlMetricsScoreDetailService hlMetricsScoreDetailService;

    /**
     * 查询业务模型健康度得分指标明细列表
     */
    @ApiOperation("查询业务模型健康度得分指标明细列表")
    //@PreAuthorize("@ss.hasPermi('hl:hmsd:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlMetricsScoreDetail hlMetricsScoreDetail)
    {
        startPage();
        List<HlMetricsScoreDetail> list = hlMetricsScoreDetailService.selectHlMetricsScoreDetailList(hlMetricsScoreDetail);
        return getDataTable(list);
    }

    /**
     * 导出业务模型健康度得分指标明细列表
     */
    @ApiOperation("导出业务模型健康度得分指标明细列表")
    //@PreAuthorize("@ss.hasPermi('hl:hmsd:export')")
    @Log(title = "业务模型健康度得分指标明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlMetricsScoreDetail hlMetricsScoreDetail)
    {
        List<HlMetricsScoreDetail> list = hlMetricsScoreDetailService.selectHlMetricsScoreDetailList(hlMetricsScoreDetail);
        ExcelUtil<HlMetricsScoreDetail> util = new ExcelUtil<HlMetricsScoreDetail>(HlMetricsScoreDetail.class);
        util.exportExcel(response, list, "业务模型健康度得分指标明细数据");
    }

    /**
     * 获取业务模型健康度得分指标明细详细信息
     */
    @ApiOperation("获取业务模型健康度得分指标明细详细信息")
    //@PreAuthorize("@ss.hasPermi('hl:hmsd:query')")
    @GetMapping(value = "/{scoreDetailId}")
    public AjaxResult getInfo(@PathVariable("scoreDetailId") Long scoreDetailId)
    {
        return success(hlMetricsScoreDetailService.selectHlMetricsScoreDetailByScoreDetailId(scoreDetailId));
    }

    /**
     * 新增业务模型健康度得分指标明细
     */
    @ApiOperation("新增业务模型健康度得分指标明细")
    //@PreAuthorize("@ss.hasPermi('hl:hmsd:add')")
    @Log(title = "业务模型健康度得分指标明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlMetricsScoreDetail hlMetricsScoreDetail)
    {
        return toAjax(hlMetricsScoreDetailService.insertHlMetricsScoreDetail(hlMetricsScoreDetail));
    }

    /**
     * 修改业务模型健康度得分指标明细
     */
    @ApiOperation("修改业务模型健康度得分指标明细")
    //@PreAuthorize("@ss.hasPermi('hl:hmsd:edit')")
    @Log(title = "业务模型健康度得分指标明细", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody HlMetricsScoreDetail hlMetricsScoreDetail)
    {
        return toAjax(hlMetricsScoreDetailService.updateHlMetricsScoreDetail(hlMetricsScoreDetail));
    }

    /**
     * 删除业务模型健康度得分指标明细
     */
    @ApiOperation("删除业务模型健康度得分指标明细")
    //@PreAuthorize("@ss.hasPermi('hl:hmsd:remove')")
    @Log(title = "业务模型健康度得分指标明细", businessType = BusinessType.DELETE)
	@GetMapping("/del/{scoreDetailIds}")
    public AjaxResult remove(@PathVariable Long[] scoreDetailIds)
    {
        return toAjax(hlMetricsScoreDetailService.deleteHlMetricsScoreDetailByScoreDetailIds(scoreDetailIds));
    }
}
