package com.jjt.hl.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.hl.domain.HlMetricsScoreView;
import com.jjt.hl.service.IHlMetricsScoreViewService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 业务模型健康度得分指标查看Controller
 *
 * @author jjt
 * @date 2024-09-23
 */
@Api(tags="业务模型健康度得分指标查看")
@RestController
@RequestMapping("/hl/hlView")
public class HlMetricsScoreViewController extends BaseController
{
    @Resource
    private IHlMetricsScoreViewService hlMetricsScoreViewService;

    /**
     * 查询业务模型健康度得分指标查看列表
     */
    @ApiOperation("查询业务模型健康度得分指标查看列表")
    //@PreAuthorize("@ss.hasPermi('hl:hlView:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlMetricsScoreView hlMetricsScoreView)
    {
        startPage();
        List<HlMetricsScoreView> list = hlMetricsScoreViewService.selectHlMetricsScoreViewList(hlMetricsScoreView);
        return getDataTable(list);
    }

    /**
     * 导出业务模型健康度得分指标查看列表
     */
    @ApiOperation("导出业务模型健康度得分指标查看列表")
    //@PreAuthorize("@ss.hasPermi('hl:hlView:export')")
    @Log(title = "业务模型健康度得分指标查看", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlMetricsScoreView hlMetricsScoreView)
    {
        List<HlMetricsScoreView> list = hlMetricsScoreViewService.selectHlMetricsScoreViewList(hlMetricsScoreView);
        ExcelUtil<HlMetricsScoreView> util = new ExcelUtil<HlMetricsScoreView>(HlMetricsScoreView.class);
        util.exportExcel(response, list, "业务模型健康度得分指标查看数据");
    }

    /**
     * 获取业务模型健康度得分指标查看详细信息
     */
    @ApiOperation("获取业务模型健康度得分指标查看详细信息")
    //@PreAuthorize("@ss.hasPermi('hl:hlView:query')")
    @GetMapping(value = "/{scoreDetailId}")
    public AjaxResult getInfo(@PathVariable("scoreDetailId") Long scoreDetailId)
    {
        return success(hlMetricsScoreViewService.selectHlMetricsScoreViewByScoreDetailId(scoreDetailId));
    }

    /**
     * 新增业务模型健康度得分指标查看
     */
    @ApiOperation("新增业务模型健康度得分指标查看")
    //@PreAuthorize("@ss.hasPermi('hl:hlView:add')")
    @Log(title = "业务模型健康度得分指标查看", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlMetricsScoreView hlMetricsScoreView)
    {
        return toAjax(hlMetricsScoreViewService.insertHlMetricsScoreView(hlMetricsScoreView));
    }

    /**
     * 修改业务模型健康度得分指标查看
     */
    @ApiOperation("修改业务模型健康度得分指标查看")
    //@PreAuthorize("@ss.hasPermi('hl:hlView:edit')")
    @Log(title = "业务模型健康度得分指标查看", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody HlMetricsScoreView hlMetricsScoreView)
    {
        return toAjax(hlMetricsScoreViewService.updateHlMetricsScoreView(hlMetricsScoreView));
    }

    /**
     * 删除业务模型健康度得分指标查看
     */
    @ApiOperation("删除业务模型健康度得分指标查看")
    //@PreAuthorize("@ss.hasPermi('hl:hlView:remove')")
    @Log(title = "业务模型健康度得分指标查看", businessType = BusinessType.DELETE)
	@GetMapping("/del/{scoreDetailIds}")
    public AjaxResult remove(@PathVariable Long[] scoreDetailIds)
    {
        return toAjax(hlMetricsScoreViewService.deleteHlMetricsScoreViewByScoreDetailIds(scoreDetailIds));
    }
}
