package com.jjt.hl.controller;

import com.jjt.biz.domain.BizModelDetail;
import com.jjt.biz.service.IBizModelDetailService;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.hl.domain.HlClass;
import com.jjt.hl.domain.HlObj;
import com.jjt.hl.service.IHlClassService;
import com.jjt.hl.service.IHlObjService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 模型健康度对象Controller
 *
 * @author jjt
 * @date 2024-09-05
 */
@Api(tags = "模型健康度对象")
@RestController
@RequestMapping("/hl/ho")
public class HlObjController extends BaseController {
    @Resource
    private IHlObjService hlObjService;
    @Resource
    private IHlClassService hlClassService;
    @Resource
    private IBizModelDetailService modelDetailService;

    @ApiOperation("根据分类ID查询对象")
    @GetMapping("/list-class")
    public AjaxResult list(Long hlClassId) {
        HlObj hlObj = new HlObj();
        hlObj.setHlClassId(hlClassId);
        List<HlObj> list = hlObjService.selectHlObjList(hlObj);
        return AjaxResult.success(list);
    }

    @ApiOperation("根据分类ID查询选择对象列表")
    @GetMapping("/select")
    public AjaxResult select(Long hlClassId) {
        HlClass hlClass = hlClassService.selectHlClassByHlClassId(hlClassId);

        BizModelDetail detail = new BizModelDetail();
        detail.setModelId(hlClass.getModelId());
        Map<String, Object> params = new HashMap<>();
        params.put("objType", hlClass.getObjType());
        params.put("cid", hlClassId);
        detail.setParams(params);

        List<BizModelDetail> list = modelDetailService.selectBizModelDetailList(detail);

        return AjaxResult.success(list);
    }

    @ApiOperation("添加对象")
    @GetMapping("/add")
    public AjaxResult objAdd(@ApiParam(value = "分类ID", required = true) Long hlClassId, @ApiParam(value = "对象ID数组", required = true) Long[] objIds) {
        return success(hlObjService.insertObj(hlClassId, objIds));
    }


    /**
     * 查询模型健康度对象列表
     */
    @ApiOperation("查询模型健康度对象列表")
    //@PreAuthorize("@ss.hasPermi('hl:ho:list')")
    @GetMapping("/list")
    public TableDataInfo list(HlObj hlObj) {
        startPage();
        List<HlObj> list = hlObjService.selectHlObjList(hlObj);
        return getDataTable(list);
    }

    /**
     * 导出模型健康度对象列表
     */
    @ApiOperation("导出模型健康度对象列表")
    //@PreAuthorize("@ss.hasPermi('hl:ho:export')")
    @Log(title = "模型健康度对象", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlObj hlObj) {
        List<HlObj> list = hlObjService.selectHlObjList(hlObj);
        ExcelUtil<HlObj> util = new ExcelUtil<HlObj>(HlObj.class);
        util.exportExcel(response, list, "模型健康度对象数据");
    }

    /**
     * 获取模型健康度对象详细信息
     */
    @ApiOperation("获取模型健康度对象详细信息")
    //@PreAuthorize("@ss.hasPermi('hl:ho:query')")
    @GetMapping(value = "/{hlObjId}")
    public AjaxResult getInfo(@PathVariable("hlObjId") Long hlObjId) {
        return success(hlObjService.selectHlObjByHlObjId(hlObjId));
    }

    /**
     * 新增模型健康度对象
     */
    @ApiOperation("新增模型健康度对象")
    //@PreAuthorize("@ss.hasPermi('hl:ho:add')")
    @Log(title = "模型健康度对象", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlObj hlObj) {
        return toAjax(hlObjService.insertHlObj(hlObj));
    }

    /**
     * 修改模型健康度对象
     */
    @ApiOperation("修改模型健康度对象")
    //@PreAuthorize("@ss.hasPermi('hl:ho:edit')")
    @Log(title = "模型健康度对象", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody HlObj hlObj) {
        return toAjax(hlObjService.updateHlObj(hlObj));
    }

    /**
     * 删除模型健康度对象
     */
    @ApiOperation("删除模型健康度对象")
    //@PreAuthorize("@ss.hasPermi('hl:ho:remove')")
    @Log(title = "模型健康度对象", businessType = BusinessType.DELETE)
    @GetMapping("/del")
    public AjaxResult remove(Long[] hlObjIds) {
        return toAjax(hlObjService.deleteHlObjByHlObjIds(hlObjIds));
    }
}
