package com.jjt.hl.controller;

import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.hl.domain.HlScore;
import com.jjt.hl.service.IHlScoreService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 健康度分数记录Controller
 *
 * @author jjt
 * @date 2024-09-05
 */
@Api(tags = "健康度分数记录")
@RestController
@RequestMapping("/hl/hs")
public class HlScoreController extends BaseController {
    @Resource
    private IHlScoreService hlScoreService;

    /**
     * 查询健康度分数记录列表
     */
    @ApiOperation("查询健康度分数记录列表")
    @GetMapping("/list")
    public TableDataInfo list(HlScore hlScore) {
        startPage();
        List<HlScore> list = hlScoreService.selectHlScoreList(hlScore);
        return getDataTable(list);
    }

    /**
     * 查询健康度分数记录列表
     */
    @ApiOperation("历史健康度列表")
    @GetMapping("/time/list")
    public TableDataInfo timeList(HlScore hlScore) {
        startPage();
        //type=1表示历史健康度
        hlScore.setHlType("1");
        List<HlScore> list = hlScoreService.selectHlScoreList(hlScore);
        return getDataTable(list);
    }

    /**
     * 查询健康度分数记录列表
     */
    @ApiOperation("日健康度列表")
    @GetMapping("/day/list")
    public TableDataInfo dayList(HlScore hlScore) {
        startPage();
        //type=2表示日健康度
        hlScore.setHlType("2");
        List<HlScore> list = hlScoreService.selectHlScoreList(hlScore);
        return getDataTable(list);
    }

    /**
     * 导出健康度分数记录列表
     */
    @ApiOperation("导出健康度分数记录列表")
    //@PreAuthorize("@ss.hasPermi('hl:hs:export')")
    @Log(title = "健康度分数记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HlScore hlScore) {
        List<HlScore> list = hlScoreService.selectHlScoreList(hlScore);
        ExcelUtil<HlScore> util = new ExcelUtil<HlScore>(HlScore.class);
        util.exportExcel(response, list, "健康度分数记录数据");
    }

    /**
     * 获取健康度分数记录详细信息
     */
    @ApiOperation("获取健康度分数记录详细信息")
    //@PreAuthorize("@ss.hasPermi('hl:hs:query')")
    @GetMapping(value = "/{hlScoreId}")
    public AjaxResult getInfo(@PathVariable("hlScoreId") Long hlScoreId) {
        return success(hlScoreService.selectHlScoreByHlScoreId(hlScoreId));
    }

    /**
     * 新增健康度分数记录
     */
    @ApiOperation("新增健康度分数记录")
    //@PreAuthorize("@ss.hasPermi('hl:hs:add')")
    @Log(title = "健康度分数记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody HlScore hlScore) {
        return toAjax(hlScoreService.insertHlScore(hlScore));
    }

    /**
     * 修改健康度分数记录
     */
    @ApiOperation("修改健康度分数记录")
    //@PreAuthorize("@ss.hasPermi('hl:hs:edit')")
    @Log(title = "健康度分数记录", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody HlScore hlScore) {
        return toAjax(hlScoreService.updateHlScore(hlScore));
    }

    /**
     * 删除健康度分数记录
     */
    @ApiOperation("删除健康度分数记录")
    //@PreAuthorize("@ss.hasPermi('hl:hs:remove')")
    @Log(title = "健康度分数记录", businessType = BusinessType.DELETE)
    @GetMapping("/del/{hlScoreIds}")
    public AjaxResult remove(@PathVariable Long[] hlScoreIds) {
        return toAjax(hlScoreService.deleteHlScoreByHlScoreIds(hlScoreIds));
    }
}
