package com.jjt.hl.service;

import com.jjt.biz.domain.BizObjMetrics;
import com.jjt.hl.domain.HlEvent;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 健康度事件记录Service接口
 *
 * @author jjt
 * @date 2024-09-16
 */
public interface IHlEventService {
    /**
     * 查询健康度事件记录
     *
     * @param eventId 健康度事件记录主键
     * @return 健康度事件记录
     */
    public HlEvent selectHlEventByEventId(Long eventId);

    /**
     * 查询健康度事件记录列表
     *
     * @param hlEvent 健康度事件记录
     * @return 健康度事件记录集合
     */
    public List<HlEvent> selectHlEventList(HlEvent hlEvent);

    /**
     * 新增健康度事件记录
     *
     * @param hlEvent 健康度事件记录
     * @return 结果
     */
    public int insertHlEvent(HlEvent hlEvent);

    /**
     * 修改健康度事件记录
     *
     * @param hlEvent 健康度事件记录
     * @return 结果
     */
    public int updateHlEvent(HlEvent hlEvent);

    /**
     * 批量删除健康度事件记录
     *
     * @param eventIds 需要删除的健康度事件记录主键集合
     * @return 结果
     */
    public int deleteHlEventByEventIds(Long[] eventIds);

    /**
     * 删除健康度事件记录信息
     *
     * @param eventId 健康度事件记录主键
     * @return 结果
     */
    public int deleteHlEventByEventId(Long eventId);

    /**
     * 处理事件
     *
     * @param om       指标对象
     * @param eventMap 当前事件列表
     * @param date     时间
     * @return 结果
     */
    Map<String, HlEvent> process(BizObjMetrics om, Map<Long, HlEvent> eventMap, Date date);

    /**
     * 通过对象ID查询当前事件的列表,并转换成map
     *
     * @param objId 对象ID
     * @return 结果
     */
    Map<Long, HlEvent> selectHlEventListCurr(Long objId);
}
