package com.jjt.hl.service;

import com.jjt.biz.domain.BizObjMetrics;
import com.jjt.hl.domain.HlMetrics;
import com.jjt.hl.vo.HlMetricsVO;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 业务模型健康度指标Service接口
 *
 * @author jjt
 * @date 2024-09-05
 */
public interface IHlMetricsService {
    /**
     * 查询业务模型健康度指标
     *
     * @param hlMetricsId 业务模型健康度指标主键
     * @return 业务模型健康度指标
     */
    public HlMetrics selectHlMetricsByHlMetricsId(Long hlMetricsId);

    /**
     * 查询业务模型健康度指标列表
     *
     * @param hlMetrics 业务模型健康度指标
     * @return 业务模型健康度指标集合
     */
    public List<HlMetrics> selectHlMetricsList(HlMetrics hlMetrics);

    /**
     * 新增业务模型健康度指标
     *
     * @param hlMetrics 业务模型健康度指标
     * @return 结果
     */
    public int insertHlMetrics(HlMetrics hlMetrics);

    /**
     * 修改业务模型健康度指标
     *
     * @param hlMetrics 业务模型健康度指标
     * @return 结果
     */
    public int updateHlMetrics(HlMetrics hlMetrics);

    /**
     * 批量删除业务模型健康度指标
     *
     * @param hlMetricsIds 需要删除的业务模型健康度指标主键集合
     * @return 结果
     */
    public int deleteHlMetricsByHlMetricsIds(Long[] hlMetricsIds);

    /**
     * 删除业务模型健康度指标信息
     *
     * @param hlMetricsId 业务模型健康度指标主键
     * @return 结果
     */
    public int deleteHlMetricsByHlMetricsId(Long hlMetricsId);

    /**
     * 查询指标列表
     *
     * @param modelId 模型ID
     * @param objType 对象类型
     * @return
     */
    List<HlMetrics> selectHlMetricsList4ModelId(Long modelId, String objType);

    /**
     * 添加指标
     *
     * @param hlClassId 分类ID
     * @param ids       指标IDS
     * @return 结果
     */
    int insertMetrics(Long hlClassId, Long[] ids);

    /**
     * 根据健康度分类获取所有指标对象
     * 并按metricsId分组
     *
     * @param hlClassId 健康度分类ID
     * @return 结果
     */
    Map<Long,List<HlMetricsVO>> hlMetricsList(Long hlClassId);
    /**
     * 根据日期和模型查询所有存在单次扣分的指标
     * 并按metricsId分组
     *
     * @param modelId 健康度分类ID
     * @param date 日期
     * @return 结果
     */
    Map<Long, List<HlMetricsVO>> hlMetricsDayList(Long modelId, Date date);

    /**
     * 根据类型ID删除
     * @param hlClassId 类型ID
     */
    void deleteHlMetricsByClassId(Long hlClassId);
}
