package com.jjt.hl.service;

import com.jjt.biz.vo.HlScoreVO;
import com.jjt.hl.domain.HlScore;

import java.util.Date;
import java.util.List;

/**
 * 健康度分数记录Service接口
 *
 * @author jjt
 * @date 2024-09-05
 */
public interface IHlScoreService {
    /**
     * 查询健康度分数记录
     *
     * @param hlScoreId 健康度分数记录主键
     * @return 健康度分数记录
     */
    public HlScore selectHlScoreByHlScoreId(Long hlScoreId);

    /**
     * 查询健康度分数记录列表
     *
     * @param hlScore 健康度分数记录
     * @return 健康度分数记录集合
     */
    public List<HlScore> selectHlScoreList(HlScore hlScore);

    /**
     * 新增健康度分数记录
     *
     * @param hlScore 健康度分数记录
     * @return 结果
     */
    public int insertHlScore(HlScore hlScore);

    /**
     * 修改健康度分数记录
     *
     * @param hlScore 健康度分数记录
     * @return 结果
     */
    public int updateHlScore(HlScore hlScore);

    /**
     * 批量删除健康度分数记录
     *
     * @param hlScoreIds 需要删除的健康度分数记录主键集合
     * @return 结果
     */
    public int deleteHlScoreByHlScoreIds(Long[] hlScoreIds);

    /**
     * 删除健康度分数记录信息
     *
     * @param hlScoreId 健康度分数记录主键
     * @return 结果
     */
    public int deleteHlScoreByHlScoreId(Long hlScoreId);

    /**
     * 健康度评分
     */
    void score();

    /**
     * 按模型ID进行评分
     *
     * @param modelId 模型ID
     */
    void score(Long modelId);

    /**
     * 日健康度评分
     *
     * @param date 时间
     */
    void day(Date date);

    /**
     * 日健康度评分
     *
     * @param date    时间
     * @param modelId 模型Id
     */
    void day(Date date, Long modelId);

    /**
     * 获取最近一次健康度得分
     * @return 结果
     */
    List<HlScoreVO> selectHlScoreListLast();
}
