package com.jjt.hl.service.impl;

import com.jjt.common.utils.DateUtils;
import com.jjt.hl.domain.HlClass;
import com.jjt.hl.mapper.HlClassMapper;
import com.jjt.hl.service.IHlClassService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 模型健康度分类Service业务层处理
 *
 * @author jjt
 * @date 2024-09-05
 */
@Service
public class HlClassServiceImpl implements IHlClassService {
    @Resource
    private HlClassMapper hlClassMapper;

    /**
     * 查询模型健康度分类
     *
     * @param hlClassId 模型健康度分类主键
     * @return 模型健康度分类
     */
    @Override
    public HlClass selectHlClassByHlClassId(Long hlClassId) {
        return hlClassMapper.selectHlClassByHlClassId(hlClassId);
    }

    /**
     * 查询模型健康度分类列表
     *
     * @param hlClass 模型健康度分类
     * @return 模型健康度分类
     */
    @Override
    public List<HlClass> selectHlClassList(HlClass hlClass) {
        return hlClassMapper.selectHlClassList(hlClass);
    }

    /**
     * 新增模型健康度分类
     *
     * @param hlClass 模型健康度分类
     * @return 结果
     */
    @Override
    public int insertHlClass(HlClass hlClass) {
        hlClass.setCreateTime(DateUtils.getNowDate());
        return hlClassMapper.insertHlClass(hlClass);
    }

    /**
     * 修改模型健康度分类
     *
     * @param hlClass 模型健康度分类
     * @return 结果
     */
    @Override
    public int updateHlClass(HlClass hlClass) {
        hlClass.setUpdateTime(DateUtils.getNowDate());
        return hlClassMapper.updateHlClass(hlClass);
    }

    /**
     * 批量删除模型健康度分类
     *
     * @param hlClassIds 需要删除的模型健康度分类主键
     * @return 结果
     */
    @Override
    public int deleteHlClassByHlClassIds(Long[] hlClassIds) {
        return hlClassMapper.deleteHlClassByHlClassIds(hlClassIds);
    }

    /**
     * 删除模型健康度分类信息
     *
     * @param hlClassId 模型健康度分类主键
     * @return 结果
     */
    @Override
    public int deleteHlClassByHlClassId(Long hlClassId) {
        return hlClassMapper.deleteHlClassByHlClassId(hlClassId);
    }

    /**
     * 通过模型ID获取 分类列表
     *
     * @param modelId 模型ID
     * @return 结果
     */
    @Override
    public List<HlClass> selectHlClassList4modelId(Long modelId) {
        HlClass query = new HlClass();
        query.setModelId(modelId);
        return selectHlClassList(query);
    }
}
