package com.jjt.hl.service.impl;

import com.jjt.common.utils.DateUtils;
import com.jjt.hl.domain.HlObj;
import com.jjt.hl.mapper.HlObjMapper;
import com.jjt.hl.service.IHlObjService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 模型健康度对象Service业务层处理
 *
 * @author jjt
 * @date 2024-09-05
 */
@Service
public class HlObjServiceImpl implements IHlObjService {
    @Resource
    private HlObjMapper hlObjMapper;

    /**
     * 查询模型健康度对象
     *
     * @param hlObjId 模型健康度对象主键
     * @return 模型健康度对象
     */
    @Override
    public HlObj selectHlObjByHlObjId(Long hlObjId) {
        return hlObjMapper.selectHlObjByHlObjId(hlObjId);
    }

    /**
     * 查询模型健康度对象列表
     *
     * @param hlObj 模型健康度对象
     * @return 模型健康度对象
     */
    @Override
    public List<HlObj> selectHlObjList(HlObj hlObj) {
        return hlObjMapper.selectHlObjList(hlObj);
    }

    /**
     * 新增模型健康度对象
     *
     * @param hlObj 模型健康度对象
     * @return 结果
     */
    @Override
    public int insertHlObj(HlObj hlObj) {
        hlObj.setCreateTime(DateUtils.getNowDate());
        return hlObjMapper.insertHlObj(hlObj);
    }

    /**
     * 修改模型健康度对象
     *
     * @param hlObj 模型健康度对象
     * @return 结果
     */
    @Override
    public int updateHlObj(HlObj hlObj) {
        hlObj.setUpdateTime(DateUtils.getNowDate());
        return hlObjMapper.updateHlObj(hlObj);
    }

    /**
     * 批量删除模型健康度对象
     *
     * @param hlObjIds 需要删除的模型健康度对象主键
     * @return 结果
     */
    @Override
    public int deleteHlObjByHlObjIds(Long[] hlObjIds) {
        return hlObjMapper.deleteHlObjByHlObjIds(hlObjIds);
    }

    /**
     * 删除模型健康度对象信息
     *
     * @param hlObjId 模型健康度对象主键
     * @return 结果
     */
    @Override
    public int deleteHlObjByHlObjId(Long hlObjId) {
        return hlObjMapper.deleteHlObjByHlObjId(hlObjId);
    }

    /**
     * 添加对象
     *
     * @param hlClassId 分类ID
     * @param objIds    对象ID
     * @return 结果
     */
    @Override
    public int insertObj(Long hlClassId, Long[] objIds) {
        if (objIds.length == 0) {
            return 1;
        }
        for (Long objId : objIds) {
            HlObj hlObj = new HlObj();
            hlObj.setHlClassId(hlClassId);
            hlObj.setObjId(objId);
            insertHlObj(hlObj);
        }
        return 0;
    }

    /**
     * 通过hlClassId获取列表
     *
     * @param hlClassId classid
     * @return 结果
     */
    @Override
    public List<HlObj> selectHlObjListByClassId(Long hlClassId) {
        HlObj obj = new HlObj();
        obj.setHlClassId(hlClassId);
        return selectHlObjList(obj);
    }
}
