package com.jjt.hl.service.impl;

import com.googlecode.aviator.AviatorEvaluator;
import com.jjt.biz.domain.BizModel;
import com.jjt.biz.service.IBizModelService;
import com.jjt.biz.vo.HlScoreVO;
import com.jjt.common.utils.DateUtils;
import com.jjt.common.utils.bean.BeanUtils;
import com.jjt.hl.domain.*;
import com.jjt.hl.mapper.HlMetricsScoreDetailMapper;
import com.jjt.hl.mapper.HlMetricsScoreViewMapper;
import com.jjt.hl.mapper.HlScoreMapper;
import com.jjt.hl.service.*;
import com.jjt.hl.vo.HlMetricsVO;
import org.apache.ibatis.session.ExecutorType;
import org.apache.ibatis.session.SqlSession;
import org.apache.ibatis.session.SqlSessionFactory;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * 健康度分数记录Service业务层处理
 *
 * @author jjt
 * @date 2024-09-05
 */
@Service
public class HlScoreServiceImpl implements IHlScoreService {
    @Resource
    private HlScoreMapper hlScoreMapper;
    @Resource
    private IBizModelService modelService;
    @Resource
    private IHlClassScoreService hlClassScoreService;
    @Resource
    private IHlObjService hlObjService;
    @Resource
    private IHlMetricsService hlMetricsService;
    @Resource
    private IHlMetricsScoreService hlMetricsScoreService;
    @Resource
    private JdbcTemplate jdbcTemplate;
    @Resource
    private SqlSessionFactory factory;

    /**
     * 查询健康度分数记录
     *
     * @param hlScoreId 健康度分数记录主键
     * @return 健康度分数记录
     */
    @Override

    public HlScore selectHlScoreByHlScoreId(Long hlScoreId) {
        return hlScoreMapper.selectHlScoreByHlScoreId(hlScoreId);
    }

    /**
     * 查询健康度分数记录列表
     *
     * @param hlScore 健康度分数记录
     * @return 健康度分数记录
     */
    @Override
    public List<HlScore> selectHlScoreList(HlScore hlScore) {
        return hlScoreMapper.selectHlScoreList(hlScore);
    }

    /**
     * 新增健康度分数记录
     *
     * @param hlScore 健康度分数记录
     * @return 结果
     */
    @Override
    public int insertHlScore(HlScore hlScore) {
        hlScore.setCreateTime(DateUtils.getNowDate());
        return hlScoreMapper.insertHlScore(hlScore);
    }

    /**
     * 修改健康度分数记录
     *
     * @param hlScore 健康度分数记录
     * @return 结果
     */
    @Override
    public int updateHlScore(HlScore hlScore) {
        hlScore.setUpdateTime(DateUtils.getNowDate());
        return hlScoreMapper.updateHlScore(hlScore);
    }

    /**
     * 批量删除健康度分数记录
     *
     * @param hlScoreIds 需要删除的健康度分数记录主键
     * @return 结果
     */
    @Override
    public int deleteHlScoreByHlScoreIds(Long[] hlScoreIds) {
        return hlScoreMapper.deleteHlScoreByHlScoreIds(hlScoreIds);
    }

    /**
     * 删除健康度分数记录信息
     *
     * @param hlScoreId 健康度分数记录主键
     * @return 结果
     */
    @Override
    public int deleteHlScoreByHlScoreId(Long hlScoreId) {
        return hlScoreMapper.deleteHlScoreByHlScoreId(hlScoreId);
    }

    /**
     * 健康度评分
     */
    @Override
    public void score() {
        //暂时先模拟分数
        //1.获取所有模型
        //2.获取模型健康度指标分类
        //3.1.获取对象
        //3.2.获取指标
        //
        List<BizModel> modelList = modelService.selectBizModelList(new BizModel());
        Date curr = new Date();
        for (BizModel model : modelList) {
            HlScore score = new HlScore();
            score.setModelId(model.getModelId());
            score.setHlDate(curr);
            score.setHlType("1");
            insertHlScore(score);
            BigDecimal totalLose = BigDecimal.ZERO;
            List<HlClass> classList = modelService.selectHlClassList4modelId(model.getModelId());
            for (HlClass hlClass : classList) {
                HlClassScore hlClassScore = new HlClassScore();
                BeanUtils.copyBeanProp(hlClassScore, hlClass);
                hlClassScore.setHlScoreId(score.getHlScoreId());
                List<HlObj> hlObjList = hlObjService.selectHlObjListByClassId(hlClass.getHlClassId());
                hlClassScoreService.insertHlClassScore(hlClassScore);
                HlMetrics hm = new HlMetrics();
                hm.setHlClassId(hlClass.getHlClassId());
                List<HlMetrics> hlMetricsList = hlMetricsService.selectHlMetricsList(hm);
                BigDecimal loseScore = BigDecimal.ZERO;
                //1.均分 2.细项分
//                hlClass.getScoreType();
                for (HlMetrics hlMetrics : hlMetricsList) {
                    //TODO ..这里需要从对象指标表里面去找。
//                    BizObjMetrics
//                    BizObjMetricsData
                    BigDecimal ss = random(hlMetrics.getHlScore().intValue());
                    BigDecimal lose = hlMetrics.getHlScore().subtract(ss);
                    loseScore = loseScore.add(lose);
                    HlMetricsScore metricsScore = new HlMetricsScore();
                    BeanUtils.copyBeanProp(metricsScore, hlMetrics);
                    metricsScore.setLoseScore(lose);
                    metricsScore.setScore(ss);
                    metricsScore.setScoreClassId(hlClassScore.getScoreClassId());
                    hlMetricsScoreService.insertHlMetricsScore(metricsScore);
//                    if (flag()) {
//                        //TODO 模拟扣分判断
//                        if ("1".equals(hlClassScore.getScoreType())) {
//                            //均分
////                            Random
//                        } else {
//                            //细项分
//                        }
//                    }
                }
                hlClassScore.setLoseScore(loseScore);
                totalLose = totalLose.add(loseScore);
                BigDecimal df = hlClassScore.getHlScore().subtract(loseScore);
                hlClassScore.setScore(df);
                hlClassScoreService.updateHlClassScore(hlClassScore);
            }

            score.setHlScore(BigDecimal.valueOf(100).subtract(totalLose));
            updateHlScore(score);
        }
    }

    /**
     * 按模型ID进行评分
     *
     * @param modelId 模型ID
     */
    @Override
    public void score(Long modelId) {
        HlScore score = new HlScore();
        score.setModelId(modelId);
        score.setHlDate(new Date());
        //单次评分
        score.setHlType("1");
        insertHlScore(score);
        BigDecimal totalScore = BigDecimal.ZERO;
        //查找健康度分类
        List<HlClass> classList = modelService.selectHlClassList4modelId(modelId);
        List<HlMetricsScoreDetail> details = new ArrayList<>();
        List<HlMetricsScoreView> views = new ArrayList<>();
        for (HlClass hlClass : classList) {
            HlClassScore hlClassScore = new HlClassScore();
            BeanUtils.copyBeanProp(hlClassScore, hlClass);
            hlClassScore.setHlScoreId(score.getHlScoreId());
            hlClassScore.setScore(BigDecimal.ZERO);
            if (hlClass.getHlScore() == null || hlClass.getHlScore().compareTo(BigDecimal.ZERO) == 0) {
                continue;
            }
            hlClassScoreService.insertHlClassScore(hlClassScore);
            HlMetrics hm = new HlMetrics();
            hm.setHlClassId(hlClass.getHlClassId());
            List<HlMetrics> hlMetricsList = hlMetricsService.selectHlMetricsList(hm);
            //所有指标
            Map<Long, List<HlMetricsVO>> metricsMap = hlMetricsService.hlMetricsList(hlClass.getHlClassId());

            BigDecimal lostClass = BigDecimal.ZERO;

            for (HlMetrics hlMetrics : hlMetricsList) {
                if ("1".equals(hlClass.getScoreType())) {
                    //1.均分 2.细项分
                    //如果是均分，需要计算，如果是细项分，直接用
                    BigDecimal metricsScore = hlClass.getHlScore().divide(BigDecimal.valueOf(hlMetricsList.size()), RoundingMode.HALF_UP);
                    hlMetrics.setHlScore(metricsScore);
                }

                List<HlMetricsVO> vos = metricsMap.get(hlMetrics.getMetricsId());
                if (vos == null || vos.size() == 0) {
                    //如果没有查到指标，继续下一盘
                    continue;
                }
                //扣分
                BigDecimal lost = BigDecimal.ZERO;
                //指标总数也
                int total = vos.size();
                //评分标准 1.当前值  2.持续1小时值
                int eventNum = 0;
                List<Long> eventIds = new ArrayList<>();
                List<HlMetricsScoreView> viewList = new ArrayList<>();
                for (HlMetricsVO vo : vos) {
                    //加这个是，不管有没有事件，都需要查看当时的值
                    HlMetricsScoreView view = new HlMetricsScoreView();
                    view.setdValue(vo.getDValue());
                    view.setObjMetricsId(vo.getObjMetricsId());
                    viewList.add(view);
                    if (vo.getEventId() != null) {
                        eventIds.add(vo.getEventId());
                        if ("1".equals(hlMetrics.getHlStand())) {
                            //有事件就扣分
                            eventNum++;
                        } else {
                            //需要判断是否持续1小时
                            if (vo.getEndTime() == null) {
                                //如果没有结束时间，则判断至当前是否已经到1小时
                                vo.setEndTime(new Date());
                            }
                            if (vo.getEndTime().getTime() - vo.getStartTime().getTime() > 3600 * 1000) {
                                eventNum++;
                            }
                        }
                    }
                }
                //（告警组件数量/总数量 ）*细项分
                if (eventNum > 0) {
                    lost = BigDecimal.valueOf(eventNum).divide(BigDecimal.valueOf(total),2, RoundingMode.HALF_UP).multiply(hlMetrics.getHlScore());
                }
                //最终得分 = 分数-扣分
                BigDecimal score2 = BigDecimal.ZERO;
                if (hlMetrics.getHlScore() != null) {
                    if (hlMetrics.getHlScore().compareTo(lost) >= 0) {
                        score2 = hlMetrics.getHlScore().subtract(lost);
                    }
                }
                HlMetricsScore metricsScore = new HlMetricsScore();
                BeanUtils.copyBeanProp(metricsScore, hlMetrics);
                metricsScore.setLoseScore(lost);
                metricsScore.setScore(score2);
                metricsScore.setScoreClassId(hlClassScore.getScoreClassId());
                hlMetricsScoreService.insertHlMetricsScore(metricsScore);

                for (Long eventId : eventIds) {
                    HlMetricsScoreDetail detail = new HlMetricsScoreDetail();
                    detail.setScoreMetricsId(metricsScore.getScoreMetricsId());
                    detail.setEventId(eventId);
                    details.add(detail);
                }
                viewList.forEach(view -> {
                    view.setScoreMetricsId(metricsScore.getScoreMetricsId());
                    views.add(view);
                });
                lostClass = lostClass.add(lost);
            }
            hlClassScore.setLoseScore(lostClass);
            BigDecimal df = BigDecimal.ZERO;
            if (hlClassScore.getHlScore().compareTo(lostClass) >= 0) {
                df = hlClassScore.getHlScore().subtract(lostClass);
            }
            hlClassScore.setScore(df);
            totalScore = totalScore.add(df);
            hlClassScoreService.updateHlClassScore(hlClassScore);
        }
        if (details.size() > 0) {
            try (SqlSession sqlSession = factory.openSession(ExecutorType.BATCH, false)) {
                HlMetricsScoreDetailMapper mapper = sqlSession.getMapper(HlMetricsScoreDetailMapper.class);
                details.forEach(mapper::insertHlMetricsScoreDetail);
                sqlSession.commit();
            }
        }
        if (views.size() > 0) {
            try (SqlSession sqlSession = factory.openSession(ExecutorType.BATCH, false)) {
                HlMetricsScoreViewMapper mapper = sqlSession.getMapper(HlMetricsScoreViewMapper.class);
                views.forEach(mapper::insertHlMetricsScoreView);
                sqlSession.commit();
            }
        }
        score.setHlScore(totalScore);
        updateHlScore(score);
    }

    /**
     * 日健康度评分
     *
     * @param date 时间
     */
    @Override
    public void day(Date date) {
//暂时先模拟分数
        //1.获取所有模型
        //2.获取模型健康度指标分类
        //3.1.获取对象
        //3.2.获取指标
        //
        List<BizModel> modelList = modelService.selectBizModelList(new BizModel());
        for (BizModel model : modelList) {
            HlScore score = new HlScore();
            score.setModelId(model.getModelId());
            score.setHlDate(date);
            score.setHlType("2");
            insertHlScore(score);
            BigDecimal totalLose = BigDecimal.ZERO;
            List<HlClass> classList = modelService.selectHlClassList4modelId(model.getModelId());
            for (HlClass hlClass : classList) {
                HlClassScore hlClassScore = new HlClassScore();
                BeanUtils.copyBeanProp(hlClassScore, hlClass);
                hlClassScore.setHlScoreId(score.getHlScoreId());
                List<HlObj> hlObjList = hlObjService.selectHlObjListByClassId(hlClass.getHlClassId());
                hlClassScoreService.insertHlClassScore(hlClassScore);
                HlMetrics hm = new HlMetrics();
                hm.setHlClassId(hlClass.getHlClassId());
                List<HlMetrics> hlMetricsList = hlMetricsService.selectHlMetricsList(hm);
                BigDecimal loseScore = BigDecimal.ZERO;
                //1.均分 2.细项分
//                hlClass.getScoreType();
                for (HlMetrics hlMetrics : hlMetricsList) {
                    //TODO ..这里需要从对象指标表里面去找。
//                    BizObjMetrics
//                    BizObjMetricsData
                    BigDecimal ss = random(hlMetrics.getHlScore().intValue());
                    BigDecimal lose = hlMetrics.getHlScore().subtract(ss);
                    loseScore = loseScore.add(lose);
                    HlMetricsScore metricsScore = new HlMetricsScore();
                    BeanUtils.copyBeanProp(metricsScore, hlMetrics);
                    metricsScore.setLoseScore(lose);
                    metricsScore.setScore(ss);
                    metricsScore.setScoreClassId(hlClassScore.getScoreClassId());
                    hlMetricsScoreService.insertHlMetricsScore(metricsScore);
//                    if (flag()) {
//                        //TODO 模拟扣分判断
//                        if ("1".equals(hlClassScore.getScoreType())) {
//                            //均分
////                            Random
//                        } else {
//                            //细项分
//                        }
//                    }
                }
                hlClassScore.setLoseScore(loseScore);
                totalLose = totalLose.add(loseScore);
                BigDecimal df = hlClassScore.getHlScore().subtract(loseScore);
                hlClassScore.setScore(df);
                hlClassScoreService.updateHlClassScore(hlClassScore);
            }

            score.setHlScore(BigDecimal.valueOf(100).subtract(totalLose));
            updateHlScore(score);
        }
    }


    /**
     * 日健康度评分
     *
     * @param date    时间
     * @param modelId 模型Id
     */
    @Override
    public void day(Date date, Long modelId) {
        HlScore score = new HlScore();
        score.setModelId(modelId);
        score.setHlDate(date);
        score.setHlType("2");
        insertHlScore(score);
        BigDecimal totalScore = BigDecimal.ZERO;
        //所有扣分的指标
        Map<Long, List<HlMetricsVO>> lostMetricsMap = hlMetricsService.hlMetricsDayList(modelId, date);
        //查找健康度分类
        List<HlClass> classList = modelService.selectHlClassList4modelId(modelId);
        List<HlMetricsScoreDetail> details = new ArrayList<>();
        for (HlClass hlClass : classList) {
            HlClassScore hlClassScore = new HlClassScore();
            BeanUtils.copyBeanProp(hlClassScore, hlClass);
            hlClassScore.setHlScoreId(score.getHlScoreId());
            hlClassScoreService.insertHlClassScore(hlClassScore);
            HlMetrics hm = new HlMetrics();
            hm.setHlClassId(hlClass.getHlClassId());
            List<HlMetrics> hlMetricsList = hlMetricsService.selectHlMetricsList(hm);
            //当前分类下所有指标
            Map<Long, List<HlMetricsVO>> metricsMap = hlMetricsService.hlMetricsList(hlClass.getHlClassId());
            BigDecimal lostClass = BigDecimal.ZERO;
            for (HlMetrics hlMetrics : hlMetricsList) {
                if ("1".equals(hlClass.getScoreType())) {
                    //1.均分 2.细项分
                    //如果是均分，需要计算，如果是细项分，直接用
                    BigDecimal metricsScore = hlClass.getHlScore().divide(BigDecimal.valueOf(hlMetricsList.size()), RoundingMode.HALF_UP);
                    hlMetrics.setHlScore(metricsScore);
                }

                //总的指标数量
                List<HlMetricsVO> vos1 = metricsMap.get(hlMetrics.getMetricsId());
                int total = vos1 != null ? vos1.size() : 0;
                //扣分指标数量
                List<HlMetricsVO> vos = lostMetricsMap.get(hlMetrics.getMetricsId());
                int lostNum = vos != null ? vos.size() : 0;
                //扣分
                BigDecimal lost = BigDecimal.ZERO;

                //（告警组件数量/总数量 ）*细项分
                if (lostNum > 0) {
                    if (total == 0) {
                        lost = BigDecimal.ZERO;
                    } else {
                        lost = BigDecimal.valueOf(lostNum).divide(BigDecimal.valueOf(total), RoundingMode.HALF_UP).multiply(hlMetrics.getHlScore());
                    }
                }
                //最终得分 = 分数-扣分
                BigDecimal score2 = BigDecimal.ZERO;
                if (hlMetrics.getHlScore().compareTo(lost) >= 0) {
                    score2 = hlMetrics.getHlScore().subtract(lost);
                }
                HlMetricsScore metricsScore = new HlMetricsScore();
                BeanUtils.copyBeanProp(metricsScore, hlMetrics);
                metricsScore.setLoseScore(lost);
                metricsScore.setScore(score2);
                metricsScore.setScoreClassId(hlClassScore.getScoreClassId());
                hlMetricsScoreService.insertHlMetricsScore(metricsScore);
                if (vos != null) {
                    for (HlMetricsVO vo : vos) {
                        HlMetricsScoreDetail detail = new HlMetricsScoreDetail();
                        detail.setScoreMetricsId(metricsScore.getScoreMetricsId());
                        detail.setEventId(vo.getEventId());
                        details.add(detail);
                    }
                }
                lostClass = lostClass.add(lost);
            }
            hlClassScore.setLoseScore(lostClass);
            BigDecimal df = BigDecimal.ZERO;
            if (hlClassScore.getHlScore().compareTo(lostClass) >= 0) {
                df = hlClassScore.getHlScore().subtract(lostClass);
            }
            hlClassScore.setScore(df);
            totalScore = totalScore.add(df);
            hlClassScoreService.updateHlClassScore(hlClassScore);
        }
        if (details.size() > 0) {
            try (SqlSession sqlSession = factory.openSession(ExecutorType.BATCH, false)) {
                HlMetricsScoreDetailMapper mapper = sqlSession.getMapper(HlMetricsScoreDetailMapper.class);
                details.forEach(mapper::insertHlMetricsScoreDetail);
                sqlSession.commit();
            }
        }
        score.setHlScore(totalScore);
        updateHlScore(score);
    }

    /**
     * 获取最近一次健康度得分
     *
     * @return 结果
     */
    @Override
    public List<HlScoreVO> selectHlScoreListLast() {
        return hlScoreMapper.selectHlScoreListLast();
    }


    /**
     * 根据模型ID删除健康度数据
     *
     * @param modelId 模型ID
     */
//    @Override
    public void deleteHlBase4ModelId(Long modelId) {
        if (modelId == -1) {
            return;
        }
        try {
            // 开始事务
            jdbcTemplate.execute("BEGIN");

            // 执行删除语句
            jdbcTemplate.update("DELETE FROM hl_detail WHERE HL_OBJ_ID IN (SELECT HL_OBJ_ID FROM hl_obj WHERE CLASS_ID IN (SELECT CLASS_ID FROM hl_class WHERE hl_base_id IN (SELECT hl_base_id FROM hl_base WHERE model_id = ?)))", modelId);
            jdbcTemplate.update("DELETE FROM hl_obj WHERE CLASS_ID IN (SELECT CLASS_ID FROM hl_class WHERE hl_base_id IN (SELECT hl_base_id FROM hl_base WHERE model_id = ?))", modelId);
            jdbcTemplate.update("DELETE FROM hl_class WHERE hl_base_id IN (SELECT hl_base_id FROM hl_base WHERE model_id = ?)", modelId);
            jdbcTemplate.update("DELETE FROM hl_base WHERE model_id = ?", modelId);

            // 提交事务
            jdbcTemplate.execute("COMMIT");
        } catch (Exception e) {
            // 回滚事务
            jdbcTemplate.execute("ROLLBACK");
            throw new RuntimeException(e);
        }
    }

//    /**
//     * 健康度评分
//     */
//    @Override
//    public void score() {
//        Map<String, String> expMap = relaService.selectHlMetricsRelaList(new HlMetricsRela()).stream()
//                .collect(Collectors.toMap(HlMetricsRela::getHlCode, HlMetricsRela::getExp));
//        Map<String, Long> defMap = defService.selectMetricsDefList(new MetricsDef()).stream().collect(Collectors.toMap(MetricsDef::getMetricsCode, MetricsDef::getMetricsId));
//
//        List<HlBase> list = selectHlBaseList(new HlBase());
//        list.forEach(base -> {
//            if (base.getModelId() != -1) {
//                Map<Long, List<BizObjMetrics>> metricsGroup = modelService.selectBizModelMetricsList(base.getModelId()).stream().collect(Collectors.groupingBy(BizObjMetrics::getMetricsId));
//                HlScore score = new HlScore();
//                score.setModelId(base.getModelId());
//                scoreService.insertHlScore(score);
//                List<HlClass> classes = base.getHlClassList();
//                AtomicReference<BigDecimal> total = new AtomicReference<>(new BigDecimal(0));
//                classes.forEach(cs -> {
//                    HlScoreDetail csDetail = new HlScoreDetail();
//                    csDetail.setHlScoreId(score.getHlScoreId());
//                    csDetail.setHlType("CLASS");
//                    csDetail.setHlCode(cs.getClassCode());
//                    List<HlObj> objs = cs.getHlObjList();
//                    AtomicReference<BigDecimal> scc = new AtomicReference<>(new BigDecimal(0));
//                    objs.forEach(ob -> {
//                        List<HlDetail> details = ob.getHlDetailList();
//                        HlScoreDetail obDetail = new HlScoreDetail();
//                        obDetail.setHlScoreId(score.getHlScoreId());
//                        obDetail.setHlType("OBJ");
//                        obDetail.setHlCode(ob.getHlObjCode());
//                        AtomicReference<BigDecimal> sc = new AtomicReference<>(new BigDecimal(0));
//                        if ("LINK".equals(ob.getHlObjCode())) {
//                            details.forEach(d -> {
//                                HlScoreDetail scoreDetail = new HlScoreDetail();
//                                scoreDetail.setHlScoreId(score.getHlScoreId());
//                                scoreDetail.setHlType("DETAIL");
//                                scoreDetail.setHlCode(d.getHlDetailCode());
//                                String hlCode = d.getHlDetailCode();
//                                String exp = expMap.get(hlCode);
//                                BigDecimal standScore = new BigDecimal(d.getHlDetailScore());
//                                switch (hlCode) {
//                                    case "C01":
//                                    case "C02":
//                                    case "C03":
//                                        if (StringUtils.isNotEmpty(exp)) {
//                                            Matcher matcher = match(exp);
//                                            Map<String, List<BizObjMetrics>> originalMap = new HashMap<>();
//                                            //先拿到一个code,好获取组件数量
//                                            String oneCode = "";
//                                            while (matcher.find()) {
//                                                String code = matcher.group(1);
//                                                String old = String.format("${%s}", code);
//                                                String newCode = code.replace(".", "");
//                                                oneCode = newCode;
//                                                exp = exp.replace(old, newCode);
//
//                                                Long mid = defMap.get(code);
//                                                List<BizObjMetrics> omList = metricsGroup.get(mid);
//                                                originalMap.put(newCode, omList);
//                                            }
//                                            // 获取组件数量
//                                            int size = originalMap.get(oneCode).size();
//                                            int alarmSize = 0;
//                                            // 遍历列表并创建新的 Map
//                                            for (int i = 0; i < size; i++) {
//                                                Map<String, Object> singleEntryMap = new HashMap<>();
//                                                for (String s : originalMap.keySet()) {
//                                                    singleEntryMap.put(s, originalMap.get(s).get(i).getDValue().floatValue());
//                                                }
//
//                                                boolean flag = evaluator(exp, singleEntryMap);
//                                                if (flag) {
//                                                    alarmSize++;
//                                                }
//                                            }
//                                            //最终得分（告警组件数量/总数量 ）*细项分
//                                            BigDecimal df = standScore.subtract(BigDecimal.valueOf(alarmSize).divide(BigDecimal.valueOf(size)).multiply(standScore));
//                                            scoreDetail.setHlScore(df);
//                                            scoreDetailService.insertHlScoreDetail(scoreDetail);
//                                        }
//                                        break;
//                                    default:
//                                        break;
//                                }
//                            });
//                        } else {
//                            sc.set(random(ob.getHlObjScore()));
//                        }
//                        obDetail.setHlScore(sc.get());
//                        scoreDetailService.insertHlScoreDetail(obDetail);
//                        scc.set(scc.get().add(obDetail.getHlScore()));
//                    });
//                    csDetail.setHlScore(scc.get());
//                    scoreDetailService.insertHlScoreDetail(csDetail);
//                    total.set(total.get().add(csDetail.getHlScore()));
//                });
//                score.setHlScore(total.get());
//                scoreService.updateHlScore(score);
//            }
//        });
//    }
//
//    /**
//     * 昨日健康度评分
//     */
//    @Override
//    public void yesterday() {
//        LocalDate localDate = LocalDate.now().minusDays(1);
//        List<HlBase> list = selectHlBaseList(new HlBase());
//
//        list.forEach(base -> {
//            if (base.getModelId() != -1) {
//                HlDay hlDay = new HlDay();
//                hlDay.setModelId(base.getModelId());
//                hlDay.setHlDate(Date.from(localDate.atStartOfDay(ZoneId.systemDefault()).toInstant()));
//                dayService.insertHlDay(hlDay);
//                List<HlClass> classes = base.getHlClassList();
//                AtomicReference<BigDecimal> total = new AtomicReference<>(new BigDecimal(0));
//                classes.forEach(cs -> {
//                    HlDayDetail csDetail = new HlDayDetail();
//                    csDetail.setDayId(hlDay.getDayId());
//                    csDetail.setHlType("CLASS");
//                    csDetail.setHlCode(cs.getClassCode());
//                    List<HlObj> objs = cs.getHlObjList();
//                    AtomicReference<BigDecimal> scc = new AtomicReference<>(new BigDecimal(0));
//                    objs.forEach(ob -> {
//                        List<HlDetail> details = ob.getHlDetailList();
//                        HlDayDetail obDetail = new HlDayDetail();
//                        obDetail.setDayId(hlDay.getDayId());
//                        obDetail.setHlType("OBJ");
//                        obDetail.setHlCode(ob.getHlObjCode());
//                        AtomicReference<BigDecimal> sc = new AtomicReference<>(new BigDecimal(0));
//                        if ("LINK".equals(ob.getHlObjCode())) {
//                            details.forEach(d -> {
//                                HlDayDetail scoreDetail = new HlDayDetail();
//                                scoreDetail.setDayId(hlDay.getDayId());
//                                scoreDetail.setHlType("DETAIL");
//                                scoreDetail.setHlCode(d.getHlDetailCode());
//                                switch (d.getHlDetailCode()) {
//                                    case "C01":
//                                    case "C02":
//                                    case "C03":
//                                        BigDecimal dc = random(d.getHlDetailScore());
//                                        scoreDetail.setHlScore(dc);
//                                        sc.set(sc.get().add(dc));
//                                        dayDetailService.insertHlDayDetail(scoreDetail);
//                                        break;
//                                    default:
//                                        break;
//                                }
//                            });
//                        } else {
//                            sc.set(random(ob.getHlObjScore()));
//                        }
//                        obDetail.setHlScore(sc.get());
//                        dayDetailService.insertHlDayDetail(obDetail);
//                        scc.set(scc.get().add(obDetail.getHlScore()));
//                    });
//                    csDetail.setHlScore(scc.get());
//                    dayDetailService.insertHlDayDetail(csDetail);
//                    total.set(total.get().add(csDetail.getHlScore()));
//                });
//                hlDay.setHlScore(total.get());
//                dayService.updateHlDay(hlDay);
//            }
//        });
//    }

    private BigDecimal random(int s) {
        Random random = new Random();
        int randomNumber = random.nextInt(s);
//        // 生01到3的随机数
//        int v = s.intValue() - randomNumber;
        return BigDecimal.valueOf(randomNumber);
    }

    /**
     * 公式计算
     *
     * @param exp 表达式
     * @param env 值
     * @return 结果
     */
    private boolean evaluator(String exp, Map<String, Object> env) {
        return (boolean) AviatorEvaluator.execute(exp, env);
    }

    /**
     * 正则匹配
     *
     * @param exp 表达式
     * @return 结果
     */
    private Matcher match(String exp) {
        //正则表达式匹配变量
        Pattern pattern = Pattern.compile("\\$\\{(.+?)\\}");
        return pattern.matcher(exp);
    }
}
