package com.jjt.push.service;

import com.jjt.biz.domain.AlarmRecord;
import com.jjt.push.domain.PushConfig;

import java.util.List;

/**
 * 推送配置Service接口
 *
 * @author jjt
 * @date 2024-10-08
 */
public interface IPushConfigService {
    /**
     * 查询推送配置
     *
     * @param pcId 推送配置主键
     * @return 推送配置
     */
    public PushConfig selectPushConfigByPcId(Long pcId);

    /**
     * 查询推送配置列表
     *
     * @param pushConfig 推送配置
     * @return 推送配置集合
     */
    public List<PushConfig> selectPushConfigList(PushConfig pushConfig);

    /**
     * 新增推送配置
     *
     * @param pushConfig 推送配置
     * @return 结果
     */
    public int insertPushConfig(PushConfig pushConfig);

    /**
     * 修改推送配置
     *
     * @param pushConfig 推送配置
     * @return 结果
     */
    public int updatePushConfig(PushConfig pushConfig);

    /**
     * 批量删除推送配置
     *
     * @param pcIds 需要删除的推送配置主键集合
     * @return 结果
     */
    public int deletePushConfigByPcIds(Long[] pcIds);

    /**
     * 删除推送配置信息
     *
     * @param pcId 推送配置主键
     * @return 结果
     */
    public int deletePushConfigByPcId(Long pcId);

    /**
     * 发送短信
     *
     * @param phone   手机号
     * @param content 内容
     */
    void sendSms(String phone, String content) throws Exception;

    /**
     * 推送告警信息
     *
     * @param record 告警记录
     */
    void push(AlarmRecord record);

    /**
     * 发送邮件
     *
     * @param mail    邮箱
     * @param title   标题
     * @param content 内容
     */
    void sendMail(String mail, String title, String content) throws Exception;
}
