package com.jjt.push.service.impl;

import cn.hutool.json.JSONUtil;
import com.jjt.push.domain.PushConfig;
import com.jjt.push.mapper.PushConfigMapper;
import com.jjt.push.service.IMailService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.mail.*;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;
import java.util.Map;
import java.util.Properties;

/**
 * 推送配置Service业务层处理
 *
 * @author jjt
 * @date 2024-10-08
 */
@Service
public class MailServiceImpl implements IMailService {
    @Resource
    private PushConfigMapper pushConfigMapper;


    private String user;
    private String pass;
    private String smtp;
    private Integer port;
    private Boolean auth;

    private void config() {
        PushConfig pc = pushConfigMapper.selectPushConfigByPcId(1L);
        Map<String, Object> map = JSONUtil.toBean(pc.getConfigMail(), Map.class);
        auth = (Boolean) map.get("auth");
        user = (String) map.get("user");
        pass = (String) map.get("pass");
        smtp = (String) map.get("smtp");
        port = (Integer) map.get("port");
    }

    /**
     * 发送邮件
     *
     * @param mail    邮箱
     * @param title   标题
     * @param content 内容
     * @return 结果
     * @throws Exception 异常
     */
    @Override
    public boolean send(String mail, String title, String content) throws Exception {
        config();
        Properties props = new Properties();
        props.put("mail.smtp.auth", auth);
        props.put("mail.smtp.starttls.enable", "true");
        props.put("mail.smtp.host", smtp);
        props.put("mail.smtp.port", port);

        Session session = Session.getInstance(props, new Authenticator() {
            @Override
            protected PasswordAuthentication getPasswordAuthentication() {
                return new PasswordAuthentication(user, pass);
            }
        });

        try {
            Message message = new MimeMessage(session);
            message.setFrom(new InternetAddress(user));
            // 设置发件人
            message.setRecipients(Message.RecipientType.TO, InternetAddress.parse(mail));
            // 设置收件人
            message.setSubject(title);
            // 设置邮件主题
            message.setText(content);
            // 设置邮件内容

            Transport.send(message);
            return true;
        } catch (MessagingException e) {
            throw new RuntimeException("邮件发送错误:{}" + e.getMessage());
        }
    }
}
