package com.jjt.push.service.impl;

import com.jjt.push.domain.PushRecord;
import com.jjt.push.mapper.PushRecordMapper;
import com.jjt.push.service.IPushRecordService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * 推送记录Service业务层处理
 *
 * @author jjt
 * @date 2024-10-11
 */
@Service
public class PushRecordServiceImpl implements IPushRecordService {
    @Resource
    private PushRecordMapper pushRecordMapper;

    /**
     * 查询推送记录
     *
     * @param prId 推送记录主键
     * @return 推送记录
     */
    @Override
    public PushRecord selectPushRecordByPrId(Long prId) {
        return pushRecordMapper.selectPushRecordByPrId(prId);
    }

    /**
     * 查询推送记录列表
     *
     * @param pushRecord 推送记录
     * @return 推送记录
     */
    @Override
    public List<PushRecord> selectPushRecordList(PushRecord pushRecord) {
        return pushRecordMapper.selectPushRecordList(pushRecord);
    }

    /**
     * 新增推送记录
     *
     * @param pushRecord 推送记录
     * @return 结果
     */
    @Override
    public int insertPushRecord(PushRecord pushRecord) {
        pushRecord.setSendTime(new Date());
        return pushRecordMapper.insertPushRecord(pushRecord);
    }

    /**
     * 修改推送记录
     *
     * @param pushRecord 推送记录
     * @return 结果
     */
    @Override
    public int updatePushRecord(PushRecord pushRecord) {
        return pushRecordMapper.updatePushRecord(pushRecord);
    }

    /**
     * 批量删除推送记录
     *
     * @param prIds 需要删除的推送记录主键
     * @return 结果
     */
    @Override
    public int deletePushRecordByPrIds(Long[] prIds) {
        return pushRecordMapper.deletePushRecordByPrIds(prIds);
    }

    /**
     * 删除推送记录信息
     *
     * @param prId 推送记录主键
     * @return 结果
     */
    @Override
    public int deletePushRecordByPrId(Long prId) {
        return pushRecordMapper.deletePushRecordByPrId(prId);
    }
}
