package com.jjt.push.service.impl;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.jjt.push.domain.PushConfig;
import com.jjt.push.mapper.PushConfigMapper;
import com.jjt.push.service.ISmsService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * 推送配置Service业务层处理
 *
 * @author jjt
 * @date 2024-10-08
 */
@Service
public class SmsServiceImpl implements ISmsService {
    @Resource
    private PushConfigMapper pushConfigMapper;

    /**
     * 发送邮件
     *
     * @param phone   手机号
     * @param content 内容
     * @return 结果
     * @throws Exception 异常
     */
    @Override
    public boolean send(String phone, String content) throws Exception {
        //获取短信接口发送地址
        PushConfig pc = pushConfigMapper.selectPushConfigByPcId(1L);
        Map<String, Object> map = JSONUtil.toBean(pc.getConfigSms(), Map.class);
        String uri = (String) map.get("uri");
        return send(uri, phone, content);
    }

    /**
     * 发送邮件
     * 发送短信
     *
     * @param uri     地址
     * @param phone   手机号
     * @param content 内容
     * @return 结果
     */
    @Override
    public boolean send(String uri, String phone, String content) throws Exception {
        // 封装请求体
        JSONObject json = new JSONObject();
        json.putOnce("phone", phone);
        json.putOnce("message", content);
        // 添加请求头信息
        Map<String, String> heads = new HashMap<>();
        // 使用json发送请求，下面的是必须的
        heads.put("Content-Type", "application/json;charset=UTF-8");

        try {
        /* headerMap是添加的请求头
            body是传入的参数，这里选择json，后端使用@RequestBody接收
         */
            HttpResponse response = HttpRequest.post(uri)
                    .headerMap(heads, false)
                    .body(json.toJSONString(1))
                    .timeout(5 * 1000)
                    .execute();
            JSONObject object = JSONUtil.parseObj(response.body(), true);
            Integer result = object.getInt("result");
            if (result == 0) {
                return true;
            } else {
                throw new Exception(object.toJSONString(1));
            }
        } catch (Exception e) {
            throw new Exception("短信发送错误：" + e.getMessage());
        }
    }
}
