package com.jjt.risk.controller;

import com.jjt.biz.domain.BizObj;
import com.jjt.biz.domain.MetricsDef;
import com.jjt.biz.service.IBizObjService;
import com.jjt.biz.service.IMetricsDefService;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.risk.domain.RiskModel;
import com.jjt.risk.domain.RiskObj;
import com.jjt.risk.service.IRiskModelService;
import com.jjt.risk.service.IRiskObjService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 风险管理Controller
 *
 * @author jjt
 * @date 2024-09-12
 */
@Api(tags = "风险管理")
@RestController
@RequestMapping("/risk/model")
public class RiskModelController extends BaseController {
    @Resource
    private IRiskModelService riskModelService;
    @Resource
    private IMetricsDefService metricsDefService;
    @Resource
    private IBizObjService objService;
    @Resource
    private IRiskObjService riskObjService;


    @ApiOperation("查询所有指标")
    @GetMapping("/ms/list")
    public AjaxResult msList() {
        List<MetricsDef> list = metricsDefService.selectMetricsDefList(new MetricsDef());
        return AjaxResult.success(list);
    }

    @ApiOperation("根据指标ID查询对象列表")
    @GetMapping("/obj/list")
    public AjaxResult objList(Long metricsId) {
        List<BizObj> list = objService.selectBizObjListByMetricsId(metricsId);
        return AjaxResult.success(list);
    }

    /**
     * 查询风险管理列表
     */
    @ApiOperation("查询风险管理列表")
    //@PreAuthorize("@ss.hasPermi('risk:model:list')")
    @GetMapping("/list")
    public TableDataInfo list(RiskModel riskModel) {
        startPage();
        List<RiskModel> list = riskModelService.selectRiskModelList(riskModel);
        return getDataTable(list);
    }

    /**
     * 导出风险管理列表
     */
    @ApiOperation("导出风险管理列表")
    //@PreAuthorize("@ss.hasPermi('risk:model:export')")
    @Log(title = "风险管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RiskModel riskModel) {
        List<RiskModel> list = riskModelService.selectRiskModelList(riskModel);
        ExcelUtil<RiskModel> util = new ExcelUtil<RiskModel>(RiskModel.class);
        util.exportExcel(response, list, "风险管理数据");
    }

    /**
     * 获取风险管理详细信息
     */
    @ApiOperation("获取风险管理详细信息")
    @GetMapping(value = "/{riskId}")
    public AjaxResult getInfo(@PathVariable("riskId") Long riskId) {
        RiskModel riskModel = riskModelService.selectRiskModelByRiskId(riskId);
        List<Long> ids = riskModel.getRiskObjList().stream().map(RiskObj::getObjId).collect(Collectors.toList());
        riskModel.setObjIds(ids);
        return success(riskModel);
    }

    /**
     * 新增风险管理
     */
    @ApiOperation("新增风险管理")
    //@PreAuthorize("@ss.hasPermi('risk:model:add')")
    @Log(title = "风险管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RiskModel riskModel) {
        int r = riskModelService.insertRiskModel(riskModel);
        if ("2".equals(riskModel.getObjType())) {
            //如果是自定义对象
            riskObjService.process(riskModel.getRiskId(), riskModel.getObjIds());
        }
        return toAjax(r);
    }

    /**
     * 修改风险管理
     */
    @ApiOperation("修改风险管理")
    //@PreAuthorize("@ss.hasPermi('risk:model:edit')")
    @Log(title = "风险管理", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody RiskModel riskModel) {
        if ("2".equals(riskModel.getObjType())) {
            //如果是自定义对象
            riskObjService.process(riskModel.getRiskId(), riskModel.getObjIds());
        }
        return toAjax(riskModelService.updateRiskModel(riskModel));
    }

    /**
     * 删除风险管理
     */
    @ApiOperation("删除风险管理")
    //@PreAuthorize("@ss.hasPermi('risk:model:remove')")
    @Log(title = "风险管理", businessType = BusinessType.DELETE)
    @GetMapping("/del")
    public AjaxResult remove(Long[] riskIds) {
        return toAjax(riskModelService.deleteRiskModelByRiskIds(riskIds));
    }
}
