package com.jjt.risk.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.risk.domain.RiskObj;
import com.jjt.risk.service.IRiskObjService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 风险管理对象Controller
 *
 * @author jjt
 * @date 2024-09-12
 */
@Api(tags="风险管理对象")
@RestController
@RequestMapping("/risk/obj")
public class RiskObjController extends BaseController
{
    @Resource
    private IRiskObjService riskObjService;

    /**
     * 查询风险管理对象列表
     */
    @ApiOperation("查询风险管理对象列表")
    //@PreAuthorize("@ss.hasPermi('risk:obj:list')")
    @GetMapping("/list")
    public TableDataInfo list(RiskObj riskObj)
    {
        startPage();
        List<RiskObj> list = riskObjService.selectRiskObjList(riskObj);
        return getDataTable(list);
    }

    /**
     * 导出风险管理对象列表
     */
    @ApiOperation("导出风险管理对象列表")
    //@PreAuthorize("@ss.hasPermi('risk:obj:export')")
    @Log(title = "风险管理对象", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RiskObj riskObj)
    {
        List<RiskObj> list = riskObjService.selectRiskObjList(riskObj);
        ExcelUtil<RiskObj> util = new ExcelUtil<RiskObj>(RiskObj.class);
        util.exportExcel(response, list, "风险管理对象数据");
    }

    /**
     * 获取风险管理对象详细信息
     */
    @ApiOperation("获取风险管理对象详细信息")
    //@PreAuthorize("@ss.hasPermi('risk:obj:query')")
    @GetMapping(value = "/{riskObjId}")
    public AjaxResult getInfo(@PathVariable("riskObjId") Long riskObjId)
    {
        return success(riskObjService.selectRiskObjByRiskObjId(riskObjId));
    }

    /**
     * 新增风险管理对象
     */
    @ApiOperation("新增风险管理对象")
    //@PreAuthorize("@ss.hasPermi('risk:obj:add')")
    @Log(title = "风险管理对象", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RiskObj riskObj)
    {
        return toAjax(riskObjService.insertRiskObj(riskObj));
    }

    /**
     * 修改风险管理对象
     */
    @ApiOperation("修改风险管理对象")
    //@PreAuthorize("@ss.hasPermi('risk:obj:edit')")
    @Log(title = "风险管理对象", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
   public AjaxResult edit(@RequestBody RiskObj riskObj)
    {
        return toAjax(riskObjService.updateRiskObj(riskObj));
    }

    /**
     * 删除风险管理对象
     */
    @ApiOperation("删除风险管理对象")
    //@PreAuthorize("@ss.hasPermi('risk:obj:remove')")
    @Log(title = "风险管理对象", businessType = BusinessType.DELETE)
	@GetMapping("/del/{riskObjIds}")
    public AjaxResult remove(@PathVariable Long[] riskObjIds)
    {
        return toAjax(riskObjService.deleteRiskObjByRiskObjIds(riskObjIds));
    }
}
