package com.jjt.risk.service;

import com.jjt.risk.domain.RiskAnalysis;
import com.jjt.risk.domain.RiskModel;

import java.util.Date;
import java.util.List;

/**
 * 风险分析结果Service接口
 *
 * @author jjt
 * @date 2024-09-12
 */
public interface IRiskAnalysisService {
    /**
     * 查询风险分析结果
     *
     * @param resultId 风险分析结果主键
     * @return 风险分析结果
     */
    public RiskAnalysis selectRiskAnalysisByResultId(Long resultId);

    /**
     * 查询风险分析结果列表
     *
     * @param riskAnalysis 风险分析结果
     * @return 风险分析结果集合
     */
    public List<RiskAnalysis> selectRiskAnalysisList(RiskAnalysis riskAnalysis);

    /**
     * 新增风险分析结果
     *
     * @param riskAnalysis 风险分析结果
     * @return 结果
     */
    public int insertRiskAnalysis(RiskAnalysis riskAnalysis);

    /**
     * 修改风险分析结果
     *
     * @param riskAnalysis 风险分析结果
     * @return 结果
     */
    public int updateRiskAnalysis(RiskAnalysis riskAnalysis);

    /**
     * 批量删除风险分析结果
     *
     * @param resultIds 需要删除的风险分析结果主键集合
     * @return 结果
     */
    public int deleteRiskAnalysisByResultIds(Long[] resultIds);

    /**
     * 删除风险分析结果信息
     *
     * @param resultId 风险分析结果主键
     * @return 结果
     */
    public int deleteRiskAnalysisByResultId(Long resultId);

    /**
     * 立即分析
     *
     * @param rm 风险对象
     * @param d  时间
     * @return 结果
     */
    RiskAnalysis risk(RiskModel rm, Date d) throws Exception;
}
