package com.jjt.risk.service;

import com.jjt.risk.domain.RiskObj;

import java.util.List;

/**
 * 风险管理对象Service接口
 *
 * @author jjt
 * @date 2024-09-12
 */
public interface IRiskObjService {
    /**
     * 查询风险管理对象
     *
     * @param riskObjId 风险管理对象主键
     * @return 风险管理对象
     */
    public RiskObj selectRiskObjByRiskObjId(Long riskObjId);

    /**
     * 查询风险管理对象列表
     *
     * @param riskObj 风险管理对象
     * @return 风险管理对象集合
     */
    public List<RiskObj> selectRiskObjList(RiskObj riskObj);

    /**
     * 新增风险管理对象
     *
     * @param riskObj 风险管理对象
     * @return 结果
     */
    public int insertRiskObj(RiskObj riskObj);

    /**
     * 修改风险管理对象
     *
     * @param riskObj 风险管理对象
     * @return 结果
     */
    public int updateRiskObj(RiskObj riskObj);

    /**
     * 批量删除风险管理对象
     *
     * @param riskObjIds 需要删除的风险管理对象主键集合
     * @return 结果
     */
    public int deleteRiskObjByRiskObjIds(Long[] riskObjIds);

    /**
     * 删除风险管理对象信息
     *
     * @param riskObjId 风险管理对象主键
     * @return 结果
     */
    public int deleteRiskObjByRiskObjId(Long riskObjId);

    /**
     * 处理风险对象
     *
     * @param riskId 风险ID
     * @param objIds 对象IDS
     */
    void process(Long riskId, List<Long> objIds);
}
