package com.jjt.risk.service.impl;

import java.util.List;
        import com.jjt.common.utils.DateUtils;
import org.springframework.stereotype.Service;
import com.jjt.risk.mapper.RiskModelMapper;
import com.jjt.risk.domain.RiskModel;
import com.jjt.risk.service.IRiskModelService;
import javax.annotation.Resource;

/**
 * 风险管理Service业务层处理
 *
 * @author jjt
 * @date 2024-09-12
 */
@Service
public class RiskModelServiceImpl implements IRiskModelService {
    @Resource
    private RiskModelMapper riskModelMapper;

    /**
     * 查询风险管理
     *
     * @param riskId 风险管理主键
     * @return 风险管理
     */
    @Override
    public RiskModel selectRiskModelByRiskId(Long riskId) {
        return riskModelMapper.selectRiskModelByRiskId(riskId);
    }

    /**
     * 查询风险管理列表
     *
     * @param riskModel 风险管理
     * @return 风险管理
     */
    @Override
    public List<RiskModel> selectRiskModelList(RiskModel riskModel) {
        return riskModelMapper.selectRiskModelList(riskModel);
    }

    /**
     * 新增风险管理
     *
     * @param riskModel 风险管理
     * @return 结果
     */
    @Override
    public int insertRiskModel(RiskModel riskModel) {
                riskModel.setCreateTime(DateUtils.getNowDate());
            return riskModelMapper.insertRiskModel(riskModel);
    }

    /**
     * 修改风险管理
     *
     * @param riskModel 风险管理
     * @return 结果
     */
    @Override
    public int updateRiskModel(RiskModel riskModel) {
                riskModel.setUpdateTime(DateUtils.getNowDate());
        return riskModelMapper.updateRiskModel(riskModel);
    }

    /**
     * 批量删除风险管理
     *
     * @param riskIds 需要删除的风险管理主键
     * @return 结果
     */
    @Override
    public int deleteRiskModelByRiskIds(Long[] riskIds) {
        return riskModelMapper.deleteRiskModelByRiskIds(riskIds);
    }

    /**
     * 删除风险管理信息
     *
     * @param riskId 风险管理主键
     * @return 结果
     */
    @Override
    public int deleteRiskModelByRiskId(Long riskId) {
        return riskModelMapper.deleteRiskModelByRiskId(riskId);
    }
}
