package com.jjt.risk.service.impl;

import java.util.List;
        import com.jjt.common.utils.DateUtils;
import org.springframework.stereotype.Service;
import com.jjt.risk.mapper.RiskMsConfigMapper;
import com.jjt.risk.domain.RiskMsConfig;
import com.jjt.risk.service.IRiskMsConfigService;
import javax.annotation.Resource;

/**
 * 风险管理指标配置Service业务层处理
 *
 * @author jjt
 * @date 2024-09-12
 */
@Service
public class RiskMsConfigServiceImpl implements IRiskMsConfigService {
    @Resource
    private RiskMsConfigMapper riskMsConfigMapper;

    /**
     * 查询风险管理指标配置
     *
     * @param hcId 风险管理指标配置主键
     * @return 风险管理指标配置
     */
    @Override
    public RiskMsConfig selectRiskMsConfigByHcId(Long hcId) {
        return riskMsConfigMapper.selectRiskMsConfigByHcId(hcId);
    }

    /**
     * 查询风险管理指标配置列表
     *
     * @param riskMsConfig 风险管理指标配置
     * @return 风险管理指标配置
     */
    @Override
    public List<RiskMsConfig> selectRiskMsConfigList(RiskMsConfig riskMsConfig) {
        return riskMsConfigMapper.selectRiskMsConfigList(riskMsConfig);
    }

    /**
     * 新增风险管理指标配置
     *
     * @param riskMsConfig 风险管理指标配置
     * @return 结果
     */
    @Override
    public int insertRiskMsConfig(RiskMsConfig riskMsConfig) {
                riskMsConfig.setCreateTime(DateUtils.getNowDate());
            return riskMsConfigMapper.insertRiskMsConfig(riskMsConfig);
    }

    /**
     * 修改风险管理指标配置
     *
     * @param riskMsConfig 风险管理指标配置
     * @return 结果
     */
    @Override
    public int updateRiskMsConfig(RiskMsConfig riskMsConfig) {
                riskMsConfig.setUpdateTime(DateUtils.getNowDate());
        return riskMsConfigMapper.updateRiskMsConfig(riskMsConfig);
    }

    /**
     * 批量删除风险管理指标配置
     *
     * @param hcIds 需要删除的风险管理指标配置主键
     * @return 结果
     */
    @Override
    public int deleteRiskMsConfigByHcIds(Long[] hcIds) {
        return riskMsConfigMapper.deleteRiskMsConfigByHcIds(hcIds);
    }

    /**
     * 删除风险管理指标配置信息
     *
     * @param hcId 风险管理指标配置主键
     * @return 结果
     */
    @Override
    public int deleteRiskMsConfigByHcId(Long hcId) {
        return riskMsConfigMapper.deleteRiskMsConfigByHcId(hcId);
    }
}
