package com.jjt.risk.service.impl;

import com.jjt.risk.domain.RiskObj;
import com.jjt.risk.mapper.RiskObjMapper;
import com.jjt.risk.service.IRiskObjService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 风险管理对象Service业务层处理
 *
 * @author jjt
 * @date 2024-09-12
 */
@Service
public class RiskObjServiceImpl implements IRiskObjService {
    @Resource
    private RiskObjMapper riskObjMapper;

    /**
     * 查询风险管理对象
     *
     * @param riskObjId 风险管理对象主键
     * @return 风险管理对象
     */
    @Override
    public RiskObj selectRiskObjByRiskObjId(Long riskObjId) {
        return riskObjMapper.selectRiskObjByRiskObjId(riskObjId);
    }

    /**
     * 查询风险管理对象列表
     *
     * @param riskObj 风险管理对象
     * @return 风险管理对象
     */
    @Override
    public List<RiskObj> selectRiskObjList(RiskObj riskObj) {
        return riskObjMapper.selectRiskObjList(riskObj);
    }

    /**
     * 新增风险管理对象
     *
     * @param riskObj 风险管理对象
     * @return 结果
     */
    @Override
    public int insertRiskObj(RiskObj riskObj) {
        return riskObjMapper.insertRiskObj(riskObj);
    }

    /**
     * 修改风险管理对象
     *
     * @param riskObj 风险管理对象
     * @return 结果
     */
    @Override
    public int updateRiskObj(RiskObj riskObj) {
        return riskObjMapper.updateRiskObj(riskObj);
    }

    /**
     * 批量删除风险管理对象
     *
     * @param riskObjIds 需要删除的风险管理对象主键
     * @return 结果
     */
    @Override
    public int deleteRiskObjByRiskObjIds(Long[] riskObjIds) {
        return riskObjMapper.deleteRiskObjByRiskObjIds(riskObjIds);
    }

    /**
     * 删除风险管理对象信息
     *
     * @param riskObjId 风险管理对象主键
     * @return 结果
     */
    @Override
    public int deleteRiskObjByRiskObjId(Long riskObjId) {
        return riskObjMapper.deleteRiskObjByRiskObjId(riskObjId);
    }

    /**
     * 处理风险对象
     *
     * @param riskId 风险ID
     * @param objIds 对象IDS
     */
    @Override
    public void process(Long riskId, List<Long> objIds) {
        //1.先删除，再插入
        riskObjMapper.deleteRiskObjByRiskId(riskId);
        for (Long objId : objIds) {
            RiskObj riskObj = new RiskObj();
            riskObj.setRiskId(riskId);
            riskObj.setObjId(objId);
            insertRiskObj(riskObj);
        }
    }
}
